# proc checkforupdates {}  
# Checks online at the Sourceforge web site to see if there is a 
# later version of the software. The Sourceforge site has a file
# http://chessdb.sourceforge.net/tutorial/version.txt which has
# 5 integers descriging the version, 3 for the date, the a : then another 
# 3 for the stable realease and another 3 for the date of the 
# stable release. 

# Then there can be several lines, indicating any bugs. 
# eg. 
# 3 6 11 -1  9 1 2007 1 14 : 3 6 9 0 0 2007 1 1
# found a bug #1 - cured in version 2
# found a bug #2 - cured in version 34
# indicates 3.6.11-beta1 and latest stable is 3.6.9

proc checkforupdates {} {
    global majorVersion minorVersion patchlevel chessdbVersion\
      chessdbVersionDate betalevel
    global Latestmajor Latestminor Latestpatch LatestBetaNumber\
      YearOfLatestRelease MonthOfLatestRelease DayOfLatestRelease colon\
      LatestStablemajor LatestStableminor LatestStablepatch\
      YearOfLatestStableRelease MonthOfLatestStableRelease\
      DayOfLatestStableRelease

    # Set the file on the web site which will hold the version 
    set url [format http://chessdb.sourceforge.net/tutorial/version.txt]
    # set url  [format http://192.168.0.10/versions-of-chessdb.txt ]

    # Name of a temporary file on my local disk. This must be writable by the\
      user. If not
    # there will be a problem. I need to put some sort of error handler to\
      handle the case
    # where the user starts ChessDB in a directory where he/she does not have\
      write access. 

    set tmpfile [file join $::chessdbTWICDir "version.txt"]

    # Make sure we can connect to the web site, since if not, there is nothing\
      we can do. 
    # I can't say I fully understand this bit - in fact, I don't undertstand\
      most of it. 

    set token [geturl_followRedirects $url -validate 1]
    if {! [regexp -nocase {ok} [::http::code $token]]} {
    }

    set token [httpcopy $url $tmpfile]
    set status [http::status $token]
    set code [http::code $token]
    puts $token

    # Check the result code from the web server. If this is not
    # 200, then there is a problem and we should
    # break out of the loop, delete the zip file (since it has a problem)
    # and set the file 'start-from' so it starts from that next time.
    set ind [string first 200 $code]
    if {$ind == -1} {
	tk_messageBox -type ok -icon warning -title [tr HelpCheckForUpdates]\
	  -message "[tr HelpUpdateStatusCantConnect] $code"
	return
    }

    set fd [open $tmpfile "r"]
    gets $fd line
    close $fd

    # Now scan the consents fo the file, looking for the  integers which give\
      information about the 
    # latest version of the software, and the date it was released. That way a\
      user will know if 
    # his copy is only a few days old, or very old. 

    scan $line "%d %d %d %d %d  %d %d %d %c %d %d %d %d %d %d " Latestmajor\
      Latestminor Latestpatch StableOrBeta LatestBetaNumber\
      YearOfLatestRelease MonthOfLatestRelease DayOfLatestRelease colon\
      LatestStablemajor LatestStableminor LatestStablepatch\
      YearOfLatestStableRelease MonthOfLatestStableRelease\
      DayOfLatestStableRelease

    # Format the version data to be of the form of major.minor.patchlevel, so\
      code with a major 
    # version of 3, a minor version of 6 and a patchlevel of 10, will be\
      written as "3.6.10"

    # First this is done for the latest version of the software. 
    if {$StableOrBeta == 0} {
	set LatestchessdbVersion [format "%d.%d.%d" $Latestmajor $Latestminor\
	  $Latestpatch]
    }
    if {$StableOrBeta == -1} {
	set LatestchessdbVersion [format "%d.%d.%d-beta-%d" $Latestmajor\
	  $Latestminor $Latestpatch $LatestBetaNumber]
    }


    # format the date of the last release in the ISO 8601 format - i.e.\
      YYYY-MM-DD
    set DateOfLastRelease [format "%04d-%02d-%02d" $YearOfLatestRelease\
      $MonthOfLatestRelease $DayOfLatestRelease]

    # Now do the same for the latest stable version. 
    set LatestStablechessdbVersion [format "%d.%d.%d" $LatestStablemajor\
      $LatestStableminor $LatestStablepatch]

    # format the date of the last stable release in the ISO 8601 format - i.e.\
      YYYY-MM-DD
    set DateOfLastStableRelease [format\
      "%04d-%02d-%02d" $YearOfLatestStableRelease $MonthOfLatestStableRelease\
      $DayOfLatestStableRelease]
    set DateOfLastBeta [format %04d-%02d-%02d $YearOfLatestRelease\
      $MonthOfLatestRelease $DayOfLatestRelease]

    # Now there are 5 ways to exit if the software is old. First if the major\
      version is out of date, there 
    # is no need to bother considering the minor versions or patch levels. 
    # The software (ChessDB, a database at\
      http://sourceforge.net/projects/chessdb ) has menus for several 
    # languages  Czech, Dutch, English, French, German, Hungarian, Italian, 
    # Norwegian, Polish, Portuguese, Serbian, Spanish and Swedish. Russian\
      support is dropped, unless anyone 
    # else wants to take it on. 

    # For this reason, all the messages given to the message box are just a\
      code, such as 'HelpTitleUpdatesMessage'
    # Depending on the language set in the software, a different message will\
      be displayed. The English

    if {$majorVersion < $Latestmajor} {
	if {$StableOrBeta != 0} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableThereIsLaterBeta]\n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease\n\n[tr\
	      VersionOfLatestBeta] $LatestchessdbVersion [tr DateOfRelease]\
	      $DateOfLastBeta \n\n[tr ThisVersionIs] $chessdbVersion\
	      [tr WhichWasRelasedOn] $chessdbVersionDate \n\n[tr FreeUpgradeAt]"
	    return
	} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableButNoLaterBeta] \n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease \n\n[tr\
	      ThisVersionIs] $chessdbVersion [tr WhichWasRelasedOn]\
	      $chessdbVersionDate \n\n[tr FreeUpgradeAt]"
	    return
	}
    }
    # If the minor version is out of date, but then we should exit unless the\
      major version overrides this. 
    # But the major version has just been checked, so no need to worry. 
    if {$minorVersion < $Latestminor && $majorVersion == $Latestmajor } {
	if {$StableOrBeta != 0} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableThereIsLaterBeta] \n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease\
	      [tr VersionOfLatestBeta] $LatestchessdbVersion\
	      [tr DateOfRelease] $DateOfLastBeta \n\n[tr ThisVersionIs]\
	      $chessdbVersion [tr WhichWasRelasedOn] $chessdbVersionDate\
	      \n\n[tr FreeUpgradeAt]"
	    return
	} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableButNoLaterBeta]\n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease \n\n[tr\
	      ThisVersionIs] $chessdbVersion [tr WhichWasRelasedOn]\
	      $chessdbVersionDate \n\n[tr FreeUpgradeAt]"
	    return
	}
    }
    if {$patchlevel < $Latestpatch  && $minorVersion == $Latestminor && $majorVersion == $Latestmajor  } {
	if {$StableOrBeta != 0  } {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableThereIsLaterBeta]\n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease\n\n[tr\
	      VersionOfLatestBeta] $LatestchessdbVersion [tr DateOfRelease]\
	      $DateOfLastBeta \n\n[tr ThisVersionIs] $chessdbVersion\
	      [tr WhichWasRelasedOn] $chessdbVersionDate \n\n[tr FreeUpgradeAt]"
	    return
	} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr NotUsingLatestStableButNoLaterBeta] \n\n[tr\
	      VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease \n\n[tr\
	      ThisVersionIs] $chessdbVersion [tr WhichWasRelasedOn]\
	      $chessdbVersionDate \n\n[tr FreeUpgradeAt]"
	    return
	}
}
	if {$betalevel < $LatestBetaNumber && $patchlevel == $Latestpatch  && $minorVersion == $Latestminor && $majorVersion == $Latestmajor} {
	    tk_messageBox -type ok -icon warning -title\
	      [tr HelpTitleUpdatesMessage] -message "[tr BetaButNotLatestBeta]\
	      \n\n[tr VersionOfLatestBeta] $LatestchessdbVersion\
	      [tr DateOfRelease] $DateOfLastBeta  \n\n[tr ThisVersionIs]\
	      $chessdbVersion [tr WhichWasRelasedOn] $chessdbVersionDate\
	      \n\n[tr VersionOfLatestStable] $LatestStablechessdbVersion\
	      [tr DateOfRelease] $DateOfLastStableRelease \n\n[tr\
	      FreeUpgradeAt] "
	    return
	}

	if {$majorVersion == $Latestmajor && $minorVersion == $Latestminor &&\
	  $patchlevel == $Latestpatch && $LatestBetaNumber == 0} {
	    tk_messageBox -type ok -icon info -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr UsingLatestStableNoLaterBeta] $chessdbVersion\
	      [tr WhichWasRelasedOn] $chessdbVersionDate"
	    return
	}

	if {$majorVersion == $Latestmajor && $minorVersion == $Latestminor &&\
	  $patchlevel == $Latestpatch && $LatestBetaNumber == $betalevel && $betalevel != 0} {
	    tk_messageBox -type ok -icon info -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr HelpUpdateStatusCurrent] $LatestchessdbVersion [tr ButNoteNotStable] \n\n[tr VersionOfLatestStable] $LatestStablechessdbVersion [tr WhichWasRelasedOn] $DateOfLastStableRelease \n\n[tr FreeUpgradeAt]\n\n"
	    return
	}

	if {$majorVersion == $Latestmajor && $minorVersion == $Latestminor &&\
	  $patchlevel == $Latestpatch && $LatestBetaNumber == $betalevel} {
	    tk_messageBox -type ok -icon info -title\
	      [tr HelpTitleUpdatesMessage] -message\
	      "[tr HelpUpdateStatusCurrent] $LatestchessdbVersion"
	    return
	}

	tk_messageBox -type ok -icon info -title [tr HelpTitleUpdatesMessage]\
	  -message "[tr HelpUpdateStatusTooNew1]$chessdbVersion\
	  [tr HelpUpdateStatusTooNew2] $LatestchessdbVersion"
    }


    # this proc contributed by [Donal Fellows]
    # This is where I am having so real problems. Working out how on earth to\
      have\
  sensible 
    # error handlers. 
    proc geturl_followRedirects {url args} {
	while {1} {
	    set token [eval [list http::geturl $url] $args]
	    switch -glob [http::ncode $token] {
	    30[1237] {
		    ### redirect - see below ### 
		}
	    default {
		    return $token
		}
	    }
	    upvar #0 $token state
	    array set meta [set ${token}(meta)]
	    if {![info exist meta(Location)]} {
		return $token
	    }
	    set url $meta(Location)
	    unset meta
	}
    }


    # I suspect this ::http::cleanup $token is in the wrong place and should be\
  placed elsewhere. 
    # ::http::cleanup $token

