# Copyright (C) Dr. David Kirkby 2006-2007 
# ChessDB http://chessdb.sourceforge.net/

# ChessDB is a Chess Database based on one called 'Scid'

# To avoid any confusion, this program is called ChessDB rather than 
# Scid. It uses a lot of Scid code
# http://scid.sourceforge.net/, but I don't want Shane Hudson, 
# (the author of Scid) to be responsible for any bugs in ChessDB. 

# This file is used when downloading PGN files from The Week In Chess 
# (TWIC) web site.
# This is new code and adds new functionaltiy that was not in Scid



# proc maximumTWICnumber  determines the largest issue of TWIC's 
# PGN files likely to be downloadable. It is not 100% perfect, 
# but should if anything try to download one later than the latest 
# and so never fail to get the latest 

proc ::tools::maximumTWICnumber {{when today}} {
    set time [clock scan $when]
    set year [clock format $time -format %Y]
    # might want %W instead of %U; see the [clock] man page
    set week [scan [clock format $time -format %U] %d]
    set maxweek [expr {(($year * 52) + $week) - 103730}]
    return $maxweek
}


# proc ::tools::twic::download  needs to be able to read the values
# of the radio buttons, checkbuttons and entry widgets from  ::tools::twic
proc ::tools::twic::download {} {
    variable loadintocurrentDB
    variable importDB
    variable autofirst
    variable autolast
    variable FirstIssue
    variable LastIssue
    variable createLargePGN
    # disable the download button, so the user can't start it twice. 
    .twicWin.b.download configure -state disabled
    set newbasename "newgames"


    # If the user wants to create neither the database of the PGN file, then
    # he is wanting nothing to do. We must re-enable the 'Download' button, 
    # which was not done in the first public release 3.6.12-beta-1
    if {$createLargePGN == 0 && $importDB == 0} {
	tk_messageBox -type ok -icon error   -title "ChessDB:" -message [tr DoNothingAtAll ]
        .twicWin.b.download configure -state normal  
	return
    }
    if {  $importDB ==  1 && [sc_base isReadOnly]  == 1} {
	tk_messageBox -type ok -icon error -title "ChessDB:" -message [tr CurrentDatabaseReadOnly ]
        .twicWin.b.download configure -state normal  
         return
    }
    if { $importDB ==  1 && [sc_base inUse ]  == 0 } {
	tk_messageBox -type ok -icon error -title "ChessDB:" -message [tr NotOpenDatabase ]
        .twicWin.b.download configure -state normal  
         return
    }
    set n [ sc_base numGames]
    if { $n > 0 &&  $importDB ==  1 } { 
	set answer [ tk_messageBox -type okcancel -icon warning -title [tr WarningCurrentDBNotEmpty] -message "[tr WarningCurrentDatabaseHasGames1 ] $n [tr WarningCurrentDatabaseHasGames2] \n\n[tr WarningCurrentDatabaseHasGames3 ]" ]
switch -- $answer {
    ok {}
    cancel {.twicWin.b.download configure -state normal ; return}
    }
}


    # If use user wants to determine the last file to download automatically
    # Then a huge number is chosen which will be good to about the year 2187 
    # by which time I think the software will be out of date!
    if {$autolast == 1} {
	set LastIssue 9999
    }

    # Make some estimes of the likly last issue
    set ApproximateLastIssue [::tools::maximumTWICnumber]

    # And use that +5 to be totally obsurd. Anthing >= $BeyondMaximumLikelyValue
    # will be considered an error
    set BeyondMaximumLikelyValue [expr {$ApproximateLastIssue + 5}]
    set LikelyUpperValue [expr {$ApproximateLastIssue + 2}]
    set LikelyLowerValue [expr {$ApproximateLastIssue - 2}]

    # If the user want to find the first file automatically, then 
    # a file 'start-from.txt' must be opened. The existance of this file
    # will have already been checked in ::tools::twic, so there is 
    # no need to check for it. It can be assumed to exist. 

    # However, it was once of 0 bytes, which is a problem. 
    # Hence I should check that. It should be 3 to 5 bytes bytes long. 
    set chessdbTWICDir [ file nativename $::chessdbTWICDir]
    set lastdownload [file join $::chessdbTWICDir "start-from.txt"]
    set lastdownload [file nativename $lastdownload]
    
    if {$autofirst == 1} {
	set fp [open $lastdownload r]
	set data [read $fp]
	set len [string length $data]
	if {$len < 6 && $len > 2} {
	    set FirstIssue [format %d $data]
	    close $fp
            if { $FirstIssue >= $BeyondMaximumLikelyValue } { 
	    tk_messageBox -type ok -icon warning -title [tr FileCorruption] -message "[tr FirstIssueInFileTooLarge1] \"$lastdownload\" [tr FirstIssueInFileTooLarge2 ] $FirstIssue [tr FirstIssueInFileTooLarge3]\n\n[tr ReportPossibleInternalError]"
            .twicWin.b.download configure -state normal
             return
             }
            
            .twicWin.b.download configure -state disabled
	} {
	    tk_messageBox -type ok -icon error  -title "[tr FileCorruption]"\
	      -message "[tr TheLengthOfFileIsNotCorrect] \"$lastdownload\" [tr ReportPossibleInternalError]"
            .twicWin.b.download configure -state normal
	    return
	}
    }
    if {$autofirst == 0 || $autolast == 0} {
	set lenLast [string length $LastIssue]
	set lenFirst [string length $FirstIssue]
	if {$lenLast == 0 || $lenFirst == 0} {
	    tk_messageBox -type ok -icon error   -title "ChessDB:"\
	      -message "[tr IfUsingManualYouMustEnterValue]\
	      $ApproximateLastIssue"
            .twicWin.b.download configure -state normal
	    return
	}
    }
    # Check if the user wants a first issue which is most unlikely to exist. 
    # we should exit. 
    if { $autofirst == 0} {
        if { $FirstIssue >=  $BeyondMaximumLikelyValue } { 
	   tk_messageBox -type ok -icon warning -title [tr TitleUnliklyLastIssue ] -message "[tr UnliklyFirstIssue1] $ApproximateLastIssue [tr UnliklyFirstIssue2] $BeyondMaximumLikelyValue [tr UnliklyFirstIssue3] $FirstIssue [tr UnliklyIssue] \n\n[tr IfyouBeliveAnError]"
            .twicWin.b.download configure -state normal
	    return
        }
     }
        


    # Check if the user wants a last issue which is most unlikely to exist. 
    # we should exit. 
    if { $autolast == 0} {
        if { $LastIssue >=  $BeyondMaximumLikelyValue } { 
	   tk_messageBox -type ok -icon warning -title [tr TitleUnliklyLastIssue ] -message "[tr UnliklyLastIssue1] $ApproximateLastIssue \n\n[tr UnliklyLastIssue2] $BeyondMaximumLikelyValue [tr UnliklyLastIssue3] [tr UnliklyLastIssue4] $LastIssue [tr UnliklyIssue] \n\n[tr IfyouBeliveAnError]"
            .twicWin.b.download configure -state normal
	    return
        }
     }
        

    # Check the user has not manually entered a number < 210, which
    # is the minimum on the TWIC web site. 

    if {$autofirst == 0 && $FirstIssue < 210} {
	tk_messageBox -type ok -icon error    -title "ChessDB:" -message\
	  "[tr NotBelow210]"
        .twicWin.b.download configure -state normal  
	return
    }
 
    # Chech that 'last-file.txt' does not contain a number of < 210)
    if {$autofirst == 1 && $FirstIssue < 210} {
	tk_messageBox -type ok -icon error   -title "ChessDB:" -message\
	  "[tr NotBelow210] [tr butLastFileIndicates] [tr ReportPossibleInternalError ] "
        .twicWin.b.download configure -state normal  
	return
    }
    # Check that the FirstIssue <= LastIssue
    if {$FirstIssue > $LastIssue} {
	tk_messageBox -type ok -icon error   -title "[tr UserError]"\
	  -message "[tr FirstIssueGreaterLastIssue]"
        .twicWin.b.download configure -state normal  
	return
    }

    # check we have write access to this directory - otherwise give up now.

    set randomfile [file join $::chessdbTWICDir "dukerjh3232"]
    set a [file writable $randomfile]

    if {[catch {open $randomfile "w"} fid]} {
	tk_messageBox -type ok -icon error   -title [tr TitleCanNotOpenFile]\
	  -message "[tr CanNotWriteToDirectory]  $::chessdbTWICDir\
	  [tr CanNotWriteFile2]"
	close $fid
        .twicWin.b.download configure -state normal  
	return
    }
    close $fid
    file delete $randomfile


    .twicWin.tf.txt edit reset
    .twicWin.tf.txt delete 1.0 end
    .twicWin.tf.txt tag configure h1 -font "helvetica 16" -underline on
    .twicWin.tf.txt insert 1.0 " [tr ActionsToBePerformed] \n\n" h1
    # .twicWin.tf.txt insert end "[tr FilesFromTWICPlaced] $::chessdbTWICDir \n\n"
    update idletasks
    if {$::utils::download::useProxy} {
       .twicWin.tf.txt insert end "ProxyHost: $::utils::download::proxyHost \
        ProxyPort: $::utils::download::proxyPort\n\n" }
    set pgn .pgn
    set newgames $newbasename$pgn

    set NEWGAMES [file nativename [file join $::chessdbTWICDir $newgames]]

    if {$createLargePGN == 1} {
       .twicWin.tf.txt insert end "[tr NewPGNWillBeCreated] \n$NEWGAMES\n\n"
    }
    if {$importDB == 1} {
       .twicWin.tf.txt insert end [tr GamesWillBeReadToCurrent]
    }

    # check we execute 'unzip'

    if {[catch {exec unzip} fid]} {
	tk_messageBox -type ok -icon error   -title [tr TitleNeedUnzip]\
	  -message [tr NeedUnzip]
        .twicWin.b.download configure -state normal  
	return
    }
    .twicWin.tf.txt insert end " \n\n[tr DownloadLog] \n\n" h1
    file delete $NEWGAMES 

    # LOOP STARTS HERE 
    # LOOP STARTS HERE 
    # LOOP STARTS HERE 
    # LOOP STARTS HERE 
    # LOOP STARTS HERE 
    for {set issue $FirstIssue} {$issue <= $LastIssue} {incr issue 1} {

	#  ZIPFILE is the full path =\
	  /export/home/drkirkby/.chessdb/twic/twic643g.zip
	#  zipfile is just the file name twic643g.zip     
	set zipfile [format twic%dg.zip $issue]
	set ZIPFILE [file nativename [file join $::chessdbTWICDir $zipfile]]

	set pgnfile [format twic%d.pgn $issue]
	set PGNFILE [file nativename [file join $::chessdbTWICDir $pgnfile]]

	# set url [format http://www.althorne.org/twic/zips/twic%dg.zip $issue]
	set url [format http://www.chesscenter.com/twic/zips/twic%dg.zip $issue]

	if {[winfo exists .twicWin.tf.txt]} {
	    .twicWin.tf.txt insert end "$url \n"
	} {
	    return
	}

	set token [httpcopy $url [file join $::chessdbTWICDir $zipfile]]
	set status [http::status $token]
	set code [http::code $token]
	# puts "status = $status"
	# puts "code = $code  "
	# Check the result code from the web server. If this is not
	# 200, then there is a problem and we should 
	# break out of the loop, delete the zip file (since it has a problem)
	# and set the file 'start-from.txt' so it starts from that next time. 
	set ind [string first 200 $code]
	if {$ind == -1} {
	    if {[winfo exists .twicWin.tf.txt]} {
		.twicWin.tf.txt insert end $url
	    } {
		return
	    }
	    set resultfp [open $lastdownload "w"]
 	    puts $resultfp $issue
	    .twicWin.tf.txt insert end "\n\n$code \n\n[ tr WebServerNotOK] $url \n"
	    close $resultfp
	    file delete [file join $::chessdbTWICDir $zipfile]
            # If the problem arrose on the first issue, 
            # then no changes will have been made. 
            # Otherwise, break out out the loop and tell
            # user about the database and/or PGN created.
            # puts "$FirstIssue  $issue "

            if { $FirstIssue == $issue && $autofirst == 0 } {
	       tk_messageBox -type ok -icon warning -title [tr NofilesRetrieved ] -message "$code \n\n[ tr NoChangesMade]"
             .twicWin.b.download configure -state normal  
               return
            } 
            if { $FirstIssue == $issue && $autolast == 0 } {
	       tk_messageBox -type ok -icon warning -title [tr NofilesRetrieved ] -message "$code \n\n[ tr NoChangesMade]"
             .twicWin.b.download configure -state normal  
               return
            } 
            if { $FirstIssue == $issue && $autofirst == 1 } {
	       tk_messageBox -type ok -icon warning -title [tr NofilesRetrieved ] -message "$code \n\n[tr NoNewTWICIssueFound]\n\n[tr TriedButFailed] $issue"
               .twicWin.b.download configure -state normal
               return
            }
            if { $issue > $FirstIssue && $issue < $LastIssue && $autolast == 0} {
	       tk_messageBox -type ok -icon warning -title [tr TitlePartiallyCompleteDownload] -message "$code \n\n[ tr SomeFileButNotAll] \n\n[tr FailureOccuredAt] $issue"
               .twicWin.b.download configure -state normal  
               break
            }
            if { $issue > $FirstIssue && $issue < $LastIssue && $autolast == 1} {
               set n [expr {$issue - $FirstIssue}]
                if { $n == 1 && $issue  >= $LikelyLowerValue} {
	           tk_messageBox -type ok -icon info -title "ChessDB" -message "[tr OneTWICIssueDownloaded ] $FirstIssue) \n\n[tr BasedOnTheDate] $ApproximateLastIssue [tr soThisIsConsistant] \n\n[tr NewPGNandCurrent] $chessdbTWICDir"
                }
                if { $n > 1 && $issue >= $LikelyLowerValue } {
	           tk_messageBox -type ok -icon info -title "ChessDB" -message "$n [tr TWICIssuesDownloaded ] $FirstIssue - [expr $issue - 1]) \n\n[tr BasedOnTheDate] $ApproximateLastIssue, [tr soThisIsConsistant]  \n\n[tr NewPGNandCurrent] $chessdbTWICDir"
                }
                if { $n == 1 && $issue  < $LikelyLowerValue} {
	           tk_messageBox -type ok -icon warning -title "ChessDB" -message "[tr OneTWICIssueDownloaded ] $FirstIssue) \n\n[tr BasedOnTheDate] $ApproximateLastIssue [tr soThisInNotConsistant]  \n\n[tr NewPGNandCurrent] $chessdbTWICDir"
                }
                if { $n > 1 && $issue < $LikelyLowerValue } {
	           tk_messageBox -type ok -icon warning -title "ChessDB" -message "$n [tr TWICIssuesDownloaded ] $FirstIssue - [expr $issue - 1]) \n\n[tr BasedOnTheDate] $ApproximateLastIssue. [tr soThisInNotConsistant]  \n\n[tr NewPGNandCurrent] $chessdbTWICDir"
                }
               .twicWin.b.download configure -state normal  
               break
            }
	}
	set ZIPFILESIZE [file size $ZIPFILE]
	if {[winfo exists .twicWin.tf.txt]} {
	    .twicWin.tf.txt insert end "$ZIPFILE ( $ZIPFILESIZE b )\n"
	} {
	    return
	}

	if {$ZIPFILESIZE < 5000} {
	    tk_messageBox -type ok -icon error -title [tr TitleZipfileTooShort ] -message [ tr ZipfileTooShort] 
             .twicWin.b.download configure -state normal  
	    return
	}
	catch {exec unzip -o -d $::chessdbTWICDir $ZIPFILE}
        file delete $ZIPFILE

	# Weeks  300, 301, 304 and 307 are a bit odd, in that the pgn file is\
	  in a sub directory, whereas most of the zip files on the TWIC web\
	  site  have the files in the root directory. 
	if {$issue == 300 || $issue == 301 || $issue == 304 || $issue == 307} {
	    set zipdir [format twic%d $issue]
	    set pgnfile [format twic%d.pgn $issue]
	    set pgnfileodd [file join $::chessdbTWICDir $zipdir games $pgnfile]
	    file copy $pgnfileodd $::chessdbTWICDir
	    file delete -force [file join $::chessdbTWICDir $zipdir]
	}
	set PGNFILESIZE [file size $PGNFILE]
	if {[winfo exists .twicWin.tf.txt]} {
	    .twicWin.tf.txt insert end "$PGNFILE ( $PGNFILESIZE b )\n\n"
	} {
	    return
	}
	update idletasks
	set ISSUE [file join $::chessdbTWICDir [format twic%d $issue]]
	# puts $TMPBASE 

	set resultfp [open $lastdownload "w"]
 	puts $resultfp [expr {$issue + 1}]
	close $resultfp
        
        
        if {$importDB == 1} {
           sc_base import file $PGNFILE
           updateStatusBar
           updateTitle
           updateMenuStates
           ::windows::switcher::Refresh
           ::maint::Refresh
           update
        }
	if {$createLargePGN == 1} {
	    fappend $PGNFILE $NEWGAMES
	}
        file delete $PGNFILE

    }
    # Give the user a nice message 
    # if he used auto and it seems to have gone
    # well, but on the last issue 
    # retrieved being as expected 

    set ind2 [string first 404 $code]
    if {$issue <= $LikelyUpperValue && $issue >= $LikelyLowerValue && $ind == 0 && $autolast == 1 && $ind2 == 0} {
	tk_messageBox -type ok -icon infor -title "ChessDB:" -message "OK" 
    }
    # If we have got from the loop upto  $LastIssue then
    # then next time we will need to start from $LastIssue 

    if {$createLargePGN == 1} {
	set NEWGAMESSIZE [file size $NEWGAMES]
	if {[winfo exists .twicWin.tf.txt]} {
	    .twicWin.tf.txt insert end "[tr NewPGNCreated ]\n"
             set NEWGAMES [file nativename $NEWGAMES  ]
	    .twicWin.tf.txt insert end "$NEWGAMES ( $NEWGAMESSIZE b )\n\n"
	    .twicWin.tf.txt insert end "[tr ShouldYouChose] [expr {$issue}]\n"
	} {
            # Not sure why we might be here, but I guess I did 
            # check the window existed for a reason. 
	    return
	}
    }

    update idletasks

    if {$importDB == 1} {
      if {[winfo exists .twicWin.tf.txt]} {
         if {$createLargePGN == 0} {
	    .twicWin.tf.txt insert end "[tr ShouldYouChose] [expr {$issue}]\n"
         }
      } {
         # Not sure why we might be here, but I guess I did 
         # check the window existed for a reason. 
	return
      }
    }

}

