###
### importdir.tcl: part of ChessDB.
### Copyright (C) 2007  Dr. David Kirkby
###

# Imports all the PGN files from one directory, which is much faster than
# importing them individually if there are a lot, and much easier than
# doing it at the shell using cat (UNIX) or copy (Windows).
# This code is new, and is not used at all in Scid


proc importDirectoryOfPGNFile {} {
  set ::stopnow 0
    global importPgnErrors

    set err ""
    if {[sc_base isReadOnly]} {
	set err [tr CurrentDatabaseReadOnly]
    }
    if {![sc_base inUse]} {
	set err [tr NotOpenDatabase]
    }
    if {$err != ""} {
	tk_messageBox -type ok -icon error -title [tr TitleChessDBError]\
	  -message $err
	return
    }
    set dirname [tk_chooseDirectory -title [tr ChooseDirectoryWithPGN]\
      -mustexist 1]
    set dirname [file nativename $dirname]
    if {$::windowsOS} {
       set files [glob -nocomplain -types f -directory $dirname *.PGN]
    } { 
       set files [glob -nocomplain -types f -directory $dirname *.pgn *.PGN]
    }
    set numfiles [llength $files]
    if {$numfiles == 0} {
	tk_messageBox -type ok -icon error -title [tr TitleNoPGNFileInDir]\
	  -message "[tr NoPGNFileInDir]: $dirname"
    } {
	set n [sc_base numGames]
	if {$n == 0} {
	    set answer [tk_messageBox -type okcancel -icon info -title\
	      [tr TitleImportingPGNFiles] -message "[tr ImportingNumber]\
	      $numfiles [tr PGNFilesFromDir] $dirname"]
	    switch -- $answer {
	    ok { }
	    cancel {
		    return
		}
	    }
	} {
	    set answer [tk_messageBox -type okcancel -icon warning -title\
	      [tr TitleImportingPGNFiles] -message "[tr ImportingNumber]\
	      $numfiles [tr PGNFilesFromDir] $dirname\n\n[tr\
	      WarningCurrentDatabaseHasGames1] $n\
	      [tr WarningCurrentDatabaseHasGames4]\n\n[tr\
	      WarningCurrentDatabaseHasGames5]\n\n[tr\
	      WarningCurrentDatabaseHasGames6]"]
	    switch -- $answer {
	    ok { }
	    cancel {
		    return
		}
	    }
	}
    }
    doMultiplePgnFileImport $files $dirname
}

proc doMultiplePgnFileImport {filelist dirname} {
  set w .ipgnWin
  if {[winfo exists $w]} { destroy $w }
  toplevel $w
  # Find the number of files that need to be imported
  set numfiles [llength $filelist]
  wm title $w "Importing $numfiles PGN files from $dirname"
  canvas $w.progress -width 400 -height 20 -bg white -relief solid -border 1
  $w.progress create rectangle 0 0 0 0 -fill orange -outline blue -tags bar
  $w.progress create text 395 10 -anchor e -font font_Regular -tags time -fill black -text "0:00 / 0:00" 

  # canvas $w.progress2 -width 400 -height 20 -bg white -relief solid -border 1
  # $w.progress2 create rectangle 0 0 0 0 -fill red -outline blue -tags bar
  # $w.progress2 create text 395 10 -anchor e -font font_Regular -tags time -fill black -text "0:00 / 0:00"

  pack $w.progress -side bottom
  #pack $w.progress2 -side bottom

  frame $w.buttons
  pack $w.buttons -side bottom -fill x
  button $w.buttons.stop -textvar ::tr(Stop) -command {set ::stopnow 1 ; sc_progressBar}
  button $w.buttons.close -textvar ::tr(Close) -command "focus .; destroy $w"
  pack $w.buttons.close $w.buttons.stop -side right -ipadx 5 -padx 5 -pady 2

  pack [frame $w.tf] -side top -expand yes -fill both
  text $w.text -height 8 -width 60 -background gray90 \
    -wrap word -setgrid 1 -yscrollcommand "$w.ybar set"
  #  -wrap none -cursor watch -setgrid 1 -yscrollcommand "$w.ybar set"
  scrollbar $w.ybar -command "$w.text yview"
  pack $w.ybar -in $w.tf -side right -fill y
  pack $w.text -in $w.tf -side left -fill both -expand yes
  update


  # busyCursor .
  sc_progressBar $w.progress bar 401 21 time
  catch {grab $w.buttons.stop}
  bind $w <Escape> "$w.buttons.stop invoke"
  $w.buttons.close configure -state disabled
  # $w.text insert end "[tr ImportingPGNgamesFrom] [file tail $fname]...\n\n"
  $w.text configure -state disabled

  set importPgnErrors ""
  set err ""
  set warnings ""
  $w.text configure -state normal
  $w.text configure -cursor top_left_arrow
  $w.text tag configure bold -justify "left" -underline on
  set ngames 0
  set totalwarnings 0
  set i 0
  while {$i < $numfiles && $::stopnow == 0 } {
        sc_progressBar $w.progress bar 401 21 time
	set fname [lindex $filelist $i]
        set fname [file nativename $fname]
        $w.text insert end "[tr StartingToImportFilename ] $fname\n"
        set tmperr [catch {sc_base import file $fname} result]
        set nImported [lindex $result 0]
        set ngames [expr {$ngames + $nImported}]
        set warnings [lindex $result 1]
        set numwarnings [llength $warnings]
        set totalwarnings [expr {$totalwarnings + $numwarnings}]
        append err $warnings
        $w.text insert end "[tr ImportedFile] [expr {$i+1}] [tr of] $numfiles [tr filesWith] $nImported [tr games]. $ngames [tr gamesImportedNow]\n"
        $w.text insert end "$warnings" bold
	# sc_base import file $filename
   updateTitle
   updateMenuStates
  ::windows::switcher::Refresh
  ::maint::Refresh
	updateStatusBar
	update
        incr i
 }
    if {$err == ""} {
        $w.text insert end "\n\n[tr ThereWereNoWarnings]"
    } { 
        $w.text insert end "\n\n****************************************\n[tr ThereWereWarnings]\n****************************************"

    }
  $w.text configure -state disabled
  $w.buttons.close configure -state normal
  $w.buttons.stop configure -state disabled
  catch {grab release $w.buttons.stop}
  bind $w <Escape> "$w.buttons.close invoke; break"
  # unbusyCursor .
  # unbusyCursor $w
  # Auto-close import progress window if there were no errors/warnings?
  if {$err == ""  &&  $warnings == ""} { destroy $w }
  updateTitle
  updateMenuStates
  ::windows::switcher::Refresh
  ::maint::Refresh
  update
}
###
### End of file: importdir.tcl
###

