# Copyright(C) Dr. David Kirkby 2006-2007
# Download from TWIC  manager window: closed by default

package require Tcl 8.4
package require Tk 8.4
package require http 2.3

# maximum of milliseconds to wait for the page
set timeout 10000

set headers(Accept) "text/html\;q=0.9,text/plain\;q=0.8,image/png,*/*"
set headers(Accept-Language) "en-us,en\;q=0.5"
set headers(Accept-Charset) "ISO-8859-1,utf-8\;q=0.7,*\;q=0.7"
if {$::utils::download::useProxy} {
   ::http::config -useragent "ChessDB http://chessdb.sourceforge.net/" -proxyhost $::utils::download::proxyHost -proxyport $::utils::download::proxyPort
} else {
   ::http::config -useragent "ChessDB http://chessdb.sourceforge.net/"
}
set twicWin 0

proc ::tools::closewindow {} {
    destroy .twicWin
    set twicWin 0
    return
}

# ::tools::twic
#
#   Opens the TWIC window, for retrieving games from TWIC
#
proc ::tools::twic {} {
    set w .twicWin
    if {[winfo exists $w]} {
	#    ::tools::closewindow 
	destroy .twicWin
	set twicWin 0
	return
    }
    set twicWin 1
    toplevel $w
    wm title $w [tr TitleDownloadFromTWIC]
    wm minsize $w 25 10

    bind $w <F1> {helpWindow TWIC}

    # Frame 0 (menu bar)
    set f0 [frame $w.f0  -borderwidth 2 ]
    # menubutton $f0.file  -text [tr File] -menu $f0.file.menu -underline 0
    menubutton $f0.help  -text [tr Help] -menu $f0.help.menu -underline 0
    pack $f0  -fill x
    # pack $f0.file $f0.help -side left -fill x
    pack $f0.help -side left -fill x
    menu $f0.help.menu -tearoff 0
    # menu $f0.file.menu -tearoff 0
    $f0.help.menu add command -label [ tr MainHelpIndex ] -underline 0 -command {helpWindow Index}
    $f0.help.menu add command -label "[ tr Contents ]" -underline 0 -command {helpWindow Contents}
    $f0.help.menu add command -label "[tr HelpOnDownloadingChessServer ] TWIC" -underline 0 -command  {helpWindow TWIC}




    # Frame 1
    set tf [frame $w.tf]
    set txt [text $tf.txt -wrap word -height 10 -width 40 -bg black -fg orange]
    set yscroll [scrollbar $tf.yscroll -orient vertical -command [list $txt\
      yview]]
    $txt configure -yscrollcommand [list $yscroll set]
    grid $txt -sticky news
    grid $yscroll -column 1 -row 0 -sticky ns
    grid rowconfigure $tf 0 -weight 1
    grid columnconfigure $tf 0 -weight 1

    $tf.txt tag configure h1 -font "helvetica 16" -underline on

    $tf.txt tag configure h2 -font "helvetica 13" -justify "left" -underline on

    $tf.txt tag configure normal -font "helvetica 10" -justify "left"\
      -underline off

    pack $tf -fill both -expand 1      

    # Frame 2
    set cbf [frame $w.cbf -borderwidth 10]
    checkbutton $cbf.createBigPGN -text [tr CreateLargePGNofGames ] -variable ::tools::twic::createLargePGN
    checkbutton $cbf.importDB -text [tr ImportToCurrentDatabase] -variable ::tools::twic::importDB

    grid $cbf.createBigPGN -sticky w -row 0 -column 0
    grid $cbf.importDB -sticky w     -row 0 -column 1 

    pack $cbf -anchor w

    # Frame 3
    set minimumIssue [frame $w.minimumIssue -borderwidth 10]

    entry $w.minimumIssue.data -width 4\
      -textvariable ::tools::twic::FirstIssue -validate key\
      -validatecommand {string is integer %P}


    set startfrom  [file join $::chessdbTWICDir "start-from.txt"]
    set startfrom  [file nativename $startfrom ]

    radiobutton $minimumIssue.auto -text\
      [tr AutomaticallySetFirstIssue ]\
      -variable ::tools::twic::autofirst -value 1 -command\
      "$minimumIssue.data configure -state disabled"


    radiobutton $minimumIssue.manual -text [tr ManuallySetFirstIssue ]\
      -variable ::tools::twic::autofirst -value 0\
      -command "$minimumIssue.data configure -state normal"



    # Frame 4
    set maximumIssue [frame $w.maximumIssue -borderwidth 10]
    radiobutton $maximumIssue.auto -text "[tr DownloadToLastCopyOnTWICWebSite]\
      " -variable ::tools::twic::autolast -value 1\
      -command "$maximumIssue.data configure -state disabled"
    radiobutton $maximumIssue.manual -text [tr ManuallySetLastIssue   ] -variable ::tools::twic::autolast -value 0\
      -command "$maximumIssue.data configure -state normal ; $maximumIssue.data delete 0 1000"
    entry $maximumIssue.data -width 4 -textvariable ::tools::twic::LastIssue\
      -validate key -validatecommand {string is integer %P}

    $maximumIssue.data configure -state disabled
    $maximumIssue.auto select

    grid $maximumIssue.auto -row 0 -column 0 -sticky w
    grid $maximumIssue.manual -row 1 -column 0 -sticky w
    grid $maximumIssue.data -row 1 -column 1 -sticky w

    grid $minimumIssue.auto -row 0 -column 0 -sticky w
    grid $minimumIssue.manual -row 1 -column 0 -sticky w
    grid $minimumIssue.data -row 1 -column 1 -sticky w

    pack $minimumIssue -anchor w
    pack $maximumIssue -anchor w
    pack $tf

    # Frame 5 (Close and Download buttons)
    frame $w.b -borderwidth 2
    set b .twicWin.b


    button $b.close -text "[tr Close]" -command {destroy .twicWin}
    button .twicWin.b.download -text [tr Download] -command {::tools::twic::download }
    pack $b.close -anchor e  -side right
    pack $b.download -anchor e -side right
    pack $b -anchor e -side right

    bind $w <Destroy> {set twicWin 0}

    # Try to read a file 'start-from.txt'. It it exists, 
    # then we can set up an automatic start. 
    # If not, lets indicate this if its clicked. 

    if {! [catch {open $startfrom "r"} fid]} {
	# set fid [open $startfrom r]
	set data [read $fid]
	close $fid
	$minimumIssue.auto configure -state normal
	$minimumIssue.data configure -state disabled
	$minimumIssue.auto select
    } {
	$minimumIssue.auto configure -state disabled
	$minimumIssue.manual configure -state normal
	$minimumIssue.manual select
	$minimumIssue.data configure -state normal
    }
}

