### download.tcl
### Functions for setting download settings and network proxy.
### Part of ChessDB. Copyright (C) Dr. David Kirkby 2006-2007.
###                  Copyright (C) Warren Lewis 2007.
### Added help page, Dave Kirkby, 2007-02-10

namespace eval ::utils::download {}

#set ::utils::download::useProxy 0

# ::utils::downloads::OptionsDialog
#
#   Dialog window for configuring Download and Proxy network settings
#   and logging into chess server to download games. 
#
proc ::utils::download::OptionsDialog {} {
  set w .downloadOptions

  # Create temp  user-settable download and network variables:
  foreach v {proxyHost proxyPort ICC_server ICC_user ICC_pass ICC_port ICC_savepass 
             FICS_server FICS_user FICS_pass FICS_port FICS_savepass} {
    set ::utils::download::${v}_temp [ set ::utils::download::$v ]
  }

  toplevel $w
  wm title $w [ tr DownloadOptions ]
  wm transient $w .

  bind $w <F1> {helpWindow DownloadOptions}
  pack [frame $w.b] -side bottom -fill x -pady 2
  pack [frame $w.f1 -relief groove -borderwidth 2] \
    -side top -fill x -padx 5 -pady 5 -ipadx 4 -ipady 4
  pack [frame $w.f2 -relief groove -borderwidth 2] \
    -side top -fill x -padx 5 -pady 5 -ipadx 4 -ipady 4
  pack [frame $w.f3 -relief groove -borderwidth 2] \
    -side top -fill x -padx 5 -pady 5 -ipadx 4 -ipady 4

  set f1 $w.f1
  set f2 $w.f2
  set f3 $w.f3
  set r 0

  # Configure the HTTP proxy server - there is no support for use of proxy servers to 
  # access the chess servers, as the Tcl telnet client used does not support proxy servers. 

  label $f1.proxyHostLabel -text "${::tr(ProxyHost)}:"
  grid $f1.proxyHostLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f1.proxyEntry -width 40 -textvariable ::utils::download::proxyHost_temp
  grid $f1.proxyEntry -row $r -column 2

  incr r

  label $f1.proxyPortLabel -text "${::tr(ProxyPort)}:"
  grid $f1.proxyPortLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f1.proxyPortEntry -width 10 -textvariable ::utils::download::proxyPort_temp -validate key -validatecommand {string is integer %P}

  grid $f1.proxyPortEntry -row $r -column 2 -sticky w

  
  # Configure account on The Internet Chess Club (ICC) server. 
  # Normally the host will be 'chessclub.com' and the port 5000, but 
  # either can be changed. 

  set r 0

  label $f2.iccHostLabel -text "${::tr(ICCserver)}:"
  grid $f2.iccHostLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f2.iccHostEntry -width 40 -textvariable ::utils::download::ICC_server_temp
  grid $f2.iccHostEntry -row $r -column 2 -sticky w

  incr r

  label $f2.iccUserLabel -text "${::tr(ICCuser)}:"
  grid $f2.iccUserLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f2.iccUserEntry -width 20 -textvariable ::utils::download::ICC_user_temp
  grid $f2.iccUserEntry -row $r -column 2 -sticky w

  incr r

  label $f2.iccPassLabel -text "${::tr(ICCpass)}:"
  grid $f2.iccPassLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f2.iccPassEntry -width 20 -show * -textvariable ::utils::download::ICC_pass_temp
  grid $f2.iccPassEntry -row $r -column 2 -sticky w

  incr r

  label $f2.iccPortLabel -text "${::tr(Port)}:"
  grid $f2.iccPortLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f2.iccPortEntry -width 10 -textvariable ::utils::download::ICC_port_temp -validate key -validatecommand {string is integer %P}
  grid $f2.iccPortEntry -row $r -column 2 -sticky w 

  incr r

  label $f2.iccSavePasswordLabel -text "${::tr(SavePassword)}:"
  grid $f2.iccSavePasswordLabel -row $r -column 0 -columnspan 2 -sticky we
  checkbutton $f2.iccSavePasswordEntry -variable ::utils::download::ICC_savepass_temp -text  [ tr NotEncrypted]
  grid $f2.iccSavePasswordEntry -row $r -column 2 -sticky w 



  # Configure account on The Free Internet Chess  Server (FICS). 
  # Normally the host will be 'freechess.org' and the port 5000, but 
  # either can be changed. 

  set r 0

  label $f3.ficsHostLabel -text "${::tr(FICSserver)}:"
  grid $f3.ficsHostLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f3.ficsHostEntry -width 40 -textvariable ::utils::download::FICS_server_temp
  grid $f3.ficsHostEntry -row $r -column 2 -sticky w

  incr r

  label $f3.ficsUserLabel -text "${::tr(FICSuser)}:"
  grid $f3.ficsUserLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f3.ficsUserEntry -width 20 -textvariable ::utils::download::FICS_user_temp
  grid $f3.ficsUserEntry -row $r -column 2 -sticky w

  incr r
  label $f3.ficsPassLabel -text "${::tr(FICSpass)}:"
  grid $f3.ficsPassLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f3.ficsPassEntry -width 20 -show * -textvariable ::utils::download::FICS_pass_temp
  grid $f3.ficsPassEntry -row $r -column 2 -sticky w

  incr r

  label $f3.ficsPortLabel -text "${::tr(Port)}:"
  grid $f3.ficsPortLabel -row $r -column 0 -columnspan 2 -sticky we
  entry $f3.ficsPortEntry -width 10 -textvariable ::utils::download::FICS_port_temp -validate key -validatecommand {string is integer %P}
  grid $f3.ficsPortEntry -row $r -column 2 -sticky w

  incr r

  label $f3.ficsSavePasswordLabel -text "${::tr(SavePassword)}  "
  grid $f3.ficsSavePasswordLabel -row $r -column 0 -columnspan 2 -sticky we
  checkbutton $f3.ficsSavePasswordEntry -text  [ tr NotEncrypted]  -variable ::utils::download::FICS_savepass_temp 
  grid $f3.ficsSavePasswordEntry -row $r -column 2 -sticky w 

  grid [frame $f1.gap$r -height 5] -row $r -column -0; incr r
  grid [frame $f2.gap$r -height 5] -row $r -column -0; incr r
  grid [frame $f3.gap$r -height 5] -row $r -column -0; incr r

  dialogbutton $w.b.ok -text OK -command ::utils::download::OptionsDialogOK
  dialogbutton $w.b.cancel -text $::tr(Cancel) -command [list destroy $w]
  packbuttons right $w.b.cancel $w.b.ok
  bind $w <Return> [list $w.b.ok invoke]
  bind $w <Escape> [list $w.b.cancel invoke]
  ::utils::win::Centre $w
  wm resizable $w 0 0
  raiseWin $w
  grab $w
  focus $w.f1.proxyEntry
}

proc ::utils::download::OptionsDialogOK {} {

  # Destroy the download options dialog
  if { [string length $::utils::download::ICC_user_temp] > 0 } { 
    set firstchar [string range $::utils::download::ICC_user_temp 0 0 ]
    if { $firstchar eq "!" } { 
    } {
      tk_messageBox -type ok -icon info -message  [tr LogInAnonymously] -title [tr TitleLogInAnonymously ]
    }
 
  }
  
  set w .downloadOptions
  catch {grab release $w}
  destroy $w

  # Update the user-settable download variables:
  foreach v {proxyHost proxyPort ICC_server ICC_user ICC_pass ICC_port ICC_savepass 
             FICS_server FICS_user FICS_pass FICS_port FICS_savepass} {
    set ::utils::download::$v [set ::utils::download::${v}_temp]
  }

  if { [llength $::utils::download::proxyHost] > 0 } {
    set ::utils::download::useProxy 1
  } else {
    set ::utils::download::useProxy 0
  }
}

