### smoves2pgn.tcl
### Utility to take FICS smoves format and convert to pgn
### Copyright (C) 2007 Warren Lewis
### Todo: more error checking, if too slow move to a C function

namespace eval ::utils::smoves2pgn {}

proc ::utils::smoves2pgn::convert { pgn } {
   # initializations
   set foundheader1 0
   set foundheader2 0
   set movessection 0
   set comment ""
   set result "?"
   array set movesw {}
   array set movesb {}
   set mn 0

   # setup list of month abbreviations
   set monlist [list Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec]

   #split records on newlines
   set records [split $pgn "\n"]

   # walk through each record and process
   foreach rec $records {
      switch -regexp -- $rec {
         {(\w+) \((\w+)\) vs. (\w+) \((\w+)\) --- (\w+) (\w+)(\s+)(\d+), ([:\d]+) (\w+) (\d+)} {
            set foundheader1 1
            regexp -- {(\w+) \((\w+)\) vs. (\w+) \((\w+)\) --- (\w+) (\w+)(\s+)(\d+), ([:\d]+) (\w+) (\d+)} \
               $rec x wp wr bp br day mon junque dd time tz year
            continue
         }
         {(\w+) (\w+) (\w+), initial time: (\d+) minutes, increment: (\d+)} {
            set foundheader2 1
            regexp {(\w+) (\w+) (\w+), initial time: (\d+) minutes, increment: (\d+)} \
               $rec x rate type d1 inittime inc
            continue
         }
         {(\d+)\.(\s+)([+#=\-\w]+)(\s+)\(([:\d]+)\)} {
            set movessection 1
            #set up for scanning a move record
            set wm "NM"
            set bm "NM"
            set mn [expr {$mn + 1}]
            scan $rec "%s %s %s %s %s" num wm wt bm bt

            #insert moves into movesw and movesb arrays
            set movesw($mn) $wm
            set movesb($mn) $bm
         }
         default {
	       set fp [string first "{" $rec]
	       if { $fp == -1} { continue}
               set ep [string last "}" $rec]
               set comment [string range $rec $fp $ep]
               set result  [string range $rec [expr {$ep +2}] end]
               break
         }
      }
    }

   # if the headers have been found and this looks like smoves format
   # create pgnout return variable in pgn format
   set pgnout ""
   if {$foundheader1 == 1 && $foundheader2 == 1} {
      append pgnout "\[Event \"FICS $rate $type game\"\]\n"
      append pgnout "\[Site \"FICS\"\]\n"
      append pgnout "\[Date \"$year.[expr [lsearch $monlist $mon] + 1].$dd\"\]\n"
      append pgnout "\[Round \"-\"\]\n"
      append pgnout "\[White \"$wp\"\]\n"
      append pgnout "\[Black \"$bp\"\]\n"
      append pgnout "\[WhiteElo \"$wr\"\]\n"
      append pgnout "\[BlackElo \"$br\"\]\n"
      append pgnout "\[TimeControl \"[expr $inittime*60]+$inc\"\]\n"
      append pgnout "\[Result \"$result\"\]\n"
      append pgnout "\n"
   }
   if {$movessection == 1} {
      set max [array size movesw]
      for {set i 1} {$i < $max+1} {incr i} {
         append pgnout "$i. $movesw($i) "
         if {$movesb($i) == "NM"} {
            append pgnout "\n"
         } else {
            append pgnout "$movesb($i)\n"
         }
      }
      append pgnout "$comment $result\n"
   }
   return $pgnout
}

## Parse smoves output and put it into pgn format
#if { $argc != 1} {
#     puts "Please specify smoves format file to parse"
#     exit
#}
#set fid [open [lindex $argv 0]]
#set content [read $fid]
#close $fid
#
#puts [::utils::smoves2pgn::convert $content]
