# english-basic.tcl:
# Text for menu names and status bar help messages in English.
# Part of ChessDB which is a fork of Scid (Shane's Chess Information Database).
#
# Instructions for adding a new language:
#
# (1) Choose a letter code for the language. Currently assigned codes are:
#      E=English, D=Deutsch, F=Francais, S=Spanish, B=Brasil Portuguese,
#      P=Polish, N=Nederlands, W=Swedish, O=Norsk, C=Czech, H=Hungarian,
#      Y=Serbian K=Korean
#
# (2) Edit the code below that has the lines "addLanguage ..." and add your
#     new language. The final digit in each line is the index of the
#     letter to underline in the menu, counting from 0 as the first letter.
#
# (3) Copy the section of English menu and help message details below (all
#     the commands that start "menuText E ..." or "helpMsg E ..." or
#     "translate E ...") and change all the "E" letters to the letter you
#     assigned for the new language.
#
# (4) Write the translations. This involves changing anything "in quotes"
#     or {in braces} for the menuText, helpMsg and translate commands.
#
#     A menu command has the format:
#         menuText L tag "Name..." underline {HelpMessage...}
#
#     A status bar help message for a button has the format:
#         helpMsg L tag {HelpMessage...}
#
#     A general word or message translation has the format:
#         translate L tag {message...}
#
#     where "L" is the language letter, "tag" is the name of the menu entry
#     or the button widget name, and "underline" is the index of the letter
#     to underline, counting from zero as the first letter. Two menu entries
#     that appear in the same menu should have a different underlined letter.
#     If in doubt, just make them all "0" and I'll assign sensible underlined
#     letters when your translations are incorporated into ChessDB.
#
# Additions, corrections? Email: drkirkby@users.sourceforge.net


addLanguage E English 0 iso8859-1

proc setLanguage_E {} {

menuText E File "File" 0
menuText E FileNew "New..." 0 {Create a new ChessDB database}
menuText E FileOpen "Open..." 0 {Open an existing ChessDB database}
menuText E FileClose "Close" 0 {Close the active ChessDB database}
menuText E FileFinder "Finder" 0 {Open the File Finder window}
menuText E FileBookmarks "Bookmarks" 0 {Bookmarks menu (shortcut: Ctrl+B)}
menuText E FileBookmarksAdd "Add Bookmark" 0  {Bookmark the current database game and position}
menuText E FileBookmarksFile "File Bookmark" 0  {File a bookmark for the current game and position}
menuText E FileBookmarksEdit "Edit Bookmarks..." 0  {Edit the bookmarks menus}
menuText E FileBookmarksList "Display Folders as Single List" 0  {Display bookmark folders as a single list, not submenus}
menuText E FileBookmarksSub "Display Folders as Submenus" 0  {Display bookmark folders as submenus, not a single list}
menuText E FileMaint "Maintenance" 0 {ChessDB database maintenance tools}
menuText E FileMaintWin "Maintenance Window" 0  {Open/close the ChessDB database maintenance window}
menuText E FileMaintCompact "Compact Database..." 0  {Compact database files, removing deleted games and unused names}
menuText E FileMaintClass "ECO-Classify Games..." 2 {Recompute the ECO code of all games}
menuText E FileMaintSort "Sort Database..." 0  {Sort all games in the database}
menuText E FileMaintDelete "Delete Twin Games..." 0  {Find twin games and set them to be deleted}
menuText E FileMaintTwin "Twin Checker Window" 0  {Open/update the Twin checker window}
menuText E FileMaintName "Name Spelling" 0 {Name editing and spelling tools}
menuText E FileMaintNameEditor "Name Editor" 0  {Open/close the name editor window}
menuText E FileMaintNamePlayer "Spellcheck Player Names..." 11  {Spellcheck player names using the spellcheck file}
menuText E FileMaintNameEvent "Spellcheck Event Names..." 11  {Spellcheck event names using the spellcheck file}
menuText E FileMaintNameSite "Spellcheck Site Names..." 11  {Spellcheck site names using the spellcheck file}
menuText E FileMaintNameRound "Spellcheck Round Names..." 11  {Spellcheck round names using the spellcheck file}
menuText E FileReadOnly "Read-only..." 0  {Treat the current database as read-only, preventing changes}
menuText E FileSwitch "Switch to Database" 0  {Switch to a different opened database}
menuText E FileExit "Exit" 1 {Exit ChessDB}
menuText E Edit "Edit" 0
menuText E EditAdd "Add Variation" 0 {Add a variation at this move in the game}
menuText E EditDelete "Delete Variation" 0 {Delete a variation for this move}
menuText E EditFirst "Make First Variation" 5  {Promote a variation to be first in the list}
menuText E EditMain "Promote Variation to Main Line" 21  {Promote a variation to be the main line}
menuText E EditTrial "Try Variation" 0  {Start/stop trial mode, for testing an idea on the board}
menuText E EditStrip "Strip" 2 {Strip comments or variations from this game}
menuText E EditStripComments "Comments" 0  {Strip all comments and annotations from this game}
menuText E EditStripVars "Variations" 0 {Strip all variations from this game}
menuText E EditStripBegin "Moves from the beginning" 1  {Strip moves from the beginning of the game}
menuText E EditStripEnd "Moves to the end" 0  {Strip moves to the end of the game}
menuText E EditReset "Empty Clipbase" 0  {Reset the clipbase to be completely empty}
menuText E EditCopy "Copy This Game to Clipbase" 0  {Copy this game to the Clipbase database}
menuText E EditPaste "Paste Last Clipbase Game" 0  {Paste the active Clipbase game here}
menuText E EditPastePGN "Paste Clipboard text as PGN game..." 18  {Interpret the clipboard text as a game in PGN notation and paste it here}
menuText E EditSetup "Setup Start Board..." 0  {Set the start position for this game}
menuText E EditCopyBoard "Copy Position" 6 {Copy the current board in FEN notation to the text selection (clipboard)}
menuText E EditPasteBoard "Paste Start Board" 12  {Set the start board from the current text selection (clipboard)}
menuText E Game "Game" 0
menuText E GameNew "New Game" 0  {Reset to an empty game, discarding any changes}
menuText E GameFirst "Load First Game" 5 {Load the first filtered game}
menuText E GamePrev "Load Previous Game" 5 {Load the previous filtered game}
menuText E GameReload "Re-Load Current Game" 3  {Reload this game, discarding any changes made}
menuText E GameNext "Load Next Game" 7 {Load the next filtered game}
menuText E GameLast "Load Last Game" 8 {Load the last filtered game}
menuText E GameRandom "Load Random Game" 8 {Load a random filtered game}
menuText E GameNumber "Load Game Number..." 5  {Load a game by entering its number}
menuText E GameReplace "Save: Replace game..." 6  {Save this game, replacing the old version}
menuText E GameAdd "Save: Add New Game..." 6  {Save this game as a new game in the database}
menuText E GameDeepest "Identify Opening" 0 {Goto the deepest game position listed in the ECO book}
menuText E GameGotoMove "Goto Move Number..." 5  {Go to a specified move number in the current game}
menuText E GameNovelty "Find Novelty..." 7  {Find the first move of this game that has not played before}
menuText E Search "Search" 0
menuText E SearchReset "Reset Filter" 0 {Reset the filter so all games are included}
menuText E SearchNegate "Negate Filter" 0 {Negate the filter to only include excluded games}
menuText E SearchCurrent "Current Board..." 0 {Search for the current board position}
menuText E SearchHeader "Header..." 0 {Search by Header (player, event, etc) information}
menuText E SearchMaterial "Material/Pattern..." 0 {Search for material or board patterns}
menuText E SearchUsing "Using Search File..." 0 {Search using a SearchOptions file}
menuText E Windows "Windows" 0
menuText E WindowsComment "Comment Editor" 0 {Open/close the comment editor}
menuText E WindowsGList "Game List" 0 {Open/close the game list window}
menuText E WindowsPGN "PGN Window" 0 {Open/close the PGN (game notation) window}
menuText E WindowsPList "Player Finder" 2 {Open/close the player finder}
menuText E WindowsTmt "Tournament Finder" 2 {Open/close the tournament finder}
menuText E WindowsSwitcher "Database switcher" 0  {Open/close the Database Switcher window}
menuText E WindowsMaint "Maintenance Window" 0  {Open/close the Maintenance window}
menuText E WindowsECO "ECO Browser" 0 {Open/close the ECO Browser window}
menuText E WindowsRepertoire "Repertoire Editor" 0  {Open/close the opening repertoire editor}
menuText E WindowsStats "Statistics Window" 0  {Open/close the filter statistics window}
menuText E WindowsTree "Tree Window" 0 {Open/close the Tree window}
menuText E WindowsTB "Endgame Tablebase Window" 1  {Open/close the Tablebase window}
menuText E Tools "Tools" 0
menuText E ToolsAnalysis "Analysis Engine..." 0  {Start/stop a chess analysis engine}
menuText E ToolsAnalysis2 "Analysis Engine 2..." 16  {Start/stop the 2nd chess analysis engine}
menuText E ToolsCross "Crosstable" 0 {Show tournament crosstable for this game}
menuText E ToolsEmail "Email Manager" 0  {Open/close the email chess manager window}
menuText E ToolsFilterGraph "Filter Graph" 7  {Open/close the filter graph window}
menuText E ToolsOpReport "Opening Report" 0  {Generate an opening report for the current position}
menuText E ToolsTracker "Piece Tracker"  6 {Open the Piece Tracker window}
menuText E ToolsCoach "Play with coach"  0 {Start a game with a coach and tactical opportunities}
menuText E ToolsPInfo "Player Information"  0  {Open/update the Player Information window}
menuText E ToolsPInfoBlack "Black"  0  {Open/update the Player Information window for the Black player}
menuText E ToolsPInfoWhite "White"  0  {Open/update the Player Information window for the White player}
menuText E ToolsPlayerReport "Player Report..." 3  {Generate a player report}
menuText E ToolsRating "Rating Graph" 0  {Graph the rating history of the current game players}
menuText E ToolsScore "Score Graph" 0 {Show the score graph window}
menuText E ToolsExpCurrent "Export Current Game" 8  {Write current game to a PGN, HTML or LaTeX file}
menuText E ToolsExpCurrentPGN "Export Game to PGN File..." 15  {Write current game to a PGN file}
menuText E ToolsExpCurrentHTML "Export Game to HTML File..." 15  {Write current game to a HTML file}
menuText E ToolsExpCurrentLaTeX "Export Game to LaTeX File..." 15  {Write current game to a LaTeX file}
menuText E ToolsExpFilter "Export All Filter Games" 1  {Write all filtered games to a PGN, HTML or LaTeX file}
menuText E ToolsExpFilterPGN "Export Filter to PGN File..." 17  {Write all filtered games to a PGN file}
menuText E ToolsExpFilterHTML "Export Filter to HTML File..." 17  {Write all filtered games to a HTML file}
menuText E ToolsExpFilterLaTeX "Export Filter to LaTeX File..." 17  {Write all filtered games to a LaTeX file}
menuText E ToolsImportOne "Import One PGN Game..." 0  {Import a game from PGN text}
menuText E ToolsImportFile "Import File of PGN Games..." 7  {Import games from a PGN file}
menuText E ToolsImportDir "Import all PGN files in a directory" 16  {Imports all the PGN files in a particular directory}
menuText E ToolsDownload "Download Games from..." 0 {Download games from the internet}
menuText E ToolsDownloadFromICC   "ICC"  0 {Download the most recent games of anyone on ICC}
menuText E ToolsDownloadFromFICS  "FICS" 0 {Download the most recent games of anyone on FICS}
menuText E ToolsDownloadFromTWIC "TWIC" 0   {Download games in PGN format from the TWIC web site}
menuText E Options "Options" 0
menuText E OptionsBoard "Chessboard" 0 {Chess board appearance options}
menuText E OptionsBoardSize "Size" 0 {Change the board size}
menuText E OptionsBoardPieces "Piece Style" 6 {Change the board piece style}
menuText E OptionsBoardColors "Colors..." 0 {Change board colors}
menuText E OptionsBoardNames "My Player Names..." 0 {Edit my player names}
menuText E OptionsExport "Exporting" 0 {Change text export options}
menuText E OptionsFonts "Fonts" 0 {Change fonts}
menuText E OptionsFontsRegular "Regular" 0 {Change the regular font}
menuText E OptionsFontsMenu "Menu" 0 {Change the menu font}
menuText E OptionsFontsSmall "Small" 0 {Change the small font}
menuText E OptionsFontsFixed "Fixed" 0 {Change the fixed-width font}
menuText E OptionsGInfo "Game Information" 0 {Game information options}
menuText E OptionsLanguage "Language" 0 {Select menu language}
menuText E OptionsMoves "Moves" 0 {Move entry options}
menuText E OptionsMovesAsk "Ask Before Replacing Moves" 0  {Ask before overwriting any existing moves}
menuText E OptionsMovesAnimate "Animation Time" 1  {Set the amount of time used to animate moves}
menuText E OptionsMovesDelay "Autoplay Time Delay..." 1  {Set the time delay for autoplay mode}
menuText E OptionsMovesCoord "Coordinate Move Entry" 0  {Accept coordinate-style move entry (e.g. "g1f3")}
menuText E OptionsMovesSuggest "Show Suggested Moves" 0  {Turn on/off move suggestion}
menuText E OptionsMovesKey "Keyboard Completion" 0  {Turn on/off keyboard move auto-completion}
menuText E OptionsNumbers "Number Format" 0 {Select the number format}
menuText E OptionsStartup "Startup" 3 {Select windows to open at startup}
menuText E OptionsWindows "Windows" 0 {Window options}
menuText E OptionsWindowsIconify "Auto-Iconify" 5  {Iconify all windows when the main window is iconified}
menuText E OptionsWindowsRaise "Auto-Raise" 5  {Raise certain windows (e.g. progress bars) whenever they are obscured}
menuText E OptionsSounds "Sounds..." 2 {Configure move announcement sounds}
menuText E OptionsToolbar "Toolbar..." 0 {Configure the main window toolbar}
menuText E OptionsECO "Load ECO File..." 7 {Load the ECO classification file}
menuText E OptionsSpell "Load Spellcheck File..." 11  {Load the ChessDB spellcheck file}
menuText E OptionsTable "Tablebase Directory..." 10  {Select a tablebase file; all tablebases in its directory will be used}
menuText E OptionsRecent "Recent Files..." 0  {Change the number of recent files displayed in the File menu}
menuText E OptionsSave "Save Options" 0  "Save all settable options to the file $::optionsFile"
menuText E OptionsAutoSave "Auto-Save Options on Exit" 0  {Auto-save all options when exiting ChessDB}
menuText E OptionsDownload "Downloads..." 0 {Configure Download settings}
menuText E Help "Help" 0
menuText E HelpContents "Contents" 0 {Show the help contents page}
menuText E HelpIndex "Index" 0 {Show the help index page}
menuText E HelpGuide "Quick Guide" 0 {Show the quick guide help page}
menuText E HelpHints "Hints" 0 {Show the hints help page}
menuText E HelpContact "Contact Info" 1 {Show the contact information help page}
menuText E HelpTip "Tip of the Day" 0 {Show a useful ChessDB tip}
menuText E HelpStartup "Startup Window" 0 {Show the startup window}
menuText E HelpAbout "About ChessDB" 0 {Information about ChessDB}
menuText E HelpCheckForUpdates "Check for Updates" 0 {Check software revision - this requires an internet connection, as it connects to the Sourceforge web server}
menuText E HelpBugs "Bugs" 0 {Known bugs in ChessDB}
menuText E HelpBugsKnownAtRelease  "Known  at release date" 0 {Bugs known at the time of release}
menuText E HelpBugsRecentlyFound  "Discovered since release" 0 {Recently discovered bugs - needs internet connection}
menuText E GInfoHideNext "Hide Next Move" 0
menuText E GInfoMaterial "Show Material Values" 0
menuText E GInfoFEN "Show FEN" 5
menuText E GInfoMarks "Show Colored Squares and Arrows" 5
menuText E GInfoWrap "Wrap Long Lines" 0
menuText E GInfoFullComment "Show Full Comment" 10
menuText E GInfoPhotos "Show Photos" 5
menuText E GInfoTBNothing "Tablebases: Nothing" 12
menuText E GInfoTBResult "Tablebases: Result Only" 12
menuText E GInfoTBAll "Tablebases: Result and Best Moves" 19
menuText E GInfoDelete "(Un)Delete This Game" 4
menuText E GInfoMark "(Un)Mark This Game" 4
menuText E TreeFile "File" 0
menuText E TreeFileSave "Save Cache File" 0 {Save the tree cache (.stc) file}
menuText E TreeFileFill "Fill Cache File" 0  {Fill the cache file with common opening positions}
menuText E TreeFileBest "Best Games List" 0 {Show the best tree games list}
menuText E TreeFileGraph "Graph Window" 0 {Show the graph for this tree branch}
menuText E TreeFileCopy "Copy Tree Text to Clipboard" 1  {Copy the tree statistics to the clipboard}
menuText E TreeFileClose "Close Tree Window" 0 {Close the tree window}
menuText E TreeSort "Sort" 0
menuText E TreeSortAlpha "Alphabetical" 0
menuText E TreeSortECO "ECO Code" 0
menuText E TreeSortFreq "Frequency" 0
menuText E TreeSortScore "Score" 0
menuText E TreeOpt "Options" 0
menuText E TreeOptLock "Lock" 0 {Lock/unlock the tree to the current database}
menuText E TreeOptTraining "Training" 0 {Turn on/off tree training mode}
menuText E TreeOptAutosave "Auto-Save Cache File" 0  {Auto-save the cache file when closing the tree window}
menuText E TreeHelp "Help" 0
menuText E TreeHelpTree "Tree Help" 0
menuText E TreeHelpIndex "Help Index" 0
menuText E FinderFile "File" 0
menuText E FinderFileSubdirs "Look in Subdirectories" 0
menuText E FinderFileClose "Close File Finder" 0
menuText E FinderSort "Sort" 0
menuText E FinderSortType "Type" 0
menuText E FinderSortSize "Size" 0
menuText E FinderSortMod "Modified" 0
menuText E FinderSortName "Name" 0
menuText E FinderSortPath "Path" 0
menuText E FinderTypes "Types" 0
menuText E FinderTypesChessDB "ChessDB Databases" 0
menuText E FinderTypesOld "Old-Format ChessDB Databases" 0
menuText E FinderTypesPGN "PGN Files" 0
menuText E FinderTypesEPD "EPD Files" 0
menuText E FinderTypesRep "Repertoire Files" 0
menuText E FinderHelp "Help" 0
menuText E FinderHelpFinder "File Finder Help" 0
menuText E FinderHelpIndex "Help Index" 0
menuText E PListFile "File" 0
menuText E PListFileUpdate "Update" 0
menuText E PListFileClose "Close Player Finder" 0
menuText E PListSort "Sort" 0
menuText E PListSortName "Name" 0
menuText E PListSortElo "Elo" 0
menuText E PListSortGames "Games" 0
menuText E PListSortOldest "Oldest" 0
menuText E PListSortNewest "Newest" 2
menuText E TmtFile "File" 0
menuText E TmtFileUpdate "Update" 0
menuText E TmtFileClose "Close Tournament Finder" 0
menuText E TmtSort "Sort" 0
menuText E TmtSortDate "Date" 0
menuText E TmtSortPlayers "Players" 0
menuText E TmtSortGames "Games" 0
menuText E TmtSortElo "Elo" 0
menuText E TmtSortSite "Site" 0
menuText E TmtSortEvent "Event" 1
menuText E TmtSortWinner "Winner" 0
menuText E GraphFile "File" 0
menuText E GraphFileColor "Save as Color PostScript..." 8
menuText E GraphFileGrey "Save as Greyscale PostScript..." 8
menuText E GraphFileClose "Close Window" 6
menuText E GraphOptions "Options" 0
menuText E GraphOptionsWhite "White" 0
menuText E GraphOptionsBlack "Black" 0
menuText E GraphOptionsBoth "Both" 1
menuText E GraphOptionsPInfo "Player Info player" 0
menuText E StatsFile "File" 0
menuText E StatsFilePrint "Print to File..." 0
menuText E StatsFileClose "Close Window" 0
menuText E StatsOpt "Options" 0
menuText E PgnFile "File" 0
menuText E PgnFileCopy "Copy Game to Clipboard" 0
menuText E PgnFilePrint "Print to File..." 0
menuText E PgnFileClose "Close PGN Window" 10
menuText E PgnOpt "Display" 0
menuText E PgnOptColor "Color Display" 0
menuText E PgnOptShort "Short (3-line) Header" 0
menuText E PgnOptSymbols "Symbolic Annotations" 1
menuText E PgnOptIndentC "Indent Comments" 0
menuText E PgnOptIndentV "Indent Variations" 7
menuText E PgnOptColumn "Column Style (one move per line)" 1
menuText E PgnOptSpace "Space after Move Numbers" 1
menuText E PgnOptStripMarks "Strip out Colored Square/Arrow Codes" 1
menuText E PgnOptBoldMainLine "Use Bold Text for Main Line Moves" 4
menuText E PgnColor "Colors" 0
menuText E PgnColorHeader "Header..." 0
menuText E PgnColorAnno "Annotations..." 0
menuText E PgnColorComments "Comments..." 0
menuText E PgnColorVars "Variations..." 0
menuText E PgnColorBackground "Background..." 0
menuText E PgnColorMain "Main line..." 0
menuText E PgnColorCurrent "Current move background..." 1
menuText E PgnColorNextMove "Next move background..." 0
menuText E PgnHelp "Help" 0
menuText E PgnHelpPgn "PGN Help" 0
menuText E PgnHelpIndex "Index" 0
menuText E CrosstabFile "File" 0
menuText E CrosstabFileText "Print to Text File..." 9
menuText E CrosstabFileHtml "Print to HTML File..." 9
menuText E CrosstabFileLaTeX "Print to LaTeX File..." 9
menuText E CrosstabFileClose "Close Crosstable Window" 0
menuText E CrosstabEdit "Edit" 0
menuText E CrosstabEditEvent "Event" 0
menuText E CrosstabEditSite "Site" 0
menuText E CrosstabEditDate "Date" 0
menuText E CrosstabOpt "Display" 0
menuText E CrosstabOptAll "All-play-all" 0
menuText E CrosstabOptSwiss "Swiss" 0
menuText E CrosstabOptKnockout "Knockout" 0
menuText E CrosstabOptAuto "Auto" 1
menuText E CrosstabOptAges "Ages in Years" 8
menuText E CrosstabOptNats "Nationalities" 0
menuText E CrosstabOptRatings "Ratings" 0
menuText E CrosstabOptTitles "Titles" 0
menuText E CrosstabOptBreaks "Tie-Break Scores" 4
menuText E CrosstabOptDeleted "Include Deleted Games" 8
menuText E CrosstabOptColors "Colors (Swiss table only)" 0
menuText E CrosstabOptColumnNumbers "Numbered Columns (All-play-all table only)" 2
menuText E CrosstabOptGroup "Group Scores" 0
menuText E CrosstabSort "Sort" 0
menuText E CrosstabSortName "Name" 0
menuText E CrosstabSortRating "Rating" 0
menuText E CrosstabSortScore "Score" 0
menuText E CrosstabColor "Color" 0
menuText E CrosstabColorPlain "Plain Text" 0
menuText E CrosstabColorHyper "Hypertext" 0
menuText E CrosstabHelp "Help" 0
menuText E CrosstabHelpCross "Crosstable Help" 0
menuText E CrosstabHelpIndex "Help Index" 0
menuText E OprepFile "File" 0
menuText E OprepFileText "Print to Text File..." 9
menuText E OprepFileHtml "Print to HTML File..." 9
menuText E OprepFileLaTeX "Print to LaTeX File..." 9
menuText E OprepFileOptions "Options..." 0
menuText E OprepFileClose "Close Report Window" 0
menuText E OprepFavorites "Favorites" 1
menuText E OprepFavoritesAdd "Add Report..." 0
menuText E OprepFavoritesEdit "Edit Report Favorites..." 0
menuText E OprepFavoritesGenerate "Generate Reports..." 0
menuText E OprepHelp "Help" 0
menuText E OprepHelpReport "Opening Report Help" 0
menuText E OprepHelpIndex "Help Index" 0
menuText E RepFile "File" 0
menuText E RepFileNew "New" 0
menuText E RepFileOpen "Open..." 0
menuText E RepFileSave "Save..." 0
menuText E RepFileSaveAs "Save As..." 5
menuText E RepFileClose "Close Window" 0
menuText E RepEdit "Edit" 0
menuText E RepEditGroup "Add Group" 4
menuText E RepEditInclude "Add Include Line" 4
menuText E RepEditExclude "Add Exclude Line" 4
menuText E RepView "View" 0
menuText E RepViewExpand "Expand All Groups" 0
menuText E RepViewCollapse "Collapse All Groups" 0
menuText E RepSearch "Search" 0
menuText E RepSearchAll "All of Repertoire..." 0
menuText E RepSearchDisplayed "Displayed Lines Only..." 0
menuText E RepHelp "Help" 0
menuText E RepHelpRep "Repertoire Help" 0
menuText E RepHelpIndex "Help Index" 0
menuText E DownloadPGNFiles {Download PGN files} 0
menuText E ToolsPlay "Play" 0 {Play game vs the computer, online, or engine vs engine}
menuText E ToolsPlayYouBlack "Computer vs You" 0 {Play a game as Black against a chess engine}
menuText E ToolsPlayYouWhite "You vs Computer" 0 {Play a game as White against a chess engine}
menuText E ToolsPlayOnline "Play online" 0 {Play others on a chess server - requires an internet connection}
menuText E ToolsPlayEngineEngine "Computer vs Computer" 0 {Two chess computers play against each other}
menuText E ToolsObserveChessServer "Observe online game" 0 {Observe a game being played on a chess server}
menuText E HelpThanks "Thank you" 0 {A list of those who have helped ChessDB in some way}
menuText E HelpHowYouCanHelp "How you can help" 0 {How you can improve ChessDB - even if you are not a programmer}
menuText E HelpSupport "Support" 0 {How you can obtain support in using ChessDB - there is no charge for support}
menuText E HelpLicense "ChessDB's licence conditions" 0 {Displays the GNU General Public License (GPL)}
helpMsg E .button.start {Go to start of game  (key: Home)}
helpMsg E .button.end {Go to end of game  (key: End)}
helpMsg E .button.back {Go back one move  (key: LeftArrow)}
helpMsg E .button.forward {Go forward one move  (key: RightArrow)}
helpMsg E .button.intoVar {Move into a variation  (shortcut key: v)}
helpMsg E .button.exitVar {Leave the current variation  (shortcut key: z)}
helpMsg E .button.flip {Rotate board  (shortcut key: .)}
helpMsg E .button.coords {Turn board coordinates on or off  (shortcut key: 0)}
helpMsg E .button.stm {Turn the side-to-move icon on or off}
helpMsg E .button.autoplay {Autoplay moves  (key: Ctrl+Z)}
translate E TitleDownloadFromTWIC {ChessDB: Download from TWIC website}
translate E WebServerNotOK {The web server did NOT respond with an OK (HTTP status code 200) hence unable to retrieve}
translate E GotoTWICNumber {First issue to download}
translate E DownloadNow {Download now}
translate E NotBelow210 {The TWIC web site does not archive issues older than 210}
translate E TWICissuedDownloadedLast {issue(s) of TWIC downloaded }
translate E OneTWICIssueDownloaded {One issue of TWIC was downloaded (issue}
translate E TWICIssuesDownloaded {TWIC issues were download (issues}
translate E BasedOnTheDate {Based on the date, the last issue ChessDB estimated that would be on the TWIC web site was issue}
translate E soThisIsConsistant {so what you have retrieved is consistent with what ChessDB expected.}
translate E soThisInNotConsistant {This is not consistent with what ChessDB managed to download. Perhaps there was a problem, or perhaps TWIC are late updating the web site. Or perhaps the date is wrong on your computer.}
translate E TWICTitle {Downloads from The Week In Chess (TWIC)\n\n}
translate E NoChangesMade {Failed to retrieve the first file requested. Aborting. No PGN file or database has been created.}
translate E SomeFileButNotAll {Some, but not all of the files requested could be retrieved, so the database and/or PGN file will not have as many issues as you requested. Try another time, when TWIC have updated their web site}
translate E TitlePartiallyCompleteDownload {Downloads partially compleated}
translate E FailureOccuredAt {The failure occured when trying to retrieve issue}
translate E NoNewTWICIssueFound {No new TWIC issues were found - try again later, when TWIC may have updated their web site}
translate E TriedButFailed {ChessDB tried unsuccessfully to retrieve issue}
translate E TheNewDBAndOrPGN {The new ChessDB format database and/or PGN file, will be in the directory}
translate E Introduction {Introduction}
translate E Configuration {Configuration}
translate E DeleteIndividualZip {Delete individual Zip files}
translate E DeleteIndividualZip2 {Delete individual Zip files}
translate E WhenTheyAreNoLongerNeeded  {when they are no longer needed.}
translate E DeleteIndividualPGN {Delete individual PGN files}
translate E DeleteIndividualPGN2 {Delete individual PGN files}
translate E CreateLargePGN  {Create a large PGN of all PGN's downloaded}
translate E CreateChessDBDatabase {Create ChessDB format database}
translate E ManuallySetFirstIssue {Manually set first issue         }
translate E ManuallySetLastIssue  {Manually set last issue}
translate E IssueNumber {Issue number}
translate E IsNotAvailableYet {is not available yet}
translate E DownloadResults {Download results}
translate E DownloadShouldBeComplete {The download should be complete, although if you see this message very quickly, it probably means there was a problem.}
translate E NeedWriteAccess  {This operation needs to write some file(s) to disk. It does this in the directory from where you started ChessDB, but in this case you don't have write access to that directory. Therefore this feature is not available to you. Please exit ChessDB, change directory to one where you have write access, then run ChessDB again. Then you will be able to use this feature.} 
translate E NeedUnzip {The files on the TWIC web site are compressed and need 'unzip' to decompress them. If you do not have it, you can get the sources from http://www.info-zip.org/UnZip.html If you do have 'unzip', then make sure it is in the path, since ChessDB can't execute it. An 'unzip.exe' will be distributed with binary versions of ChessDB for Windows, so you should have unzip.exe if you installed a Windows binary}
translate E WarningBeta  {WARNING: This copy of ChessDB is a 'beta' release, meaning it is intended mainly for testing and evaluation, but not really for everyday use. Beta releases may have significant bugs. Please use this 'beta' release only if you want the benefits (usually more functionality) and accept the higher risk of bugs. I would appreciate feedback, particularly on beta releases. Please check regularly for updates - you can do this from the Help menu.}
translate E HelpTitleUpdatesMessage {Checking software version}
translate E HelpUpdateStatusCurrent {Your version of ChessDB is current. It is version}
translate E FreeUpgradeAt {Upgrades, when they are available, can be found for free at http://sourceforge.net/projects/chessdb/ All the stable releases are in a package called simply 'chessdb' Any beta releases, when available, will always be in a package called 'chessdb-unstable-for-testing'. Any extra files, such as tablebases, of perhaps games, will be in a package called 'extras'.}
translate E ThisVersionIs {The version of ChessDB you currently using is}
translate E HelpUpdateStatuStableToBeta  {However, that release is not considered a stable/bug-free release (hence you will find it in the 'chessdb-unstable-for-testing' package on Sourceforge and it has 'beta' in the name). While it will probably have some bug fixes, feature enhancements or completely new features compared to this stable release, there will often be a higher total number of bugs, and some new features shown on it may not work at all. Hence think about this before you download the beta release. But the best way to get ChessDB improved is to provide feedback on the bugs that exist. Beta releases will normally have more functionality than a stable release such as this, but are not as risky as alpha releases, so are often a good choice.}
translate E UsingLatestStableNoLaterBeta {You are using the latest version of ChessDB. There is not even a later version at present for test purposes (a beta release). Well done! This is version}
translate E UsingLatestStableThereIsLaterBeta {You are using the most current stable release of ChessDB. There is however a later 'beta' release available, but that is not fully tested and so is mainly for people who want to try out the latest features. There may well be significant enhancements, but some of the enhancements might not be fully functional. There is a greater chance of bugs in that case. It's up to you to decide whether or not to try the beta release. If you do, please provide feedback, as providing feedback on beta releases is the best way for ChessDB to improve.}
translate E NotUsingLatestStableThereIsLaterBeta {You are not using the latest stable release of ChessDB, you are advised to upgrade to at least that as soon as possible.\nThere is also an even later 'beta' release available, but that is not fully tested and so is mainly for people who want to try out the latest features. There may well be significant enhancements in the beta release, but some of the enhancements might not be fully functional. There is a greater chance of bugs in that case. It's up to you to decide whether or not to try the beta release. If you do, please provide feedback, as providing feedback on beta releases is the best way for ChessDB to improve. but you are strongly advised to upgrade to at least the latest stable release.} 
translate E NotUsingLatestStableButNoLaterBeta {There is a more recent release of ChessdB which is considered stable. That is not an experimental (beta) release, as there are currently no beta releases available. There is believed to be no reason for you not to upgrade.}
translate E BetaButNotLatestBeta {You are using a beta version of ChessDB, but there is a later beta version available. Whilst the latest beta is not expected to be 100% perfect, it should be better than the version you are using. Hence you are strongly advised to upgrade to the latest beta release. Remember, please give feedback on versions of ChessDB, *especially* beta releases like this one, since beta versions are released primarily so people can spot bugs, before they are made into a stable release.}
translate E VersionOfLatestStable {The latest stable release, which should be free of any significant problems, is version} 
translate E ButNoteNotStable {But note that this is not classed as a stable release, so might well have bugs which don't exist in an older stable release. (Of course, a bug that existed in a stable release may be fixed in this beta one, but in general stable releases give the less hassle, but have less features.)}
translate E VersionOfLatestBeta {The latest beta release is} 
translate E DateOfRelease {That was released on}
translate E WhichWasRelasedOn {which was released on}
translate E HelpUpdateStatusUnknown {Sorry, unable to determine version.\nPlease check manually at http://chessdb.sourceforge.net/ or try again later.} 
translate E HelpUpdateStatusCantConnect {Sorry, unable to connect to http://chessdb.sourceforge.net/ to find the current version of ChessDB. Please try again later.}
translate E HelpUpdateStatusTooNew1 {This version appears to be newer that the latest release, which is a little odd, *unless* you have checked out code from the CVS repository, in which case ignore this message. Otherwise, please contact david.kirkby@onetel.net, telling him the date, time and version of your software (}
translate E HelpUpdateStatusTooNew2 {) as well as the apparent latest version, which is}
translate E Back {Back}
translate E Browse {Browse}
translate E Cancel {Cancel}
translate E Clear {Clear}
translate E Close {Close}
translate E Contents {Contents}
translate E Defaults {Defaults}
translate E Delete {Delete}
translate E Graph {Graph}
translate E Help {Help}
translate E Import {Import}
translate E Index {Index}
translate E LoadGame {Load Game}
translate E BrowseGame {Browse Game}
translate E MergeGame {Merge Game}
translate E Preview {Preview}
translate E Revert {Revert}
translate E Save {Save}
translate E Search {Search}
translate E Stop {Stop}
translate E Store {Store}
translate E Update {Update}
translate E ChangeOrient {Change window orientation}
translate E ShowIcons {Show Icons}
translate E None {None}
translate E First {First}
translate E Current {Current}
translate E Last {Last}
translate E game {game}
translate E games {games}
translate E move {move}
translate E moves {moves}
translate E all {all}
translate E Yes {Yes}
translate E No {No}
translate E Both {Both}
translate E King {King}
translate E Queen {Queen}
translate E Rook {Rook}
translate E Bishop {Bishop}
translate E Knight {Knight}
translate E Pawn {Pawn}
translate E White {White}
translate E Black {Black}
translate E Player {Player}
translate E Rating {Rating}
translate E RatingDiff {Rating difference (White - Black)}
translate E AverageRating {Average Rating}
translate E Event {Event}
translate E Site {Site}
translate E Country {Country}
translate E IgnoreColors {Ignore colors}
translate E Date {Date}
translate E EventDate {Event date}
translate E Decade {Decade}
translate E Year {Year}
translate E Month {Month}
translate E Months {January February March April May June July August September October November December}
translate E Days {Sun Mon Tue Wed Thu Fri Sat}
translate E YearToToday {Year to today}
translate E Result {Result}
translate E Round {Round}
translate E Length {Length}
translate E ECOCode {ECO code}
translate E ECO {ECO}
translate E Deleted {Deleted}
translate E SearchResults {Search Results}
translate E OpeningTheDatabase {Opening database}
translate E Database {Database}
translate E Filter {Filter}
translate E noGames {no games}
translate E allGames {all games}
translate E empty {empty}
translate E clipbase {clipbase}
translate E score {score}
translate E StartPos {Start position}
translate E Total {Total}
translate E readonly {read-only}
translate E ErrNotOpen {This is not an open database.}
translate E ErrReadOnly {This database is read-only; it cannot be altered.}
translate E ErrSearchInterrupted {Search was interrupted; results are incomplete.}
translate E twin {twin}
translate E deleted {deleted}
translate E comment {comment}
translate E hidden {hidden}
translate E LastMove {Last move}
translate E NextMove {Next move}
translate E GameStart {Start of game}
translate E LineStart {Start of line}
translate E GameEnd {End of game}
translate E LineEnd {End of line}
translate E PInfoAll {Results for <b>all</b> games}
translate E PInfoFilter {Results for <b>filter</b> games}
translate E PInfoAgainst {Results against}
translate E PInfoMostWhite {Most common openings as White}
translate E PInfoMostBlack {Most common openings as Black}
translate E PInfoRating {Rating history}
translate E PInfoBio {Biography}
translate E PInfoEditRatings {Edit Ratings}
translate E Draw {Draw}
translate E stalemate {stalemate}
translate E withAllMoves {with all moves}
translate E withAllButOneMove {with all but one move}
translate E with {with}
translate E only {only}
translate E lose {lose}
translate E loses {loses}
translate E allOthersLose {all others lose}
translate E matesIn {mates in}
translate E hasCheckmated {has checkmated}
translate E longest {longest}
translate E WinningMoves {Winning moves}
translate E DrawingMoves {Drawing moves}
translate E LosingMoves {Losing moves}
translate E UnknownMoves {Unknown-result moves}
translate E Tip {Tip}
translate E TipAtStartup {Tip at startup}
translate E SaveCache {Save Cache}
translate E Training {Training}
translate E LockTree {Lock}
translate E TreeLocked {locked}
translate E TreeBest {Best}
translate E TreeBestGames {Best Tree Games}
translate E TreeTitleRow  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws}
translate E TreeTotal {TOTAL}
translate E FileFinder {File Finder}
translate E FinderDir {Directory}
translate E FinderDirs {Directories}
translate E FinderFiles {Files}
translate E FinderUpDir {up}
translate E TmtLimit {List Limit}
translate E TmtMeanElo {Mean Elo}
translate E TmtNone {No matching tournaments were found.}
translate E GraphFilterTitle {Filter Graph: frequency per 1000 games}
translate E AddVariation {Add Variation}
translate E AddMove {Add Move}
translate E Annotate {Annotate}
translate E AnalysisCommand {Analysis Command}
translate E PreviousChoices {Previous Choices}
translate E AnnotateTime {Set the time between moves in seconds}
translate E AnnotateWhich {Add variations}
translate E AnnotateAll {For moves by both sides}
translate E AnnotateWhite {For White moves only}
translate E AnnotateBlack {For Black moves only}
translate E AnnotateNotBest {When game move is not best move}
translate E AnnotateBlundersOnly {When game move is an obvious poor move}
translate E AnnotateBlundersOnlyScoreChange {score from/to: }
translate E MistakesThreshold {Score for weak move (?) }
translate E BlundersThreshold {Score for blunder (??) }
translate E StopBlunderAnalysisThreshold {Disregard when winning by at least }
translate E LowPriority {Low CPU Priority}
translate E EngineList {Analysis Engine List}
translate E EngineName {Name}
translate E EngineCmd {Command}
translate E EngineArgs {Parameters}
translate E EngineDir {Directory}
translate E EngineElo {Elo}
translate E EngineTime {Date}
translate E EngineNew {New}
translate E EngineEdit {Edit}
translate E EngineRequired {Fields in bold are required; others are optional}
translate E PgnWindowTitle {Game Notation - game %u}
translate E SetFilter {Set Filter}
translate E AddToFilter {Add to Filter}
translate E Swiss {Swiss}
translate E Category {Category}
translate E RepSearch {Repertoire Search}
translate E RepIncludedLines {included lines}
translate E RepExcludedLines {excluded lines}
translate E RepCloseDialog {This repertoire has unsaved changes. Do you really want to continue and discard the changes you have made? }
translate E HeaderSearch {Header Search}
translate E EndSideToMove {Side to move at end of game}
translate E GamesWithNoECO {Games with no ECO?}
translate E GameLength {Game length}
translate E FindGamesWith {Find games with flags}
translate E StdStart {Non-standard start}
translate E Promotions {Promotions}
translate E Comments {Comments}
translate E Variations {Variations}
translate E Annotations {Annotations}
translate E DeleteFlag {Delete flag}
translate E WhiteOpFlag {White opening}
translate E BlackOpFlag {Black opening}
translate E MiddlegameFlag {Middlegame}
translate E EndgameFlag {Endgame}
translate E NoveltyFlag {Novelty}
translate E PawnFlag {Pawn structure}
translate E TacticsFlag {Tactics}
translate E QsideFlag {Queenside play}
translate E KsideFlag {Kingside play}
translate E BrilliancyFlag {Brilliancy}
translate E BlunderFlag {Blunder}
translate E UserFlag {User}
translate E PgnContains {PGN contains text}
translate E GlistNumber {Number}
translate E GlistWhite {White}
translate E GlistBlack {Black}
translate E GlistWElo {W-Elo}
translate E GlistBElo {B-Elo}
translate E GlistEvent {Event}
translate E GlistSite {Site}
translate E GlistRound {Round}
translate E GlistDate {Date}
translate E GlistYear {Year}
translate E GlistEDate {EventDate}
translate E GlistResult {Result}
translate E GlistLength {Length}
translate E GlistCountry {Country}
translate E GlistECO {ECO}
translate E GlistOpening {Opening}
translate E GlistEndMaterial {End-Material}
translate E GlistDeleted {Deleted}
translate E GlistFlags {Flags}
translate E GlistVars {Variations}
translate E GlistComments {Comments}
translate E GlistAnnos {Annotations}
translate E GlistStart {Start}
translate E GlistGameNumber {Game number}
translate E GlistFindText {Find text}
translate E GlistMoveField {Move}
translate E GlistEditField {Configure}
translate E GlistAddField {Add}
translate E GlistDeleteField {Remove}
translate E GlistWidth {Width}
translate E GlistAlign {Align}
translate E GlistColor {Color}
translate E GlistSep {Separator}
translate E GlistRemoveThisGameFromFilter  {Remove this game from Filter}
translate E GlistRemoveGameAndAboveFromFilter  {Remove game (and all above it) from Filter}
translate E GlistRemoveGameAndBelowFromFilter  {Remove game (and all below it) from Filter}
translate E DatabaseName {Database Name:}
translate E TypeIcon {Type Icon:}
translate E NumOfGames {Games:}
translate E NumDeletedGames {Deleted games:}
translate E NumFilterGames {Games in filter:}
translate E YearRange {Year range:}
translate E RatingRange {Rating range:}
translate E Description {Description}
translate E Flag {Flag}
translate E DeleteCurrent {Delete current game}
translate E DeleteFilter {Delete filter games}
translate E DeleteAll {Delete all games}
translate E UndeleteCurrent {Undelete current game}
translate E UndeleteFilter {Undelete filter games}
translate E UndeleteAll {Undelete all games}
translate E DeleteTwins {Delete twin games}
translate E MarkCurrent {Mark current game}
translate E MarkFilter {Mark filter games}
translate E MarkAll {Mark all games}
translate E UnmarkCurrent {Unmark current game}
translate E UnmarkFilter {Unmark filter games}
translate E UnmarkAll {Unmark all games}
translate E Spellchecking {Spell-checking}
translate E Players {Players}
translate E Events {Events}
translate E Sites {Sites}
translate E Rounds {Rounds}
translate E DatabaseOps {Database operations}
translate E ReclassifyGames {ECO-classify games}
translate E CompactDatabase {Compact database}
translate E SortDatabase {Sort database}
translate E AddEloRatings {Add Elo ratings}
translate E AutoloadGame {Autoload game number}
translate E StripTags {Strip PGN tags}
translate E StripTag {Strip tag}
translate E Cleaner {Cleaner}
translate E CleanerHelp1 {The ChessDB Cleaner will perform all the maintenance actions you select from the list below, on the current database.}
translate E CleanerHelp2 {Current settings in the ECO classification and twin deletion dialogs will apply if you select those functions.}
translate E CleanerConfirm1 {Once Cleaner maintenance is started, it cannot be interrupted!}
translate E CleanerConfirm2 {This may take a long time on a large database, depending on the functions you have selected and their current settings.}
translate E CleanerConfirm3 {Are you sure you want to commence the maintenance functions you selected? }
translate E AnnotationSymbols  {Annotation Symbols:}
translate E Comment {Comment:}
translate E InsertMark {Insert mark}
translate E InsertMarkHelp {Insert/remove mark: Select color, type, square.}
translate E InsertArrowHelp {Insert/remove arrow: Right-click two squares. }
translate E GoodMove {Good move}
translate E PoorMove {Poor move}
translate E ExcellentMove {Excellent move}
translate E Blunder {Blunder}
translate E InterestingMove {Interesting move}
translate E DubiousMove {Dubious move}
translate E WhiteDecisiveAdvantage {White has a decisive advantage}
translate E BlackDecisiveAdvantage {Black has a decisive advantage}
translate E WhiteClearAdvantage {White has a clear advantage}
translate E BlackClearAdvantage {Black has a clear advantage}
translate E WhiteSlightAdvantage {White has a slight advantage}
translate E BlackSlightAdvantage {Black has a slight advantage}
translate E Equality {Equality}
translate E Unclear {Unclear}
translate E Diagram {Diagram}
translate E BoardSearch {Board Search}
translate E FilterOperation {Operation on current filter:}
translate E FilterAnd {AND (Restrict filter)}
translate E FilterOr {OR (Add to filter)}
translate E FilterIgnore {IGNORE (Reset filter)}
translate E SearchType {Search type:}
translate E SearchBoardExact {Exact position (all pieces on same squares)}
translate E SearchBoardPawns {Pawns (same material, all pawns on same squares)}
translate E SearchBoardFiles {Files (same material, all pawns on same files)}
translate E SearchBoardAny {Any (same material, pawns and pieces anywhere)}
translate E LookInVars {Look in variations}
translate E MaterialSearch {Material Search}
translate E Material {Material}
translate E Patterns {Patterns}
translate E Zero {Zero}
translate E Any {Any}
translate E CurrentBoard {Current Board}
translate E CommonEndings {Common Endings}
translate E CommonPatterns {Common Patterns}
translate E MaterialDiff {Material difference}
translate E squares {squares}
translate E SameColor {Same color}
translate E OppColor {Opposite color}
translate E Either {Either}
translate E MoveNumberRange {Move number range}
translate E MatchForAtLeast {Match for at least}
translate E HalfMoves {half-moves}
translate E EndingPawns {Pawn endings}
translate E EndingRookVsPawns {Rook vs. Pawn(s)}
translate E EndingRookPawnVsRook {Rook and 1 Pawn vs. Rook}
translate E EndingRookPawnsVsRook {Rook and Pawn(s) vs. Rook}
translate E EndingRooks {Rook vs. Rook endings}
translate E EndingRooksPassedA {Rook vs. Rook endings with a passed a-pawn}
translate E EndingRooksDouble {Double Rook endings}
translate E EndingBishops {Bishop vs. Bishop endings}
translate E EndingBishopVsKnight {Bishop vs. Knight endings}
translate E EndingKnights {Knight vs. Knight endings}
translate E EndingQueens {Queen vs. Queen endings}
translate E EndingQueenPawnVsQueen {Queen and 1 Pawn vs. Queen}
translate E BishopPairVsKnightPair {Two Bishops vs. Two Knights middlegame}
translate E PatternWhiteIQP {White IQP}
translate E PatternWhiteIQPBreakE6 {White IQP: d4-d5 break vs. e6}
translate E PatternWhiteIQPBreakC6 {White IQP: d4-d5 break vs. c6}
translate E PatternBlackIQP {Black IQP}
translate E PatternWhiteBlackIQP {White IQP vs. Black IQP}
translate E PatternCoupleC3D4 {White c3+d4 Isolated Pawn Couple}
translate E PatternHangingC5D5 {Black Hanging Pawns on c5 and d5}
translate E PatternMaroczy {Maroczy Center (with Pawns on c4 and e4)}
translate E PatternRookSacC3 {Rook Sacrifice on c3}
translate E PatternKc1Kg8 {O-O-O vs. O-O (Kc1 vs. Kg8)}
translate E PatternKg1Kc8 {O-O vs. O-O-O (Kg1 vs. Kc8)}
translate E PatternLightFian {Light-Square Fianchettos (Bishop-g2 vs. Bishop-b7)}
translate E PatternDarkFian {Dark-Square Fianchettos (Bishop-b2 vs. Bishop-g7)}
translate E PatternFourFian {Four Fianchettos (Bishops on b2,g2,b7,g7)}
translate E Today {Today}
translate E ClassifyGame {Classify game}
translate E EmptyBoard {Empty board}
translate E InitialBoard {Initial board}
translate E SideToMove {Side to move}
translate E MoveNumber {Move number}
translate E Castling {Castling}
translate E EnPassantFile {En Passant file}
translate E ClearFen {Clear FEN}
translate E PasteFen {Paste FEN}
translate E ReplaceMove {Replace move}
translate E AddNewVar {Add new variation}
translate E ReplaceMoveMessage1 {A move already exists here.}
translate E ReplaceMoveMessage2 {You can replace it, discarding all moves after it, or add your move as a new variation.}
translate E ReplaceMoveMessage3 {(You can avoid seeing this message in future by turning off the "Ask before replacing moves" option in the Options:Moves menu.)}
translate E ReadOnlyDialog1 {If you make this database read-only, no changes will be permitted. No games can be saved or replaced, and no delete flags can be altered. Any sorting or ECO-classification results will be temporary.}
translate E ReadOnlyDialog2 {You can easily make the database writable again, by closing and reopening it.}
translate E ReadOnlyDialog3 {Do you really want to make this database read-only?}
translate E ClearGameDialog {This game has been altered. Do you really want to continue and discard the changes made to it? }
translate E ExitDialog {Do you really want to exit ChessDB?}
translate E ExitUnsaved {The following databases have unsaved game changes. If you exit now, these changes will be lost.}
translate E PasteCurrentGame {Paste current game}
translate E ImportHelp1 {Enter or paste a PGN-format game in the frame above.}
translate E ImportHelp2 {Any errors importing the game will be displayed here.}
translate E ECOAllSections {all ECO sections}
translate E ECOSection {ECO section}
translate E ECOSummary {Summary for}
translate E ECOFrequency {Frequency of subcodes for}
translate E OprepTitle {Opening Report}
translate E OprepReport {Report}
translate E OprepGenerated {Generated by}
translate E OprepStatsHist {Statistics and History}
translate E OprepStats {Statistics}
translate E OprepStatAll {All report games}
translate E OprepStatBoth {Both rated}
translate E OprepStatSince {Since}
translate E OprepOldest {Oldest games}
translate E OprepNewest {Newest games}
translate E OprepPopular {Current popularity}
translate E OprepFreqAll {Frequency in all years:   }
translate E OprepFreq1   {In the  1 year  to today: }
translate E OprepFreq5   {In the  5 years to today: }
translate E OprepFreq10  {In the 10 years to today: }
translate E OprepEvery {once every %u games}
translate E OprepUp {up %u%s from all years}
translate E OprepDown {down %u%s from all years}
translate E OprepSame {no change from all years}
translate E OprepMostFrequent {Most frequent players}
translate E OprepMostFrequentOpponents {Most frequent opponents}
translate E OprepRatingsPerf {Ratings and Performance}
translate E OprepAvgPerf {Average ratings and performance}
translate E OprepWRating {White rating}
translate E OprepBRating {Black rating}
translate E OprepWPerf {White performance}
translate E OprepBPerf {Black performance}
translate E OprepHighRating {Games with highest average rating}
translate E OprepTrends {Result Trends}
translate E OprepResults {Result lengths and frequencies}
translate E OprepLength {Game length}
translate E OprepFrequency {Frequency}
translate E OprepWWins {White wins: }
translate E OprepBWins {Black wins: }
translate E OprepDraws {Draws:      }
translate E OprepWholeDB {whole database}
translate E OprepShortest {Shortest wins}
translate E OprepMovesThemes {Moves and Themes}
translate E OprepMoveOrders {Move orders reaching the report position}
translate E OprepMoveOrdersOne {There was only one move order reaching this position:}
translate E OprepMoveOrdersAll {There were %u move orders reaching this position:}
translate E OprepMoveOrdersMany {There were %u move orders reaching this position. The top %u are:}
translate E OprepMovesFrom {Moves from the report position}
translate E OprepMostFrequentEcoCodes {Most frequent ECO codes}
translate E OprepThemes {Positional Themes}
translate E OprepThemeDescription {Frequency of themes in the first %u moves of each game}
translate E OprepThemeSameCastling {Same-side castling}
translate E OprepThemeOppCastling {Opposite castling}
translate E OprepThemeNoCastling {Both Kings uncastled}
translate E OprepThemeKPawnStorm {Kingside pawn storm}
translate E OprepThemeQueenswap {Queens exchanged}
translate E OprepThemeWIQP {White Isolated Queen Pawn}
translate E OprepThemeBIQP {Black Isolated Queen Pawn}
translate E OprepThemeWP567 {White Pawn on 5/6/7th rank}
translate E OprepThemeBP234 {Black Pawn on 2/3/4th rank}
translate E OprepThemeOpenCDE {Open c/d/e file}
translate E OprepTheme1BishopPair {Only one side has Bishop pair}
translate E OprepEndgames {Endgames}
translate E OprepReportGames {Report games}
translate E OprepAllGames    {All games}
translate E OprepEndClass {Material at the end of each game}
translate E OprepTheoryTable {Theory Table}
translate E OprepTableComment {Generated from the %u highest-rated games.}
translate E OprepExtraMoves {Extra note moves in theory table}
translate E OprepMaxGames {Maximum games in theory table}
translate E OprepViewHTML {View HTML}
translate E OprepViewLaTeX {View LaTeX}
translate E PReportTitle {Player Report}
translate E PReportColorWhite {with the White pieces}
translate E PReportColorBlack {with the Black pieces}
translate E PReportMoves {after %s}
translate E PReportOpenings {Openings}
translate E PReportClipbase {Empty clipbase and copy matching games to it}
translate E TrackerSelectSingle {Left mouse button selects this piece.}
translate E TrackerSelectPair {Left mouse button selects this piece; right button also selects its sibling.}
translate E TrackerSelectPawn {Left mouse button selects this pawn; right button selects all 8 pawns.}
translate E TrackerStat {Statistic}
translate E TrackerGames {% games with move to square}
translate E TrackerTime {% time on each square}
translate E TrackerMoves {Moves}
translate E TrackerMovesStart {Enter the move number where tracking should begin.}
translate E TrackerMovesStop {Enter the move number where tracking should stop.}
translate E SelectAllGames {All games in the database}
translate E SelectFilterGames {Only games in the filter}
translate E SelectTournamentGames {Only games in the current tournament}
translate E SelectOlderGames {Only older games}
translate E TwinsNote1 {To be twins, two games must at least have the same two players, and criteria you can set below. When a pair of twins is found, the shorter game is deleted.}
translate E TwinsNote2 {Hint: it is best to spellcheck the database before deleting twins, since it improves twin detection. }
translate E TwinsCriteria {Criteria: Twin games must have...}
translate E TwinsWhich {Examine which games}
translate E TwinsColors {Same player colors?}
translate E TwinsEvent {Same event?}
translate E TwinsSite {Same site?}
translate E TwinsRound {Same round?}
translate E TwinsYear {Same year?}
translate E TwinsMonth {Same month?}
translate E TwinsDay {Same day?}
translate E TwinsResult {Same result?}
translate E TwinsECO {Same ECO code?}
translate E TwinsMoves {Same moves?}
translate E TwinsPlayers {Comparing player names:}
translate E TwinsPlayersExact {Exact match}
translate E TwinsPlayersPrefix {First 4 letters only}
translate E TwinsWhen {When deleting twin games}
translate E TwinsSkipShort {Ignore all games under 5 moves long?}
translate E TwinsUndelete {Undelete all games first?}
translate E TwinsSetFilter {Set filter to all deleted twin games?}
translate E TwinsComments {Always keep games with comments?}
translate E TwinsVars {Always keep games with variations?}
translate E TwinsDeleteWhich {Delete which game:}
translate E TwinsDeleteShorter {Shorter game}
translate E TwinsDeleteOlder {Smaller game number}
translate E TwinsDeleteNewer {Larger game number}
translate E TwinsDelete {Delete games}
translate E NameEditType {Type of name to edit}
translate E NameEditSelect {Games to edit}
translate E NameEditReplace {Replace}
translate E NameEditWith {with}
translate E NameEditMatches {Matches: Press Ctrl+1 to Ctrl+9 to select}
translate E Classify {Classify}
translate E ClassifyWhich {ECO-Classify which games}
translate E ClassifyAll {All games (overwrite old ECO codes)}
translate E ClassifyYear {All games played in the last year}
translate E ClassifyMonth {All games played in the last month}
translate E ClassifyNew {Only games with no ECO code yet}
translate E ClassifyCodes {ECO Codes to use}
translate E ClassifyBasic {Basic codes only ("B12", ...)}
translate E ClassifyExtended {ChessDB extensions ("B12j", ...)}
translate E NameFile {Name file}
translate E GameFile {Game file}
translate E Names {Names}
translate E Unused {Unused}
translate E SizeKb {Size (kb)}
translate E CurrentState {Current State}
translate E AfterCompaction {After compaction}
translate E CompactNames {Compact name file}
translate E CompactGames {Compact game file}
translate E SortCriteria {Criteria}
translate E AddCriteria {Add criteria}
translate E CommonSorts {Common sorts}
translate E Sort {Sort}
translate E AddToExistingFile {Add games to an existing file?}
translate E ExportComments {Export comments?}
translate E ExportVariations {Export variations?}
translate E IndentComments {Indent comments?}
translate E IndentVariations {Indent variations?}
translate E ExportColumnStyle {Column style (one move per line)?}
translate E ExportSymbolStyle {Symbolic annotation style:}
translate E ExportStripMarks {Strip square/arrow mark codes from comments?}
translate E LoadGameNumber {Enter the game number to load:}
translate E GotoMoveNumber {Goto move number:}
translate E CopyGames {Copy games}
translate E CopyConfirm1 {Do you really want to copy}
translate E CopyConfirm2 {the [::utils::thousands $nGamesToCopy] filtered games }
translate E CopyConfirm3 {in the database "$fromName" } 
translate E CopyConfirm4 {to the database "$targetName"? }
translate E CopyErr {Cannot copy games}
translate E CopyErrSource {the source database}
translate E CopyErrTarget {the target database}
translate E CopyErrNoGames {has no games in its filter}
translate E CopyErrReadOnly {is read-only}
translate E CopyErrNotOpen {is not open}
translate E LightSquares {Light squares}
translate E DarkSquares {Dark squares}
translate E SelectedSquares {Selected squares}
translate E SuggestedSquares {Suggested move squares}
translate E WhitePieces {White pieces}
translate E BlackPieces {Black pieces}
translate E WhiteBorder {White border}
translate E BlackBorder {Black border}
translate E FindNovelty {Find Novelty}
translate E Novelty {Novelty}
translate E NoveltyInterrupt {Novelty search interrupted}
translate E NoveltyNone {No novelty was found for this game}
translate E NoveltyHelp {ChessDB will find the first move of the current game that reaches a position not found in the selected database or in the ECO openings book.}
translate E SoundsFolder {Sound Files Folder}
translate E SoundsFolderHelp {The folder should contain the files King.wav, a.wav, 1.wav, etc}
translate E SoundsAnnounceOptions {Move Announcement Options}
translate E SoundsAnnounceNew {Announce new moves as they are made}
translate E SoundsAnnounceForward {Announce moves when moving forward one move}
translate E SoundsAnnounceBack {Announce when retracting or moving back one move}
translate E Upgrading {Upgrading}
translate E ConfirmOpenNew {This is an old-format (Scid 2) database that cannot be opened in ChessDB 3, but a new-format (ChessDB 3) version has already been created. Do you want to open the new-format version of the database?}
translate E ConfirmUpgrade { This is an old-format (Scid 2) database. A new-format version of the database must be created before it can be used in ChessDB 3.  Upgrading will create a new version of the database; it will not edit or remove the original files.  This may take a while, but it only needs to be done one time. You can cancel if it takes too long. Do you want to upgrade this database now?}
translate E RecentFilesMenu {Number of recent files in File menu}
translate E RecentFilesExtra {Number of recent files in extra submenu}
translate E MyPlayerNamesDescription1 { Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.}
translate E MyPlayerNamesDescription2 {Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.}
translate E showblunderexists {show blunder exists}
translate E showblundervalue {show blunder value}
translate E showscore {show score}
translate E coachgame {coach game}
translate E configurecoachgame {configure coach game}
translate E Phalanxengine {Phalanx engine}
translate E Coachengine {Coach engine}
translate E difficulty {difficulty}
translate E hard {hard}
translate E easy {easy}
translate E Playwith {Play with}
translate E white {white}
translate E black {black}
translate E Play {Play}
translate E Noblunder {No blunder}
translate E blunder {blunder}
translate E Noinfo {-- No info --}
translate E selectCoachEngines {Select a Phalanx engine in the left list and a coach engine in the right list (a Crafty engine is preferable as coach)}
translate E moveblunderthreshold {move is a blunder if loss is greater than}
translate E limitanalysis {limit engine analysis time}
translate E seconds {seconds}
translate E Abort {Abort}
translate E TitleCanNotWriteDir {Error: Can't write to directory}
translate E CanNotWriteToDirectory {ChessDB was unable to write to the directory} 
translate E CanNotWriteFile {ChessDB was unable to open the following file for writing:} 
translate E CanNotWriteFile2 {Check the disk space and permissions} 
translate E CanNotReadFile {ChessDB was unable to read the following file:} 
translate E TitleCanNotOpenFile {ChessdDB Error: Can't open file} 
translate E OverwrriteFilesIfPresent {Overwrite files of the same name in}
translate E OverwrriteDBFilesIfPresent {Overwrite the database files (.sg3, si3 & .sn3) in}
translate E FilesFromTWICPlaced {Files from the TWIC web site will be put in} 
translate E NewDatabaseWillBeCreated {A new ChessDB database will be created in }
translate E NewPGNWillBeCreated {A new PGN file will be created, which will hold the contents of all the files downloaded from the TWIC website. The new PGN file will be:}
translate E ProblemWithWriteAcessToDatabaseFiles {You chose to create a database, but one or more of the database files exists. Since you chose not to overwrite the database files, this can not be done. Either don't create the database, move or delete the database files or change the tickbox to overwrite the database files in}
translate E Appending {Appending}
translate E ToTheEndOf {on to the end of}
translate E ActionsToBePerformed {Actions to be performed}
translate E DownloadLog {Log of actions performed}
translate E DatabaseCreated {A new database 'newgames' has been created, based on the contents of the TWIC web site}
translate E NewPGNCreated {A new PGN file 'newgames.pgn' has been created, based on the contents of the TWIC web site}
translate E Warning {Warning:}
translate E ErrorsDetectedWhenCreatingDatabase {Some errors were detected when creating the database. They were:}
translate E AutomaticallyDetermineNextDownload {Automatically set first issue to download}
translate E DownloadToLastCopyOnTWICWebSite {Download to the latest issue}
translate E ShouldYouChose {Should you chose to use use the automatic method to determine the first issue to download, next time the program will start on issue}
translate E CreateNeither {You selected neither to create a database or the large PGN file. Therefore there is nothing to do!}
translate E IfUsingManualYouMustEnterValue {If you select to manually choose an issue or issues to download, you must enter a value. This will need to be between 210 and the latest issue on TWIC. Based on the clock in your computer, the latter is estimated to be approximately}
translate E FileCorruption {ChessDB Error: File Corrupted}
translate E TheLengthOfFileIsNotCorrect {The following file should be of 4 or 5 bytes long, but it is not:}
translate E FirstIssueInFileTooLarge1 {The file}
translate E FirstIssueInFileTooLarge2 {requests downloads start at issue}
translate E FirstIssueInFileTooLarge3 {but that is unrealistically large. First check the date on your computer, as the estimate of what is unrealistic or not is based on the date. If the date is correct, set the first issue manually this time only, just in case it was an odd case of corruption. Check for an updated version of ChessDB (see 'Check for Updates' in the 'Help' menu)}
translate E ReportPossibleInternalError {Please  email chessdb-users@lists.sourceforge.net to report this, since this should generally not happen and may indicate an internal error in ChessDB, which the developers would like to correct.}
translate E butLastFileIndicates {but the file 'last-file.txt' indicates the next issue to download is less than that}
translate E FirstIssueGreaterLastIssue {The first issue must be less than or equal to the last issue}
translate E UserError {ChessDB: User Error}
translate E TitleNeedUnzip {ChessDB: Unzip not found}
translate E Needpgnchessdb {The executable program pgnchessdb can't be found - its impossible to continue without that.}
translate E LookAtTutorial {Please look at the online tutorial at http://chessdb.sourceforge.net/tutorial/ The online documentation is always the most accurate, as the website is updated much more frequently than any other documentation.}
translate E NumberOfHelpPages {ChessDB has 46 online help pages; just press F1 for help!}
translate E StartupCompleted {Start-up completed}
translate E ReviewStartupCompleted {Review the above log to ensure you can make best use of ChessDB. You may need to configure a chess engine later.}
translate E FoundThreePieceTablebases {You have only the 3-piece tablebases configured. These are all that comes with ChessDB, but the 4-piece and 5-piece can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/ (The 4-piece, but not 5-piece tablebases can also be downloaded from Sourceforge in the 'extras' package.) Be aware, the 5-piece tablebases require 7.1 GB of disk space - the 4-piece ones need a more modest 30 MB}
translate E FoundFourPieceTablebases {You have at least some (possibly all) of the 4-piece tablebases configured, but do not have any 5-piece ones. The 5-piece tablebases can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/, but be aware the complete set requires 7.1 GB of disk space, so you may prefer to use just the 4-piece ones you have configured.}
translate E FoundFivePieceTablebases {You have at least some (possibly all) of the 5-piece tablebases configured. They are the largest ChessDB supports. You are advised to make sure you have them all - any missing ones can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/}
translate E CheckingForTablebaseFiles {Checking for Nalimov endgame tablebase files...}
translate E ChessDBWebsite {Website: http://chessdb.sourceforge.net/}
translate E ChessDBBasedOnScid {ChessDB is based on Scid -  http://scid.sourceforge.net/ but has new features, enhancements and bug-fixes. More than 90% of ChessDB's code comes from Scid.}
translate E MainScidAuthor {The main author of Scid was Shane Hudson}
translate E ShaneNoBugs {Shane is NOT responsible for any bugs in ChessDB}
translate E SeeTutorial {Please see the online tutorial at http://chessdb/sourceforge.net/tutorial/}
translate E GPL {ChessDB is distributed under the terms of the GNU General Public License}
translate E Copyright {Copyright (C)}
translate E AboutChessDB {About ChessDB}
translate E FastStart {Fast start: no tablebases, ECO or spelling file loaded.}
translate E TryECO {Trying to load the ECO openings file...}
translate E CantLoadSpellcheck {Unable to load the default spellcheck file}
translate E ErrorCantLoadDatbase {Error: could not open database}
translate E Email {Email:}
translate E TextAt {Text at}
translate E start {start}
translate E end {end}
translate E file {file}
translate E ResetToDefault {Reset to default}
translate E SetPGNFileExportText {ChessDB: Set PGN file export text}
translate E SetHTMLFileExportText {ChessDB: Set HTML file export text}
translate E SetLaTexFileExportText {ChessDB: Set LaTex file export text}
translate E ErrorOpening {Error opening}
translate E ErrorOpeningEPDFile {Error opening EPD file}
translate E OpeningEPDFile {Opening EPD file:}
translate E OpeningRepertoireFile {Opening repertoire file:}
translate E UnableToMergeGame {Unable to merge the selected game:}
translate E SubscribeToMailingList {Please subscribe to the chessdb-users@lists.sourceforge.net mailing list by visiting https://lists.sourceforge.net/lists/listinfo/chessdb-users}
translate E SettingUpAudio {Setting up audio move announcement...}
translate E SeachingSounds {Searching sounds folder for move announcement sounds...}
translate E NoSnack {Move speech disabled - Snack sound package 2.0 or later was not found}
translate E Snack {Move speech enabled - Snack sound package 2.0 or later was found}
translate E ConfigureSoundDir {Although you have the sound package installed, not all sounds were found. Select the directory from the Options Menu}
translate E Found {Found}
translate E of {of}
translate E soundFilesIn {sound files in}
translate E WarningUnknownOption {Warning: unknown option:}
translate E TryingToLoadTheECOOpeningsFile {Trying to load the ECO openings file...}
translate E UnableToOpenTheECOOpeningsFile {Unable to open the ECO file:}
translate E ConfiguringSpellingAndRatings {Configuring spellings and ratings - please wait.}
translate E TryingToLoadTheSpellingFile {Since the spelling and rating file (ratings.ssp) was not found, ChessDB will try to load the spellcheck file without ELO ratings (spelling.ssp)}
translate E TryingToLoadTheSpellingAndRatingsFile {First trying to load the spellcheck file which has ELO ratings too:}
translate E ThisCanBeSlowToLoad {This can be slow to load, so if you do not want to add ELO ratings, use spelling.ssp instead, which will load much faster.}
translate E UnableToOpenTheSpellCheckFile {Unable to open the spellcheck only file either}
translate E UnableToOpenTheSpellingAndRatingsFile {Unable to open the spellcheck and rating file:}
translate E NeitherSpellingOrRatingFilesFound {Neither the spellling+rating file (ratings.ssp) or the spellcheck only file (spelling.ssp) could be loaded. These were included with ChessDB. You may need to set the directory on the Options menu}
translate E positions {positions}
translate E SpellcheckFile {Spellcheck file}
translate E SpellcheckAndRatingsFile {Spellcheck and ratings file}
translate E loaded {loaded}
translate E DocumentationAndSupport {Documentation and support}
translate E CopyrightHistoryLicence {Copyright, History and License}
translate E NoTablebasesFoundWindows {No tablebases were found. The small 3-piece tablesbases are included in ChessDB in a directory 'tablebases' (typically C:>\Program Files\ChessDB\tablebases\) so you should configure ChessDB to use them by setting the Tablebase Directory on the Options menu. The 4 piece tablebases (which take up about 30 MB) and 5 piece tablebases (which use about 7.1 GB of disk space) are not included in ChessDB due to their size. They can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/ (The 4-piece, but not 5-piece tablebases can also be downloaded from Sourceforge in ChessDB's 'extras' package)}
translate E NoTablebasesFoundUNIX {No tablebases were found. The small 3-piece tablesbases are included in ChessDB in a directory 'tablebases' so you should configure ChessDB to use them by setting the Tablebase Directory on the Options menu. The 4 piece tablebases (which take up about 30 MB) and 5 piece tablebases (which use about 7.1 GB of disk space) are not included in ChessDB due to their size. They can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/ (The 4-piece, but *not* 5-piece tablebases can also be downloaded from Sourceforge in ChessDB's 'extras' package)}
translate E ConvertNullMovesToComments {Convert null moves to comments}
translate E Random {Random}
translate E GotoTheFirstPageOfGames {Go to the first page of games}
translate E GotoTheLastPageOfGames {Go to the last page of games}
translate E PreviousPageOfGames {Previous page of games}
translate E NextPageOfGames {Next page of games}
translate E NoGamesInCurrentFiler {There are no games in the current filter}
translate E ChessDBSaveGameList {ChessDB: Save Game List}
translate E SavingGameList {Saving game list...}
translate E databases {databases}
translate E All {All}
translate E files {files}
translate E TooManyDatabasesOpen {Too many databases open; close one first}
translate E OpenAChessDBFile {Open a ChessDB file}
translate E ErrorOpeningFile {ChessDB: Error opening file}
translate E UnableToUpgradeTheDatabase {Unable to upgrade the database}
translate E Opening {Opening}
translate E ReadOnly {read-only...}
translate E text {text}
translate E HashChessDBOptiomFile {ChessDB options file}
translate E HashInTclFormat {This file contains commands in the Tcl language format}
translate E HashVersion    {Version:}
translate E HashIfYouEdit {If you edit this file, you must preserve its valid Tcl}
translate E HashformatOrNotSet {format or it will not set your ChessDB options properly}
translate E ProxyHost {HTTP Proxy Host}
translate E ProxyPort {HTTP Proxy Port}
translate E Logo {Thanks to James Mossop who designed the logo.}
translate E DownloadOptions {ChessDB: Download options}
translate E ICCuser { ICC username}
translate E FICSuser { FICS username}
translate E ICCserver {ICC server}
translate E FICSserver {FICS server}
translate E ICCpass {ICC password}
translate E FICSpass {FICS password}
translate E Port {Port}
translate E SavePassword {Save password}
translate E NotEncrypted {WARNING: Saved as plain text - not encrypted at all.}
translate E WeakEncryption {WARNING: Only a very weak encryption is used.}
translate E ExtraTags {Extra Tags}
translate E AsLastGame {As last game}
translate E Databases {Databases}
translate E Notation {Notation}
translate E UpToMove {Up to move}
translate E OK {OK}
translate E bitmaps {bitmaps}
translate E bitmaps2 {bitmaps2}
translate E AutoCloseAfterStartup {Auto-close after startup}
translate E SelectUptoFour1 {Select up to 4 table base *directories*}
translate E ByClicking {By clicking any tablebase *file* in a directory}
translate E IKnowConfusing {This bit is a bit confusing I know, but it verifies the tablebases are compatible}
translate E LookingForOptionsFile {Looking for your options file}
translate E OptionsFound {Your options file}
translate E WasFoundAndLoaded {was found and loaded}
# The text is printed is "$DownloadGamesFromPre $server $DownloadGamesFromPost"
# so by setting either the pre or the post item, you can have your text 
# either before or after the server name. 
translate E DownloadGamesFromPre {Download games from}
translate E DownloadGamesFromPost { }
translate E OnlyCompleteGames {Completed games only}
translate E CompletedAndAdjourned {Completed and adjourned games}
translate E Download {Download}
translate E UsernamesFromFile {usernames from file}
translate E UsernamesFromList {usernames from list}
translate E ChessDBChooseECORange {ChessDB: Choose ECO Range}
translate E ChessDBSearchOptionsFiles {ChessDB SearchOptions files}
translate E UnabletocreateSearchOptionsfile {Unable to create SearchOptions file:}
translate E Textfile {Text file}
translate E CreateSearchOptionsfile {Create a SearchOptions file}
translate E CreateListOf {Create list of}
translate E usernames {usernames}
translate E UnableToCreatelistOfUsername {Unable to create a list of user names}
translate E HeaderSearchOptionSsavedTo {Header search options saved to}
translate E UserNameList {User name list}
translate E MainHelpIndex {Index of all help pages} 
translate E HelpOnDownloadingChessServer {Help on downloading games from}
translate E Connectto {Connect to}
translate E CloseConnection {Close connection}
translate E ConfigureSettings {Set server, username, password and port}
translate E OutputFromChessServer {Output from the chess server will be shown here}
translate E CurrentlyOnlyDemo {This part of the code is currently NON-FUNCTIONAL, as it has not been developed fully at this time.}
translate E CommandToChessServer {Once connected, commands typed here will be sent to the chess server}
translate E Login {Login}
translate E Logout {Logout} 
translate E ZipfileTooShort {The ZIP File is too small (< 5000 bytes) to be one of TWIC's zip files. Aborting....}
translate E TitleZipfileTooShort {The ZIP File is too small}
translate E TitleUnliklyLastIssue {Last Issue is unrealistic}
translate E UnliklyLastIssue1 {The last issue you requested is not a practical value. Based on the date on your computer, the last TWIC issue is estimated to be very approximately}
translate E UnliklyLastIssue2 {Therefore a request for an issue of}
translate E UnliklyLastIssue3 {or more is considered to be an error by ChessDB.}
translate E UnliklyLastIssue4 {Therefore your request to retrieve up to issue}
translate E UnliklyIssue      {will not be attempted. }
translate E IfyouBeliveAnError {If you believe this is incorrect, please check the date on your computer, check for an updated version of ChessDB, or email chessdb-users@lists.sourceforge.net for further advice.}
translate E UnliklyFirstIssue1 {The first issue you requested is not a practical value. Based on the date on your computer, the latest TWIC issue is estimated to be very approximately}
translate E UnliklyFirstIssue2 {so a request for issues starting at}
translate E UnliklyFirstIssue3 {or more is considered to be an error by ChessDB. Therefore your request to retrieve TWIC issues starting at}
translate E ImportToCurrentDatabase {Import games to the current database}
translate E CreateLargePGNofGames {Create a large PGN file of games}
translate E AutomaticallySetFirstIssue {Automatically set first issue}
translate E DoNothingAtAll {You have not chosen to create a large PGN file or to read games into the current database. Therefore there is nothing to do! Please go back and choose one or both of these}
translate E GamesWillBeReadToCurrent {Games will be imported into the current database}
translate E NewPGNandCurrent {If you selected 'Import games to the current database' the games should be there now. If you selected 'Create a large PGN file of games' the PGN file will be called 'newgames.pgn' in the directory}
translate E CurrentDatabaseReadOnly {The current database is read-only, so you can not import games into it}
translate E NotOpenDatabase {The current database is not open, so you can not import games into it} 
translate E WarningCurrentDatabaseHasGames1 {The current database has}
translate E WarningCurrentDatabaseHasGames2 {games in it. Importing games will not overwrite these, it will simply add the new games to the database. Please check that you have selected the right database - one would for example generally not want to add games from TWIC, ICC, or FICS to a database of your own games.}
translate E WarningCurrentDatabaseHasGames3 {OK to proceed and download games into the current database?}
translate E WarningCurrentDatabaseHasGames4 {games in it. Importing games will not overwrite these, it will simply add the new games to the current database.}
translate E WarningCurrentDatabaseHasGames5 {Please check that you have the right database and the right directory. It is much easier to double-check now, than to try removing the games later if you accidently put them in the wrong database!}
translate E WarningCurrentDatabaseHasGames6 {Continue, and import the games?}
translate E WarningCurrentDBNotEmpty {Warning - the current database is not empty}
translate E WithSomeEngines {With some engines, you will not see any analysis until the board changes. So if you see this message, try changing the board by moving backwards or forwards or making a new move.}
translate E AnalysisEnginesList {Analysis engines list file for ChessDB}
translate E Doyoureallywant {Do you really want to remove this engine from the list?}
translate E TheNameCommand {The Name, Command and Directory fields must not be empty.}
translate E NOTELogFileSizelimit {NOTE  : Log file size limit reached; closing log file.}
translate E UnableToStartTheProgram {Unable to start the program:}
translate E EngineCommunicationLog {ChessDB-Engine communication log file}
translate E ThisFileWasAutomatically {This file was automatically generated by ChessDB.}
translate E ItIsRewritten {It is rewritten every time an engine is started in ChessDB.}
translate E ChessDBAnalysis {ChessDB: Analysis:}
translate E QuietEngine {Quiet engine (still no output); sending it initial commands.}
translate E Engine {Engine}
translate E EngineTerminatedWithout {The analysis engine terminated without warning; it probably crashed or had an internal error.}
translate E SeenCrafty {Seen Crafty; assuming analyze and setboard commands.}
translate E SetEngingThinkingTime {Set the engine thinking time per move in seconds:}
translate E SorryNonStandard {Sorry, this game has a non-standard start position.}
translate E ShareTags {Share tags}
translate E undeletesBoth {undeletes both}
translate E noTwin {no twin} 
translate E NoDuplicatesDetectedFor {No duplicates detected for this game}
translate E TwinGameChecker {Twin game checker}
translate E ToShowTwinGams {To show twins using this window you must first use the 'Delete twin games' function}
translate E Downloads {Downloads}
translate E PreviousPair {Previous pair}
translate E NextPair {Next pair}
translate E ChessDBfound  {ChessDB found}
translate E PlayerNameCorrections {player name corrections, the first}
translate E areListedBelow {are listed below.}
translate E EditTheList {Edit the list to remove any corrections you do not want.}
translate E OnlyLinesOf {Only lines of the form:}
translate E OldNameToNewName { 'Old Name' >> 'New Name'}
translate E withNoSpaces {(with no spaces before the 'Old Name') are processed.}
translate E Ambiguous {Ambiguous}
translate E Surnames {Surnames}
translate E YouCanDisreguardA {You can discard a correction you do not want by deleting its line, or simply by adding a space or any other character at the start of the line}
translate E ToggleAnalysisBoard {Show/Hide Analysis Board}
translate E ShowAnalysisBoard {Show Analysis Board}
translate E HideAnalysisBoard {Hide Analysis Board}
translate E Score {Score}
translate E Depth {Depth}
translate E Nodes {Nodes}
translate E Time {Time}
translate E YourMove {Your move...... }
translate E Thinking {Thinking....... }
translate E SetEngineThinkingTime {Set the engine thinking time per move in seconds:}
translate E DoYouReally {Do you really want to remove this engine from the list?}
translate E NameCommandAndDir {The Name, Command and Directory fields must not be empty.}
translate E NoExtraTags {No extra tags were found}
translate E FirstLineFrom {First line from engine seen; sending it initial commands now.}
translate E Crafty18White {Crafty version is >= 18.0; assuming scores are from White perspective.}
translate E TitleEnginethinkingtime {ChessDB Engine thinking time}
translate E SoundOptions {Sound Options}
translate E FreeChessDatabase {ChessDB: A free Chess Database}
translate E UsingTclTkVersion {Using Tcl/Tk version:}
translate E Maintainer {Maintainer: Dr. David Kirkby}
translate E emailDave {Email: drkirkby@users.sourceforge.net}
translate E SearchOptionsSaved {Material/pattern search options saved to file:}
translate E TitleSearchOptionsSaved {Search Options saved}
translate E ExtraTagsEgAnand {Extra Tags: (example format: Annotator "Anand, V")}
translate E YouWereNotLoggedIn {You are not currently logged in to the chess server, so you can not log out}
translate E TitleYouWereNotLoggedIn  {ChessDB: Logout error}
translate E TitleCreateRepertore {Create a repertoire file}
translate E NonStartedStartNoRepertoir {The current game does not have the standard starting position, so its positions cannot be added to the repertoire.}
translate E RepetoireFiles {ChessDB repertoire files}
translate E AreYouSureDeleteRepGroup {Are you sure you want to delete this group, keeping all the groups and lines under it?}
translate E AreYouSureRecursivelyDeleteRepGroups {Are you sure you want to delete this group, AND ALL the groups and lines under it?}
translate E AreYouSureDeleteLine {Are you sure you want to delete this line?}
translate E TitleDeleteGroup {ChessDB: Delete group?}
translate E TitleDeleteLine  {ChessDB: Delete line?}
translate E NotLoggedOInNoDownload {You are not logged into the chess server, so can not download games. Please press 'Login' first.}
translate E TitleNotLoggedOInNoDownload {Error: Not logged in}
translate E ICCLimitOnGames {Note, the Internet Chess Club (ICC) limits the number of attempts that be made to download games in quick succession to 100. Once 100 have been attempted (whether or not they could all be downloaded), ICC server will simply reply "Game database temporarily unavailable". Since you have requested data on 6 or more players, each assumed to have 20 games in their history, this limit will be reached. After 100 attempts are made, there will be a long delay (x seconds), before any more are dowloads are attempted. ChessDB will resume once the ICC server will allow it. Note, the exact details of what limits the ICC server is programmed with are not known, so best guesses are used. If you see the message "Game database temporarily unavailable", please report the circumstances to the ChessDB mailing list.}
translate E ICCLimitOnGames1 {Note, the Internet Chess Club (ICC) limits the number of attempts that be made to download games in quick succession to 100. Once 100 have been attempted (whether or not they could all be downloaded), ICC server will simply reply "Game database temporarily unavailable" It will stay like this for some time (approximately 80s)  before allowing further downloads}
translate E ICCLimitOnGames2 {Since you have requested data on 6 or more players, each assumed to have 20 games in their history, this limit will be reached. After 100 attempts are made, there will be a long delay (80 seconds), before any more dowloads are attempted. ChessDB will resume once it believes the ICC server will allow it.}
translate E ICCLimitOnGames3 {Note, the exact details of what limits the ICC server is programmed with are not known, so best guesses are used. If you see the message "Game database temporarily unavailable", please report the circumstances to the ChessDB mailing list. If you know the parameters ICC use, then please let us know, so best use can be made of this facility} 
translate E TitleICCLimitOnGames {ICC database limit}
translate E EmailAddressFields {Email address fields:}
translate E Downloading {Please Wait !!}
translate E DownloadsComplete {An attempt has been made to download the histories of all the players. If ICC's database became unavailable, (as it sometimes does with rapid downloads), then they may not be complete. Double check the number of games. Assuming you have all the games, you may close the database if you wish. You are still logged in, so log out if you wish.}

translate E TitleDownloadsComplete {Downloads complete}
translate E WillSlowNow {The downloads from ICC will slow now quite considerably, from one every 500 ms to one every 60 seconds. This is because the ICC server is configured to restrict the rate at which games can extracted from the database. A message will be printed when all games are downloaded - until then, please keep the database open. You can leave ChessDB unattended - perhaps take a break while the downloads continue at the reduced rate. }
translate E WillSlowNow2 {If you want to get the games as fast as possible, save the database, log out, then back in again, after which you can download another 100 games very quickly.}
translate E TitleWillSlowNow {Downloads will slow down}
translate E DatabaseUnavailable {ICC's database is temporarily unavailable. This will happen if a lot of games are downloaded in a short time. ChessDB tries to avoid this, by slowing the rate of downloads after the first 100. However, as the exact conditions wwhich cause this to happen are unknown, it is difficult to do this well. If you get this message, please email chessdb-users-owner@lists.sourceforge.net and explain what you did. It is not an unusual message and is nothing to worry about.}
translate E TitleDatabaseUnavailable {ICC database is temporarily unavailable}
translate E LogInAnonymously {When connecting to ICC for the purpose of downloading games, it is suggested you do so anonymously. If not, anyone with you on their notify list will see ChessDB connect, which is probably not what you want. You can log into ICC anonymously by adding a "!" in front of your username. So if your ICC user name is "foobar", it is probably better to set it in ChessDB as "!foobar"}
translate E TitleLogInAnonymously {Anonymous login}
translate E ExtraSpacesBetweenUsernames {The list of user names must be separated by ONLY ONE SPACE. You have two or more spaces in the list. Please remove them.}
translate E TitleExtraSpacesBetweenUsernames {User errror: Too many spaces}
translate E SuccessfullySorted {The database was successfully sorted.}
translate E TitleSortResults {ChessDB: Sort results}
translate E ThisIsNotOpenNothingToSort {This is not an open database; there are no games to sort.}
translate E WillAddEloRatings {This command will use the current spellcheck file to add Elo ratings to games in this database. Wherever a player has no currrent rating but his/her rating at the time of the game is listed in the spellcheck file, that rating will be added.}
translate E OverwriteExistingNonZero {Overwrite existing non-zero ratings?}
translate E AddRatingsTo {Add ratings to:}
translate E AddedNElo {ChessDB added $r Elo ratings in $g games.}
translate E ExtraPGNTags {Extra PGN tags:}
translate E RemoveAllOccurageOfTag {Do you really want to remove all occurences of the PGN tag}
# Then follows the database name, and after it
translate E FromThisDatabase {from this database?}
translate E RemovingThePGNTag {Removing the PGN tag}
# Then follows the name of a tag. 
translate E ToSaveSpaceAnd {To save space and maintain database efficiency, it is a}
translate E ToSaveSpaceAnd2 {good idea to compact the game file after removing tags.}
translate E FindingGamesWithPGN {Finding games with the PGN tag}
# Then follows a database name
translate E ChangeTheFollowingGame {Change the following game tags:}
translate E Game {Game}
translate E NoUnusedNames {There are no unused names, so the name file is already fully compacted.}
translate E TheNameFile {The name file for the database}
#Then follows a database name
translate E wasCompated {was compacted.}
translate E TitleErrorCompactingFile {ChessDB: Error compacting file}
translate E TitleNameFileCompacted {ChessDB: Name file compacted}
translate E TitleGameFileCompacted {ChessDB: Game file compacted}
translate E TheGameFileIsAlreadyCompacted {The game file is already fully compacted.}
translate E TheGameFile {The game  file for the database}
# Then follows a database name, and finally "was compacted."
# eg The game  file for the database GM-games was compacted.
translate E YourSetting4Twins {Your settings for finding twin games are potentially likely to }
translate E YourSetting4Twins2 {cause non-twin games with similar moves to be marked as twins.}
translate E DoYouWantToContinueAndDelete {Do you want to continue and delete twin games anyway?}
translate E ItIsReccomenedThatYou {It is recommended that you specify "Yes" for at least two of the "same site", "same round" and "same year" settings.}
translate E ItIsReccommendedThatIf {It is recommended that if you select "No" for "same moves", you should select "Yes" for the colors, event, site, round, year and month settings} 
translate E AllSettingNotEntered1 {You MUST configure a chess server name (usually chessclub.com for ICC and freechess.org for FICS), a username, a password and a port (usually 5000, but 23 might be useful in some cases).}
translate E AllSettingNotEntered2 {Please set these either from the File menu of this window, or Options -> Downloads on the main ChessDB window.}
translate E NeedLoginParamtersSet {Login parameters must be set}
translate E UsernameNotReconised1 {The chess server does not reconsise the username of :}
translate E ICCUsernameNotReconised2 {Have you got the right username for this server? Has your account expired? Check all settings CAREFULLY.}
translate E TitleICCUsernameNotReconised {Unknown user name}
translate E InvalidPassword {does not reconise that password given for the username }
translate E TitleInvalidPassword {Invalid password}
translate E ConnectionToChessSeverFailed {Connection to chess server failed. Is  your network connection OK? Is the firewall blocking traffic? The chess server could be down. The error message generated was:}
translate E TitleConnectionToChessSeverFailed {Unable to connect to chess server}
translate E TheSettingsUsed {The setting used when trying to connect were:}
translate E LookingForSpellingFile {Looking for the spelling and ratings file "ratings.ssp"}
translate E SpellCheckFileFound {The spell check and ratings file was found}
translate E SpellCheckFileNotFound {The spell check file, which has the ELO ratings of players, could not be located. This was distributed with ChessDB with the name "ratings.ssp"}
translate E OptionsFile {Options File}
translate E UnableToFindOptions1 {Unable to find the options file}
translate E UnableToFindOptions2 {A new options file will be created}
translate E AttemptingToLoadTheSpellingAndRatingsFile {Attempting to load the spellcheck file which has ELO ratings too:}
translate E KiloNodesPerSecond {kn/s}
translate E IfYouWantTheseTablebases {If you want these tablebases to be used whenever you start ChessDB, select "Save Options" from the Options menu before you exit ChessDB.}
translate E UnableToReadFromChessServer1 {An error occured when ChessDB tried to read from the chess server.}
translate E UnableToReadFromChessServer2 {This can occur if there is a network problem, a fault at the chess server, you have logged out but a request from ChessDB to read has taken place (this is a bug that will be fixed later).}
translate E ErrorMessage {The error message generated was:}
translate E TitleReadFromChessSeverFailed {Unable to read from the chess server}
translate E TitleWriteFromChessSeverFailed {Unable to write to chess server}
translate E UnableToWriteToChessServer1 {An error occured when ChessDB tried to write to the chess server.}
translate E UnableToWriteToChessServer2 {This can occur if there is a network problem, a fault at the chess server, you have logged out but a request from ChessDB to write has taken place (this is a bug that will be fixed later).}
translate E IfYouWishToContinue {If you wish to continute to download  more files, it *may* be necessary to quit ChessDB and log in again (this is a bug that will be fixed later.)}
translate E NoFICSYet1 {Although it is possible to download games into a database from ICC, this is not currently possible with FICS.}
translate E NoFICSYet2 {FICS support will be added, but it is a bit more complex than on ICC, since FICS does not have the 'spgn' (or similar) command to show the PGN of a game. Expect FICS support by April or May 2007.}
translate E TitleNoFICSYet {No support currently for download via FICS}
translate E TitleImportFromAPGNFile {Import from a PGN file}
translate E TitleImportingPGNFile {ChessDB: Importing PGN file}
translate E TitleImportingPGNFiles {ChessDB: Importing PGN files}
translate E NoPGNErrorsOrWarnings {with no PGN errors or warnings.}
translate E PGNErrorsWarnings {PGN error/warnings:}
translate E ImportingPGNgamesFrom {Importing PGN games from}
translate E TitleSelectATablebaseFile {ChessDB: Select a Tablebase  file}
translate E ChooseDirectoryWithPGN {Choose a directory containing one or more PGN files}
translate E NoPGNFileInDir {It is not possible to import any PGN files, since there are no files with the extension .pgn or .PGN in the directory}
translate E TitleNoPGNFileInDir {ChessDB Error: No PGN files in the directory}
translate E ImportingNumber {This will import} 
translate E PGNFilesFromDir {PGN files from the directory}
translate E ToolsImportDirText {Import all the PGN files in a directory}
translate E TitleChessDBError {ChessDB: Error}
translate E ToHaveThisLoaded {To have this file automatically loaded when you start ChessDB, select "Save Options" from the Options menu before exiting.}
translate E ECOfile {ECO file}
translate E TitleChessDBECOFileLoaded {ChessDB: ECO file loaded.}
##context E gdgfgffggertldffdo {Importing file number 12 of 124}
translate E TablebasesWithUpto {Endgame tablebases with up to}
translate E NPieces {pieces were found, so those tablebases will be used to allow ChessDB to perform an exact analysis of endgames.}
translate E ChessDBEGTBResults {ChessDB: Endgame tablebase results}
translate E TitleUnableToWriteFile {Unable to write file}
##context E ImportingFileNumberN {Importing file number 12 of 124}
translate E ImportingFileNumberN {Importing file number}
##context E er34093489fl {Importing all 124 files PGN files from the directory C:\Program Files\My Documents}
translate E ImportingAll {Importing all}
translate E PGNfilesFrom {PGN files from the directory}
translate E ThereWereWarnings {WARNING: There were errors or warnings while importing those PGN files. This is not unusual, as many games found on the internet have errors in them. If you have imported a lot of games, you might wish to just ignore them. Otherwise, check the line numbers indicated carefully to find the problem. }
translate E ThereWereNoWarnings {Note: The PGN file(s) imported without any warning messages. That is obviously good!}
##context E jhdgdret {Imported file 12 of 345 files, with 456 games. 323232 games have been imported now.}
translate E ImportedFile {Imported file}
translate E filesWith {files, with}
translate E gamesImportedNow {games have been imported now}
translate E OpenRepertoireFile {Open a repertoire file}
translate E TitleSaveOpeningReport {ChessDB: Save opening report}
translate E TitleErrorWritingReport {ChessDB: Error writing report}
translate E TitleErrorStartingAnalysis {ChessDB: Error starting analysis}
translate E StartingToImportFilename {Start to import file:}
translate E TitleThankYouTo {Thank you to ...}
translate E ThanksToOthers {I would like to express my thanks to the following, who have helped improve ChessDB. If I have omitted anyone, please let me know and I will correct the omission. Of course, many helped Shane Hudson with Scid, and since ChessDB is based on Scid, they have contributed too.}
translate E ThanksTranslators {Thank you to the following have either provided translations for ChessDB, or in some other way helped to improve the translations.}
translate E ThanksWebsite {Thank you to the following, who have translated sections of the ChessDB website to another language.  By doing this, the number of potential users will be increased, which will almost certainly lead to more developers and so an improved program.}
translate E ThanksCode {The following have contributed code to ChessDB.}
translate E ThanksBugReports {Unfortunately bugs are inevitable in complex software such as ChessDB. Bug reports are always useful - even if they are as small as an incorrect spelling. The following have provided bug reports in sufficient detail for the report to be useful.}
translate E HelpChessDB1 {If anyone is able to help promote or improve ChessDB in the following ways, I would appreciate it:}
translate E HelpChessDB2 {Submit details about ChessDB to chess related web sites. This is particularly useful if that web site uses a language other than English. It would be nice if people searching on the web found out about ChessDB, no matter what language they performed their search in.}
translate E HelpChessDB3 {Tell others about ChessDB - it would be nice if it was as well known as ChessBase. I do this on the Internet Chess Club (ICC) some times and are surprised how many do not know what a chess database is.}
translate E HelpChessDB4 {Write code to add new functionality, or improve upon present functionality. ChessDB uses C++ and Tcl}
translate E HelpChessDB5 {If you are a GM or IM and are willing to put some positive comments about ChessDB on the ChessDB (or other) website, it would help. ChessDB is a LOT more than a free alternative for those who don't wish to spend their money on commercial products.}
translate E HelpChessDB6 {Write better documentation. There are some areas of the documentation which are poor or non-existent - especially in languages other than English. Do you have any good tips that can be included in the 'Tip of the Day' which is displayed at startup?}
translate E HelpChessDB7 {Produce binaries for Linux distributions (Redhat, Suse, Debian, Slackware etc) and preferably keep them regularly maintained. Some people may only find out about ChessDB if they find it on Linux.}
translate E HelpChessDB8 {Maintain a binary for other UNIX and UNIX-like distibutions, such as those for AIX, Mac OS X, Solaris, IRIX, HP-UX, FreeBSD, OpenBSD, NetBSD etc. One of my projects 'atlc' (http://atlc.sourceforge.net/) has been ported to everything from a Sony Playstation 2 games console to a Cray supercomputer. I doubt ChessDB will ever be as portable, but it should be possible to produce binaries which are easy for users to install.}
translate E HelpChessDB9 {Provide a link to the ChessDB website, http://chessdb.sourceforge.net/ on your web site. This will improve the search engine ranking of ChessDB. That will give us more users, more developers and so software with more features.}
translate E HelpChessDB10 {Send copies of ChessDB to magazine Editors for review.}
translate E HelpChessDB11 {Suggestions for additional features are welcome, but these are always more numerous than I have time for. Suggesions from those who contribute to ChessDB will be given higher priority. The suggestion to add a facility to import lots of PGN games at once by Mario Molinari was given higher priority (and now impleneted), since Mario has updated the Italian translation.} 
translate E HelpChessDB12 {Update the language files. ChessDB supports many langugages, but some of the the language files have not been updated for a long time. If you, or someone you know is willing to update any of the following language files, it would be very useful:}
translate E HelpChessDB13 {The main language file has a name somelanguage-basic.tcl (eg. swedish-basic.tcl). You can download the files from http://chessdb.cvs.sourceforge.net/chessdb/chessdb/tcl/lang/ Click on the relavant language file. Near the top you will see the following: }
translate E HelpChessDB14 {Click on 'download', edit the file, then email the updated file to drkirkby@users.sourceforge.net}
translate E HelpChessDB15 {Advise me of any place in which you see English text, when you expect to see that of another language. In some cases, it is difficult to convert the text, but in others it is simply that I have overlooked something. In other cases it is simply that nobody has translated the text.}
translate E IfYouCanSuggest {If you can think of other ways in which the user base of ChessDB can be increased, please let me know at drkirkby@users.sourceforge.net.}
translate E NoOpenDatabaseNoPlayerReport {There are 9 database slots which are used to hold a database. The current database slot is empty. Please change to a database that is not empty, using 'Switch to Database' on the 'File' menu} 
translate E ZeroGames {The current database has 0 games in it.}
translate E TitleZeroGames {Database has no games}
translate E ZeroGamesNoPlayerReport {Since the database has no games in it, there are no players in the database and so a Player Report can not be generated. }
translate E OpenDatabaseWithGames {Please open a database that has some games in it. }
translate E NewUserNewDatabase {If you are a new user of ChessDB, you can download a database from the ChessDB web site, create one by reading in some PGN files, download games from The Week In Chess (TWIC), ICC or FICS. There are many ways to create a database, if you don't already have one. A very small sample database, having the games from the World Chess Championships, is distributed with ChessDB under the name 'wcc'.}
translate E ZeroGamesNoFilterGraph {Since the database has no games in it, there are no players in the database and so a Filter Graph can not be generated.}
translate E TitleYouCanHelp {How you can help ChessDB}
translate E Czech {Czech}
translate E Dutch {Dutch}
translate E Finnish {Finnish}
translate E French {French}
translate E German {German}
translate E Hungarian {Hungarian}
translate E Italian {Italian}
translate E Korean {Korean}
translate E Norwegian {Norwegian}
translate E Polish {Polish}
translate E Portuguese {Portuguese}
translate E Russian {Russian}
translate E Serbian {Serbian}
translate E Swedish {Swedish}
translate E Spanish {Spanish}
translate E Turkish {Turkish}
translate E UnableLoadGame {Unable to load game number:}
translate E TitleUnableLoadGame {ChessDB Error: Unable to load game}
translate E UnableToWriteBooksmarks {Unable to write bookmarks file:}
translate E TitleSupport {Support on ChessDB}
translate E SupportChessDB1 {Support on ChessDB is much better than on almost any commerical software. You can easily contact the developers - not some dumb support staff, who usually know less than you. Support is free and responses to support requests are usually answered in less than 24 hours. It is quite common for a bug to be reported and a solution given in under 1 day.}
translate E SupportChessDB2 {First, before asking for support, read the documentation. In particular take a look at the tutorial at http://chessdb.sourceforge.net/tutorial/ The archives of the mailing lists at http://sourceforge.net/mailarchive/forum.php?forum=chessdb-users are helpful too.}
translate E SupportChessDB3 {Please email your support requests to}
translate E SupportChessDB4 {Please provide the following information:}
##context E dfd4dfdf {The version number of ChessDB will be printed after the contents of line 'SupportChessDB5'}
translate E SupportChessDB5 {The version of ChessDB you are using, which is}
##context E doererdf {The version number of Tcl/Tk will be printed after the contents of line 'SupportChessDB6'}
translate E SupportChessDB6 {The version of Tcl/Tk you are using. Tcl/Tk is needed to run ChessDB - you are using version }
translate E SupportChessDB7 {The version of Windows you are using (95, 98, NT, 98SE, 2000, ME, XP home, XP Pro, Vista etc.} 
translate E SupportChessDB8 {The version of UNIX or Linux you are using (Debian Linux, Slackware Linux, Solaris, FreeBSD, NetBSD etc).}
translate E SupportChessDB9 {Whether you compiled this yourself, or if you obtained a binary from somewhere. If you compiled it yourself, report the version of gcc used. Did you build it from the code in the CVS repository? If you used a binary, report where you obtained the binary.)}
translate E SupportChessDB10 {What steps you have taken to sort the problem out yourself.}
translate E SupportChessDB11 {If this is a bug report and you are in a position to check this under both Windows and UNIX/Linux, it would be useful to verify if the problem exists on both systems. But this is not essential - just do it if you can easily.}
translate E SupportChessDB12 {MOST IMPORTANT OF ALL, make the bug report or support request MEANINGFUL. Give as much detail as possible.}
translate E SupportChessDB13 {Reports like "ChessDB does not work on my laptop" are next to useless. So are reports like "I was analysing a game and a window poped up which said Application Error". Again, that is useless, since without the exact error message (which can be saved to a log file in this case), it is difficult to know where to look for the bug.}
translate E SupportChessDB14 {If possible send any support of bug requests in English. If sent privately to David Kirkby, please put 'ChessDB' in the title, so it is sorted into the correct email folder. This is not necessary if sending to chessdb-users@lists.sourceforge.net, which is the generally the preferred address to use.}
translate E TitleFilterGraph {ChessDB: Filter Graph}
translate E TitleSaveGraph {ChessDB: Save Graph}
translate E ThankYouDavidKirkby {Thank you from David Kirkby}
translate E ThankYouShaneHudon  {Thank you from Shane Hudson}
translate E THANKSdotShane {The following is the contents of the file 'THANKS' which was in Scid and so have indirectly helped ChessDB. The contents for the file are unmodified, and so are therefore in English only.}
translate E ThanksTclTelnet {Thank you to Todd Martin for developing 'tcltelnet' http://tmartin.org/tcltelnet/ which ChessDB uses to connect to chess servers using the telnet protocol.}
translate E APoliteRequest1 {If you wish to contribute to ChessDB and become a developer, you would be most welcome. ChessDB is programmed in C++, Tcl and Tk. If you wish to create another project, based on code in ChessDB, I would respectfully ask you use another name to ChessDB - just credit Scid and ChessDB where appropiate. Using the name 'Scid' or 'ChessDB' will cause confusion amougst users, with them not knowing who to attribute bugs to.} 
translate E APoliteRequest2 {If you create any data files (such as, but not limited to opening books, databases etc) for use with ChessDB, or derived software, I would appreciate if you keep to the spirit of free software and do not restrict their use to any particular piece of software.} 
translate E GPL2 {ChessDB is free (but copyrighted) chess software which is licensed under the GNU General Public License (GPL). Copyrights are held by Dr. David Kirkby, Shane Hudson and others. The conditions of the GPL are listed below.}
translate E GPL3 {Note the GPL is written in English and none of the translations in ChessDB (or anywhere else) are official translations. The Free Software Federation does not officially support any translation, for reasons explained at http://www.gnu.org/licenses/translations.html. The non-English translations here do do not count legally as substitutes for the authentic version. You can view the official English version by selecting "Language" on the "Options" menu, then selecting "English"}
}
