# bitmaps.tcl:
# Chess piece bitmaps used by ChessDB.

# The piece images used here were generated from freeware chess
# fonts available in TrueType format at the En Passant website
# "Chess Fonts" page, http://www.enpassant.dk/chess/fonteng.htm

# The authors of the original TrueType fonts are:
#   Alpha: Eric Bentzen.
#   Leipzig, Merida: Armando H. Marroquin.

set boardStyles {}


##########
# Size 20 is only used in Material search window, not for boards.
# It has two special extra images, wm20 and bm20, which contain a
# bishop and knight, for indicating a minor piece.
#

image create photo wm20 -data {
R0lGODlhFAAUAMIAAH9/f7+/vz8/PwAAAP///////////////yH5BAEKAAcALAAAAAAUABQA
AANweLp8cCG02cSwNB8RSACctgBAR3iDqJDd5wlidBLCHGb1CQzzx+yPDYAWyJ1gixpSwOLM
CClFESSRup7RImF42zxP0Vpg0EE6SGjSCqxTKYxHN4RJ6sYETHxVNa3vM2gDQyBoGkNbhIdq
FHRBZyAaCQA7}

image create photo bm20 -data {
R0lGODlhFAAUAMIAAH9/f7+/vwAAAD8/P////////////////yH5BAEKAAcALAAAAAAUABQA
AANneLp8cCG02YQYgupj+5CbEgyYAAQCuJHlNYZo1wHDo7VyOjSAebQxS69R25UCvVlmMXIp
TrmhSGgB4S5LzoVQegK+YJtWwLWEFjnzGVL7ftYQMoGQggerZ3CrLealoxomXxJIX1kNCQA7
}

image create photo p20 -data {
R0lGODlh8AAUAMIAAH9/fz8/P7+/vwAAAP///////////////yH5BAEKAAcALAAAAADwABQA
AAP+eLrc/jDKSau9OOvNu/8VAIBkJAhl2ohqe5xuCgTBGL/oQaMwJew30KwWhAkGA0Vv8gvk
LALRUxJ9BTSAk40qFXWzkKZWCmQit5Uo2GdDW4ZuiFQ9koZ33mxZAjhjBidJFDNIRBgBhRQD
Q4t9NH0NP3o1BEgEYjNTDix/SIITfQOIcROIooOFpouekV6PlQMEQ2qaK6QSsZUholGit5GA
BJeAuMIixgDCnwrJAbKLsMPNsiY0VxeeyxGhnoZm2cTb4OMrP88C0X3NVWF+2CLaELnCUTRm
6CfDtQuUwv7G1xb8iHUkmSV1lZy0GpErSZR9DbJVUOULCUQl3VRdPDL+rtsKRM8MxuqDjlcr
FBIflkomK+CdLP8I2Ivg5NIOmxIe5RnygOSzhDKlLGqg01LCGjMhUHQpj1AhmfEYmHIy8JSJ
jlZXAHIUDWRBojWcFnK1zZk/bw9oBLt09lcuMcpA7eS0CU8WVyIeMTBHD9ARdMjkjPt14BhF
QEkddDuhSm7MqIUrrgJ0ZhSDvJIr+7o14x9dB3z9zTtCE3A+nHxiUpNXsFKgXj+mHPN3pKa/
z5cH48LqJJwDVWoT8enYDis4W9k4cjzjliWk0p5ZBn5QcKdvOardXqqXN1nJVjFpxMTNgJw4
4zypj3V6kRlxecYl7g0+mZtewcLQ/vYMjTb+U6lh5fXfJtmVNcpOj/xnGzL/kHaeO/AZ1xtN
AaY3nHk9dZOHKnH0th43M1D4T2KXzebEbKKVFcoMhDEz1y8cvUjIPo3AU2MmNI0zYGEU2eiJ
a3JUqF9PFT6nnnd5GHMdRrScQMeSC3Q23oCdxXaEapAdMI+Sisy1I0YyQslMgOi48iU34AzY
yxlQJTfUA1hRoJMXYmJkHESOLIXIl1v+A5mAMgE2IkS9qLUGdDH9gIt0fprAaHQRxHeHeIfV
eEc2CuV0Z6TrNVYcVrdEodp0ZY36WVVsPrPYb/HxmVFykfrYyJfLddTeCx15MZ8ovJlEVHx1
zoNillrWICgh2zxpeluLfbZVnllK9pefNiiaSopPWLrVD0BZoqnbboOhBexxEQF7bXxuGfdg
rlTEJxt9YDh1n0Dj7rOmjhtVmmmG6E2ArlRpapGmYsDa6+2qlwYcxAWHyrHwwxAX1h47EVds
8cUYZ6xxBwkAADs=
}

image create photo e20 -height 20 -width 20
set x 0
foreach p {wp wn wb wr wq wk bp bn bb br bq bk} {
  image create photo ${p}20 -width 20 -height 20
  ${p}20 copy p20 -from $x 0 [expr $x + 19] 19
  incr x 20
}


####################
# Alpha:

lappend boardStyles Alpha

set pieceImageData(Alpha,25) {
R0lGODlhLAEZAMIAAL+/vz8/PwAAAH9/f////////////////yH5BAEKAAcALAAAAAAsARkA
AAP+eLrc/jDKSau9OOvNu/9gKI5kaZ5oqq4QAHSBELD0QFcuLN+rzUsC3yZAmP0WA6EiqQEM
gq+jI9gRWKVL5YGZcUI7SW038IQNjBYnUz14haOSM3crzzyt4kvYA4gJdGg4e2xuSXARd0KJ
dlZUQ2GBGGcABACOGH2TegMEf0kETAKgeQ1yinUafzpWkXqNeE0xAYcTd56NNrgUi0uwqWCc
BKNjwcJFrXGzlbMWn7igjcMUAcwKfcgVqhu2vhd9r6zYENwCtIjg6N0SMXCW4hPaGp/Ccziz
lsXHFtTGwtQV8/oJrBehHJpZ8cbJYIevnDt2AMGRaiELWiMn+9K9Q5L+Dt1EBqwW+Nm10GEQ
k9TKASxGME45gf3+1SJCzxiZbJRgCrNkjg4cUcz6dFqgpgG/neyWKfO3cYtEV3iSvJrVlJvV
bB1f9TS04OIBS1esETy6rFwbajn1TePUJw0Znf14ShBqTJTNng6ohdkr8wERVU4q2XjbRgFQ
BnRjUkp8d1qjptb8ZDWI1xq4Tlor6N2bpO+UsGCpSI7SCDERP6d5nmZVpHLkxhMypR1o813A
aPQ+IiHDGZXfM1mE/bHLhUygNjCFLo2rO7QV15ZTpksE/BxuzOoQ8eZ8E0JIp6Vf+RiJxAsu
5ebxYIxAlukuF3BpQgMi0G7dlTpbEn0yY+n+k2AYxVBYV/GdAVdCRmlEQRCSgQNWGwiCdBk6
EXU0kRf9ZTXYFwSiU4SB4PwVgRp6bQZdUjAtZ0kcs9knTS35GKMfA2RY0Y+LeLSCHEz/6bTe
AyQ+xhUQWdUYxFDWRfMUSRZO0OBkO5SSXlRBkNOGblsshmUWBgkZY4REyZcidEvABUpsVJlJ
lTkBxeViTFjasiUd04XGCZiWTUYmeNPFBmVmpUA4IXYXdUefcBfIoNIBy93o5CycXWPBm446
OZuP2DRaF6ZYlTbpc1k0CKGTMnAX5YKTOfZnpi5c9pdWbaEJ20oKtFfpOtt1BplhZuKJRIw8
kmKJTpR2QqZzi9L+yuh0ZTzK3a4HQMkklMICJZ5Ujxk7TVqxenOkj74G18+MDxSL6IKCSUYG
Jb7ShS0uwVRD6lRdaNhsMtzNGW2qqLY5SlgUjSKjjJzIO6KYrXl76bjhRtvbvQs+LBVW6xrj
hCx+VswcRBQgC2oak00Mz8MNdyUxxAUJNhVyG2VyRoidHYuwP3syujDDu/x3Ermm5fosdDsK
xi2WL9HzbSUle+yVZiGj/MC7UdlTJckGP63uy6wQLRkntsQwzcy1ZWOm0ePwVeMZPhd0s5uk
5tQj0kTbx1NdDT+JDmRQ1lg2JDDvVdCfAEOw2pF3EEE0doOLEq6BY1ftQGBjy2VUpCua3sOd
d2PfB8TaSE+T+UbkdASd0hIlK1JH+97tHeDhmiXxik6e3NlMsvs2js8ka2HKXirhk+/juD/8
ju8nm+7A7hIb+jTguoXeJAPO9/48Yqy3O7XExpcSPF8fsSH76LW/0YD3e0Dfmznkfz9i+AO2
wL5r6T8M/vvjPxxopI+zPySQ9K8ffs1YCKAAB0jAAhrwgAhMoAIXGIEEAAA7
}

set pieceImageData(Alpha,30) {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}

set pieceImageData(Alpha,35) {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}

set pieceImageData(Alpha,40) {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=
}

set pieceImageData(Alpha,45) {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}

set pieceImageData(Alpha,50) {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}

set pieceImageData(Alpha,55) {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==
}

set pieceImageData(Alpha,60) {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}

set pieceImageData(Alpha,65) {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}

set pieceImageData(Alpha,70) {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}

set pieceImageData(Alpha,75) {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}

set pieceImageData(Alpha,80) {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}

set pieceImageData(Alpha,85) {
R0lGODlh/ANVAKEBAAAAAP///////////yH5BAEKAAIALAAAAAD8A1UAAAL+lI+p
y+0Po5y02ouz3rz7D4biSJbmiabqyrbuC8fyTNf2jef6zvf+DwwKh8Si8YhMKpfM
pvMJjUqn1Kr1is1qt9yu9wsOi8fksvmMTqvX7Lb7DY/L5/S6/Y7P6/f8LuAPCNA3
SFgYEQhoqLhII+iEGMgoOani2ASZSKm5+ZG5hBnJWecpakKaBHpa+qa6GtJqlBgw
KwDrqmZ7y5E7lPqnC8cLfBH6+TeLLDwsprw8Uazka+mc1kz9AMkEiDxrLYpIDB0k
fY2RbZxafgBuwd7rq16Bqf2LXPurDvo8LySNH3/oXDR4+fgFFAjE3zSADUJ521FM
3LJ0Eigm9McQgkX+JOTKbcSmbxzGJ+6kROr2D1VIiB0RtFz3ssU2WspkoVzYQyGU
klEIDjSoY6RLnzCJyvzIwGhOoT9XXjpJMyVHhEFj3kPK9KgAbjWP2ZMq8uFFpE3J
FgFaVanVrCyULnD7gyc6uLGgRhWLA20OtmutVqqXDOxbr3fr4pxr1rBOlXLz9sXq
N0XkBJOXHmaML4CBxkTAcQsssV+i0DZsFqZM+KYC05rxegCsWmPqe0dc81AouDNu
0mOpOlYLnC4K4UX1hiXJ+qvtGdk+c7u63IVn6JeZw24Ndibo1devxvDEe+i/6DDI
39iduzd68ysW733sdHPlE8Tlxxdd/Wzy5+H+b9t1zh9n712HXXrfdaeKdrGJt5Vy
+Q1nXFIRjvXIeg+yZCF1YbHVCHx6cdjehNz5hl+FggAY4IW/KYjiZySe95+DBkqH
oDQukpOidf2NyN4LPeqInm4WZrKjDEOuOGSSRZoioIRLYmhii1zNiGSDUgKoIYap
AdjkUSfKCMqN8ORo5IuDdenDj2Wu946S9XinJZuluUmnikyiWZyabVF53JWnxRXI
Zwb4OaWeu+yH5ZP01ZiOoDg6qCOcB0l6IJoi2qcohEeqx85uW1E6p5Kh1pkkkNZc
KpmZeVKJ6p5fXglqnGICQChofIZIoJTQ1YBorb5CumYARQZq6D6JHVv+31+bAjrP
XRgtyGud0ZJa6pp43ucqtpgKOB+uVupabCeBgvmtn3immiusmZKQ7q+/0qZjgZMK
e6sInqI2mkT3WiunZc2COSa9dmoqbYfU9lvpta2OsG+eWYoHoqvlohhrlQC/Sui5
d9Lqrq0dTtyxr/CW2WB/446Mqye0UGeJXbtu68jKC7NbrX/6OBcktOUdPHAJPCO8
86WJ+eyOzO64HBE7RmvMcLuO1uulgiw7nei6IIwb8k09N41x1oRWLPGfTjYINs29
FvhLjLt6RjHTr9Q84M3OTZ3KdgkfbOrP3S6q7apWZ8B21fkSuHaMKUJt75YohrtB
4F63/fehiof+HHkHhj8u+NaTzqt1Q9qVja8GiGT879OOt+j21RnGqTdgoG/8M7+t
D23OrZPt/TpILC7+by1kh2lu5Y1TLW/ck2M+q+aW7y4oAlcKPzzzyGutvAOoSm0L
a8LMDDHIkJ+tocjQ1w70tLOPHpWP51f/2vp9k7/j7fVxX9zEB8zNtnfOdq3ZoKaz
L7nnIQ5dxJvew5TFP9N5T0b8WmDWDrg8oW0pNFjTGY/cdjlwSc9j7noZjRo2KvfB
hnFn0snFaMc3EQ5Qd6qiGwXng0J8dS18h7MVxwQ2w9N5MGog26HBCji9/YVNXQXM
XQoBWEIknulTvCBcK5KDsiUWz1gObJH+/ngHRPytMIK4QZIKCTM+Y5lwf7gjmgoT
J0G3RAxmD2GNC791xSv+541kUp9pIGiqKgaxUFsMx/EUSLo+iut8XKvjiCYmjgqK
LXSFEqPXrgjIrIWxHV2E0RfzR0KIjRFt7knYHiepSTNV0m8TKmMFXcioknkFkpxs
jsfsmMNMViSDyHOgD+9UK1ZKSZayaZ3ZxOQ5/oFqP2Vj0amyiMUb8vFxRuTaGrN1
SbvwEpWlo2YLlfVJQVqPLqNkYymTZR8rWRNjJ/vSKTfZzLel65YfRGbHlMklUAbT
lo/63g9jV8hGOgmL+OLnPvXZS3h2TJe6fOc0SRnDI67Pha9UaN3+dtnNoGVTiU7q
W0QjGspzYW2csJFjYU6ICT7y0IrylMfZgphABmqKngGzZ7xQqs1t3jAX0pNUr2gK
xnqdtFaKVGTI0tm+8kHTfQxdpNn8IcBOBm2QZlTVvkAoQ42Zhk0OAiZIgTdFAlaR
ncpSpR4HmtKG4lKDjYIoRYf31VzGNJiidBp4/ljM9/VzenfcoLsOKqqguU5v3rwh
UAGHm6Q+k4D4dCa3ngpVhBqLj4HdTlVtqBCAEsxXJZ0lxwqKOeKlzqRhJePptHhW
wKb1a2tlK2fAN7gFgi2h9gniVRxL19IeBG7QZCyp+vo7EgbpfivrK/3QyNemnjZI
Qn3jYj3+W8/XquaqchMYAu960KKkb49R8RNXmSo+ZP5VnaO1rm7vc9KQkjQ7cj2T
a2Wh3NiGloV5jdpMg1tWHDr0Wcgto2GDK1x9LTSq6/rckBpZINtuMpO0JOt6D2KP
7vL0jyo142gx69Kl7nG78DuFXTlZRQtfM5gTZSKDoXvgJBYsZfulY+dg10XmlhfF
hXUof1s8NcD69UiOTS9HA/dd22xWxq2hrnK+WlkGZbezCqyUgsmKwKN9GIcCxdl4
VvxPA25jp7/KMc+GOjvFivW+6FwWLH1J2KQRErfkUzFWXztVGltQdWBGV3rPu2Tq
bWzIow2yZY883hCbNhJUhnCOWGv+3g5fGMQsphaJs6xlOee3y6vTa5sJBo4zAnpE
Zi7d4CrtSuce9dGFnjCVFW1GOlNWtuTDc4Td3FyzknYe0fn0gtEnZVK/+MphbnNL
dyzGFNd30sDl9Hyj+du5Us9T5ILsbiS7J8+ZD9aPhM6oc5xWPxe5Uj7G65syDa6v
sszDSHT1qr3tXVnnGsq/xhtCX4VryxJ71+TeNH5rDexgC3nYxxaisRub1WRXzXyY
whLduM3scItbhrl0XiD1TIFBE9pV+6Pss6+9VoWrtcAL/3K7m+pbL9cz3bNFbHEP
DWNIx3vDvcQ0jjdaKrt9sIfRXWJxEpzyd9m5KKYmIsITHuf+Kg9cpuKUuGaebaXx
gVuwTX5gyzM+8zufe7dLR3fSbzziu70b3iOP+AiTBKl7R9ao2PSnkXjE7kjztoNP
96l6b37cDnuJPzXPNrJlXHTKmV2SR79xIy7oZaQ7ncBfvOfUqR7voM74vx9tpa7l
a0fU7RzuHBvu0EGL9pdT9+kInvzi5ykoH9Ni2pJru0jhHHmZDta9pdxzczmu7jHn
LeQir3po65oh0Jgc9qHnsNf5fWK21pLy0gZx7Suv9rVrPnjrnTtY3WnW34uY14XG
S85AXe7bLvvvgL8km5WJ9Zto3UZb9laeQ+iIJvrcwN7vrXuANa1qXx7zw/8+mz1f
eMz+UVjwSpU6BmMP/fmOnWLetCSiST9y3CVgSEUTQWchhuQlqlV3FdUkFDdx69c9
UNcpC8gd8Pc0sNR+iidrDihw8HddrQdOSRYehmZDJFZzeGR/tAaAgXd9PbceX5Fb
z4c21GZWaSF+OSdwyieBGEUyPhZF5ZeBCCh4u4d88QSBold/foeEbmKA1laEDTZ9
rFd9IuRMhzNgs/ctvCdFSBY3LGSBM4hl09A8/WdJX4h+QxSEZ3h98jd+ySQ7SQgk
S+gmjBU1CWZcTaiDAaV6YWh9VWhyQfeHImVkNucfpmWGqEdJMfMu8+dgPlh3bfg4
jGN8r5ZZFLiDebgPpjeHQrT+gnnnd74mgn14VFbYUi64SYhHg0mlHxz4cJgIiSoX
KmbIdW4mMgpAZxjXQQxicEOGibNmX1FYJ+TSiY0GfqA4hV3ycVwER0TxHM9xbstI
gZ/GiO30hMnnijjoZL3Ic454hFvob/fifrioK5foP3mmjU3HfI52MMLIh8QIjFII
gqGQi6MnOm4kj7oCK7tyONYCdOpRjpbXcq+4Zmsii/mWMs1DJ/+oaSlkP5cYEpC3
eollg3rDjiBHW59IffCmkA8UYwQDRwW5MvtIkLeYJo/Xign4SJYobABJg3q3WwMJ
XGQDdTMZg+eIjiGYgtRSkQTkNVrYcf/XThvpb/tnRR/+2IK12AC8CCS+V5LV+Grd
SHMpCZXAx5JL5RNFiUrTyFlC8TUuaZNeiZPUSJGcCITH95W+qIIfNI6LUYMI5D03
qTKZE4dkp5IVBZKzopaROJV6CJTDKJTWlZUWmRnMFJhveJHF+DMlKHw9uZe6M3wL
CEUOqYhqeESkKCp0aC14ppVHdZciKZhMiJjw2Hpm2JGH9mC82Jh4B5rGMzuK+Znt
ZTCPmZrhFHZUZZBHJJkYgYjRE3fEd5aHlIZg+JqHaXF7mC3dhZw+SZsP+GB1KZrq
2DquGYpRx4+ap5w0l5sdEZA05pCmUol12W/BaZTqlJEmuGmJx5xPiZ7fhkyWaJz+
hjmWTNaOCQmfJTafN0OOYklfs2eTAUd34GmSZnmWNoE+m9lrnYlhKOmbQHSdzmZz
2OaGOWlo75iY+VecYXmMfZkqHFUuHJqag9NSlpkNkDmJvjegTkmXsykeDQeTjhac
8glNCphq/9OLnzWAdoWC0/mcGXpbFqqfGBp9VKhvWamB+PmhqxSiNMo2jxig5hgp
LyqcEoZhs0iNCAp5v1c6StorpQlyMmqjngWdGjqMseOj9ylvveZ6WNpRMyqipkgj
pjij1OSCVTp84zlWL2qn91VswzaXUOos02mOZ3NxkvOlWWdgysmCYdqaUWqm9Lho
VddVV9WhpRhdtBdf1uT+ptmShg3ae+rXI5epGv5FnNHjp9kognrUqds2VNH2l1ea
hwF4oYSUoFwkLWk5SGnajeiFb+PEbQpqd+tmoI4UnA3apHJnHqDaOec0qmVWqm/H
me8ic5VarOzZqMYYpGOJiHxVnhUGAN3qrd8KruEqruNKrmpKKzNZruG6Fd66dtmZ
rifCrs8Fpd+al34KroTarRIAWlE5huxVfN3arM7KNVZ6m3dCsFSKpu+qsAubr2PK
sA+7rvTKmw9brnDJsNdHsRn7rjqqsRdbrR1bsZEKpcGKc70pm/EKdycosfpodCgb
QAHboqpzsAvZdS/qstcKsgr7ozmrs3mqiTxrsR7+S6s8C7RutlIS01U1O68Ny3Cl
6rNj07I3e69RKy4zCzm0KJ43uyhWix3DSbTpurNfW7Ery61Ei5Yde6tiC7JYm4Yk
GxBc+4NEw7Uxm09+mqOck6Jau20/pbeJOLec90tLq3zsard9m7Bq27Mfi7iCQLZb
KbbLV7QTu7gaqyn2yrQrVbiXa7BIy7nm6UeJ2Liq6beEmjBHa7Ra5ZY8Ormaq7qr
a7h8mbP+Grv46roQyzfekrqoG4+1e68Oy7uhO25rC7toS7u/u7HNZ7ys627JC7xc
xrzKi7PGy3izK7vEK7nPO67R67ocm7zcK72+y7xlm7GOa731iL1gi7zd27pok+u9
vxu25yu+FEu+lFu859u7j/q87cu7GcG//eu//wvAASzAA0zABWzAB4zACazAC8zA
DezADwzBESzBE0zBFWzBF4zBGazBG8zBHezBHwzCISzCI0zCJWzCJ4zCKazCK8zC
LfzABQAAOw==
}

set pieceImageData(Alpha,90) {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}

set pieceImageData(Alpha,95) {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}

####################
# Leipzig:

lappend boardStyles Leipzig

set pieceImageData(Leipzig,25) {
R0lGODlhLAEZAMIAAH9/f7+/vz8/P////wAAAP///////////yH5BAEKAAcALAAAAAAsARkA
AAP+eLrc/jDKSau9OOvNu/8gBYQkFgBAoKDjcaZZW3LybD+verBKHt+ZgAAg0AErrGEtQhwq
hoKVwHlBRY+VAGFrxEoABGIYuW1tCasyRkC4er+AAaoD8xB9IitLrp9fBANuGkSENGdLGHV0
BCeMZG0oh2JjF2eLahsofBsBQoIaQkldTHEDpqeofhFaOqw9jlUsiBZgmEGeHkJtbKMQtWfA
wLMMri6wxbRQwxWWmUqUQYCmRZ++SrLYVEyBC2gr3BMyKUXiGc2DZ9omwLh5fNgpmxLn3gfn
TAuE2ss4cYoXQkzFYcPPQcA9Q3oZLAMvEqwIStK0iAhB15lGYFIAK5L+5SIodqHWleHycFWw
k1wmEJT4BJpBNhd/aUyn0EGRAUKioTKlhSOzAHKCypsQquEdCBSpZHxyhccCLQxrAYLJwqPK
dEFOkvNJAdiAdAV7JNx5gmsDTEopTUkjCGopXVDaAJWTUgKbuNXmvSBbV8KJQP4AqQoH9GbA
E9tagFnhh5I/BrVQhZIjjactpMHyRoAE8yIyk5Aohwn7BAXcF5rtOfa21J7iLZDDnK5MTXbr
ioFOAarpQNROnLDDDQyMk/QBaaWEpm4iRcXjQsfVlfkN5Xctv1+98m6QEWqwTvWYbBki2uW8
Mnd/MVm7w9HS1lNqbMnODvjG7Crn4kzNvXL+qlO3+VKKPwIZp8yBgz3QhgtE7CDHcTAsdlYY
PM01nkBzXWdXZrSgFIZnBf1CAH3mQYRhCgNOsGBP7Y3AS3sOzMeFdyDJGF5vyWFIwRS/mcKI
hTc+MKBQCW6mnEBfEebPOIGUhRNi3FH4VULdNSFQibGdtF1LHmoBxlRdnUGicSN9aGY4FHJx
F1TAIQIGVEKANyMgI/ETj2QF8dijk1cWNCJdpZhlV5zdUUMUioywMaWXJ/TiJV2AZUTEVwOV
1BtKeWo13jjzFTlhmX2pNE5gZRFVZmdUhfrKfF81UoYWPqrKXY/8xKkfclwAuOAX+vHEH3eF
AXVYWEOACgl6mPH+8c5o5Gj0q4iH+LULWKx2NhCaWv1xx5ph/KoaWFYEg9lojMhEqVTC7eRp
PpP62q1sqARnVyRWrIHkvd7u0SMfqU3hCUo8svcFpgPTSBCVh4AzDzZBnvdusfKS0itZDWLW
RGfj3bVrfqfk5Fccwrrh3ymyAssClBYgqExYd+5b3Dzk7StGyhxKO5LIJ/mz5SSQ2CtHoymm
W5wsAPITmsxsVHLmjtsucNNvlz0wxYi7YDBiKX/G0TB3VeXsFATlQsuQFkrfA1GiOKM0FFIo
NmK1mW5FbI2HYOnlUDCmbY2jbluy5fTEJGPJwGhVrVEUsx5Lywt5d7RhaZSTTLWp4Jf+skNG
2mqv6/TQCldA5ZKlmro46I5v9+VF9n1IWrt8Z/B0j1H3R3EW16hrxXZxToGqv4/HJlO4qj/y
net0Zz1wzrQzK8yXuFPDs+6f9VYbqMqIMPI0xu0AOCorGfSUPop0QorLBapIODxyK3gTNtPo
nSXBNBcvEA7fp2eE+AKSv7aCRwMIU5jXkMX/iHK91nVFf/upgQBlACYpyEJ6RsmG0fTnPgWM
KIBJSJKpite3b3HwQfkQRjfkJSI3FQ9vC3PVIdymInLgTRc72p6vYojA+YklPpwix2ms4C+u
1VBz9ngdnrzVP+4J7GzF8xbGTigDi2ipCB4SlCYQCEQzYYp0iEvcCBEjGImucBEeg2uBl+hF
OFhICDIYNIo6hEQ349SCYZQb3Akr6ME5ykeMeBsejKI0x9jxEX4iaCMSvsgyQp6MGDhil/ca
8AJDdrAH/wBFJPPwRUo6EpFcUyQjDWJI0wBkkiYA5RtGScpSmvKUqCxlAgAAOw==
}

set pieceImageData(Leipzig,30) {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}

set pieceImageData(Leipzig,35) {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}

set pieceImageData(Leipzig,40) {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}

set pieceImageData(Leipzig,45) {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}

set pieceImageData(Leipzig,50) {
R0lGODlhWAIyAMIAAH9/fz8/PwAAAL+/v////////////////yH5BAEKAAcALAAAAABYAjIA
AAP+eLrc/jDKSau9OOvNu/9gKI5kaZ5oqq5s675wLM90bd94ru987//AoHDYAxgBRNbAuFgi
SUfjgOGMTpvRJ8p5TaaiXpUTqxVlu4fqEa0um7hhVEBAFwTib7s9Xb+P6nRlAICBDIOAKQMC
AHNoeCFzfY8kinR3lXt/gIKEi4aEiYCOkx2NBASKfqQfg6cCB4wEgySLrpwAp4Ocua8otbJu
qxuRgKrCHId0sIiadZyEz3Up0Mcev7w0wTKKjK+xc7S4BHZRc+KDAeUC2L7nxi+dyjHxvTLa
MZjezCKE6UfEfdTtM9FvBj0Z12TVm3cPRqQndUZZE0fvHD12JwIEQJX+ziC5bgtdHDTY8MVD
BRFp0VvJMgXAktMAgmN46tTMFl0OSXwxYI5GPvL+nMsi5VSbIxg7wGkQ6V0aKSrsbBx3E148
nk3o7HTR0xLQkCBYir36YSmDpg7MnrBTqasMc7xgQtljpNAMn7wEDOAWrqbfv4ABz/LATVeD
tocXDdoaFkDPAEvAsgBotwW6ZZVjUKb2xx/Rz6C7ld2UWG9prdPs2AwKoxMMdI2SyaWk1W8q
VKb5iQusZkDgpBt+MWpwyI1wp0LHrRs8D9SLQ5tnj8i3iUAkxhkS/t5ekzmHgp88MQC/lo4r
1vD8VWXRSuN5ZzhrA3b/k9/Y++g1HCee+cD+/g5nNCCVERqF1IYvzrmQTDEnKcGSbz51FhqB
noG2nn7F8CfeAuRtEOB4emlUyWFZnKBLXFyptpctC2I3ml557SZibiBshl8nyGGgUV1uFEec
PxtmsCBpKMGIWz1DwjcXZw7Gg0tXNJ5AXTx7oQbJjWLleMFLGvZIpAZJViaVJTeFGeSVfmWy
Qlt/OZYXWwj6lgtSNYUoXQWWGMGdYCBdmZ+PAva3pVhIHGSmJCNspiVt9EBmlE8ufgfNm3oZ
Zh+WI31AjAOAgnjmoCwVetWhXonAjV+LrSnfdlBGaUZCUdi2iGQcsLknYIiBqqYChzjQYFZn
EsOYjTjmCRKxHRL+Rk+kymYpp04mJGkRIMpNt8kauEYhio6ILtArU/1V4oawErwkpyxNOXNs
IOdG1m2zRsmZXwmr7knMosGtgyqdNUFGa62BYAntBYr4pkiXAtaFcFYG/0tZOjW5a4lf9+6G
brIbTDlQefeJ0xW+GE6q0CYXKnvurRG7OgF1C3MoTXhlsAzBvb9BOdVqbPGWoaYsgQygkU7Y
+y4rvzihHp1d3VmBLr6BNC3EkSm9TJ0xl8qhwp7yR/UD1J2MaiBfGzlfgqX0/MW1yN4c4avX
ymm0M596oGcVMc4pTkcYDFn1rv697HJIenNNrVGMpCOnKSlPRaGbR87LbSBZDG2qarL+3Xrv
q935s9cR+o7DRKIWW3dyT236/IlRYOmRsHepGKjvwQ8sGPpfp3YndmBclp2llHWkKdbhfP88
uGBwSz3BZiODjaOQZBcZ0kCYnOZ45dbhGBlg62g8FTHGNwFh53VutJcJpgwvtNUezJG5FFV0
bqlubQrW5r8R+GTl1XijhDWv6aSuR44AuRXp+uU1XH1JAysilviY9TgZ3Qd4pjseIX6TDHOo
BBqyU07zKgAQRyjJeQtJhgN25quIVK9Rt2tdRZLXvU8UMFV5mAoXUIYzlWEoYgTKoZ5QBLq/
3K4VFIugIbrxDs6NZ3/+OQK4DBeBYqAMcqq51QaZtxIGYiD+HwS6EfCsCIFOFAUVWTxgjTqR
vFosD0xE1NBCBvJBBfjEMU3snQZX4qgarqSMyrrZXxpRgtugbIA+RJ+k+LTDr7WwiZ5RV10+
IhqloK8VudGFpSBZhutMoDqWw+SepkiwsXCRAhoLVT/qRD8LrLCMASnBbhg3QzB2p1nGSMYV
ZMerNlpSAtTKx/ZwpCg74rED9ZKVECmADhoqJDCyIRohZ+edECwGUmBkF0fYEjdQqaI9fgCi
eNyzIRFOgHoRQxylLIaXQAoKA/cZ5jcxtREv8lB4IjOTKg03TYiNzFF7yd8wrFbBWiqJe97y
WwRkuSCKjUWP1EomMm5HvEMu0Zj+wECF1zYGJvDZbXaOA+aTLGrPOjVNnS5UU6VMo00kcAN2
fODLOsFm0FUV1HYsJeU5LUAqMepOYMpp0XmI5k5UCjQEfZijXqhzQpAG1GrbomU+gFXN8Jhx
YouRwrIgc6qEtjE7evxNRglWTmNCrKNvcmjtusMvUtKLIm0Knb6aqZ8qXcGMSCjp1AZTMLZ2
UY7hs86J8mGTHXnOnKW85I1A0CqBnciJChGrkyhF0Q9QC4MTbCw6U9K3QtByQQpYKp6Up5jE
wlSTcOnfOjal0VvZ9YoTg+g43Eo7yWUndIWDbVM5ALXbuSdlH9WU+ExTi1nItbevKJh1TEeM
lAFXfXP+xA1y9WDc4E0WPy/ClHlaMaTwObanYXLoA5pyQq3osqg8SwkoaAkKXVoAeXlBl1BH
65uYntFD2kHmbCnQVa9CBrmAVaZtvtgvGyrLaWFMJDn8ewEgcuMXerAIcnVhpPkydVr6Wg4u
ElqX93z2k0fFj0ORtYlOtPd7mDxtgTGFYQksARV2cxvSZFHiDAesGMXqsE0hMCWJVuKYZHyq
RNfb4hPt6X0VlSFvQvexYNZQu/E1oFFNvIiPsstdUIPhRHCmnkDsyFjcVcjjXqeXCEeUwrGA
pEyXjBkNwxNZE64O8EaJGyTfiMw03kis0GVPK0AmLNIVy5an286Rrtdzh9D+K3XIPNbtSFkD
yMXvvnCoSeIJEkxZxR2BSxG6Oj6qdDUSLY6IQqzCoZalo51w0JwBDD1JQXGUBZgWdSfni1Q3
FwUioyvgXNNtlQB5GXzvTTE4oUZ92hmKSCwknThSUQ+pxSiJ9NiskT2GNu5B8v1pcJr2mTav
Bbby+xoIZMc4AS5yphHAhN36F2te+qsnG70fMAe7bqrS0Z1ui4ft8Aw5bV31UteqDlnkZqwC
/lihnaSW4Qbc6dj0OdVl83fimK1XSVsBXfx1tLrha6xvOxcSaj0ZEDNHWGerViGfrESr+2Eh
D58Q2QvgMAnzdd+VPFySh3rWpJeWZOXKgYy5xhj+Aj2u2oLtvA8PKznJbD0aZZMS2Ype0Woc
IVwp3ls/s0NdKASsmEV6pmTBibpqRbwyDELU4jMPuCfT58UOSi9UW3NslRkZWKV4jHHYcmUu
4Pfx+alaXV8/trUsHc6wr9Njv+AjU4yOvadjFSTq8jt8P/ak4jjZX9rVX93tTtucTb6ejHoQ
T4MqyxJ2LO3MZuS3UT5QqkazzuYwGLqBCr4qKCruqykb3z/+sT7maXO35Jljoij4s1iUOyv3
UKzdBB199iXYQfRhbrcNvn80qqwOrh+swrjpQioEzmnR/BgnholRqFyTFx/xfikW+buqhhBV
Evij4Qv2G/GobBZzfjz+PPM17Hte1+HNXu9TzvPAcHJLjgEpH1Ml7eAKaeVDwLFQ7Qd0Lgdk
zAMkFXEoWVR+4DJ/iVIbucd/7jdvZOco3AUlCGIekPVY0kZxPfN9h4QOC9gx3UCB/Nd4xBd9
54V+JaRwWiVZF6AHLtd2w7BRe5RVMDIczEdy0FRPiGd4M+hyYeNrtxYqFxhr3ocpq8SDcdQu
7bJVZKcaHURUaDGEToQObhNaXpSFSuhTOpdHv7F/ZVE4UWiDN1iCnQRW+yWDzANgiMc5A1Z+
0BE1sxaGa9Vkv0JxDRNPJlc9LphZY2cqbHh/G5iAqAVGnwEhh+gtT0I48bdD1OZMlsCHVOH+
h3EBJQ7leHqzhE8GbhkTRTdIel03e0+Eg0ujdXvUR280IZ8BKbqHOruVJyaEOGuzUF+FJVTl
gNH1O6qSZzfDdcSUTvZHBZBCi5wGJ2QHeOk2YLWxGKtBZtY4TSOIfqjjgsXEHUkzdZP3fxzU
WUMWfvvUf3sics0yK1KYgRXlJL02hmxjZluQZ3iFjBKUTiTwffhBaHDzjhNHRZrmfoHYgTTU
i7RBeJmEhEvDYcYXFgyZkFQ4M8+XBQq0feaIMsdygezEO/hoHu8kfD0ziR8xeVmUf+pSQE6A
f+lYfQLhkr4IUWrYcbD4RzNGBVYwUIrRVL2RNyrojLRoDil4ezT+tAQHCV96JBAVYlAUWGvL
YnshKZKJtTI7CQG0RGNXSVM+dnnCdmZuaBsAtXk1J3F0yGS/53SqiIhhiTJjGTuJd06xoFdw
CTlJaX5TuW8Y0pY1g4Wb9SgVh5GbuFMdF5Jr+RVTaRENYSbakJVqxCSCVW/UR0eRA4ebBTTy
V3Hx5pcUEFSQeIQP111XwpettYyF5pXhmH3OBoZUADRRkjT+52CSKZS0yJl16ZUWJDx91ZaP
cR6R5490NDl5aULCiJjzxwZSUSBsoHJyMZyZQkW4AJWk1ikmqI0H1V6mWAF+9HE1uXMT2XOf
wldzdkLHsmNNAR1kpSdEd1deWXiq9p3+FDSQn+YvEBUi8vlrhlmYzkkm4WmQUAViBUmMuJSW
l2ebqplmWOIuyCZuwDkxCLdPpGlAv6mOdacyJ1ZupPaZbsImvcFYzAVHA9qegXRT1scd3zah
GWpaObln+Iii+7memYULDZpuTYMlLCZYIuo7stegDIii0iljkUeVFVqRXQSfquUwmeF481Mg
REad0PGXOUqYtWIjFUKla1lYZWU3xaCK+0lvL2qZgWgm5GYOnRYePvOlrghKPLqlprKmfcCl
zkmWaFqFdXlGnTYKI9KZaGqg4XaEJXmYWACcTIRvUymnX0qnnMKEd6qalzmnayioIEoJfkqZ
V0qbzriGlppVqYvJGG3ABh8yUK+oqUIpqaHBExMiJaIKGpiaqpeKlZz6qU+xlVgZqqxaqtNx
qlyBq9Wwq7zaq776q8AarMI6rMRarMZ6rMiarMq6rMzarM76rAuQAAA7
}

set pieceImageData(Leipzig,55) {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}

set pieceImageData(Leipzig,60) {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}

set pieceImageData(Leipzig,65) {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}

set pieceImageData(Leipzig,70) {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}

set pieceImageData(Leipzig,75) {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}

set pieceImageData(Leipzig,80) {
R0lGODlhwANQAOeuAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoKCgsL
CwwMDA0NDQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZGRoaGhsb
GxwcHB0dHR4eHh8fHyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygoKCkpKSoqKisr
KywsLC0tLS4uLi8vLzAwMDExMTIyMjMzMzQ0NDU1NTY2Njc3Nzg4ODk5OTo6Ojs7
Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkNDQ0REREVFRUZGRkdHR0hISElJSUpKSktL
S0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVVVVZWVldXV1hYWFlZWVpaWltb
W1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2RkZGVlZWZmZmdnZ2hoaGlpaWpqamtr
a2xsbG1tbW5ubm9vb3BwcHFxcXJycnNzc3R0dHV1dXZ2dnd3d3h4eHl5eXp6ent7
e3x8fH19fX5+fn9/f4CAgIGBgYKCgoODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouL
i4yMjI2NjY6Ojo+Pj5CQkJGRkZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampub
m5ycnJ2dnZ6enp+fn6CgoKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqur
q6ysrK2tra6urq+vr7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7
u7y8vL29vb6+vr+/v8DAwMHBwcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvL
y8zMzM3Nzc7Ozs/Pz9DQ0NHR0dLS0tPT09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb
29zc3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl5ebm5ufn5+jo6Onp6erq6uvr
6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf39/j4+Pn5+fr6+vv7
+/z8/P39/f7+/v///yH5BAEKAMMALAAAAADAA1AAAAj+AIcJHEiwoMGDCBMqXMiw
ocOHECNKnEixosWLGDNq3Mixo8ePIEOKHEmypMmTKFOqXMmypcuXMGPKnEmzps2b
OHPq3Mmzp8+fQIMKHUq0qNGjSJMqXcq0qdOnUKNKnUq1qtWrWLNq3cq1q9evYMOK
HUu2rNmzaNOqXcu2rdu3cOPKnXsVgF27AeiaNHG3QMEBd13uuEsYQMLChQ8jBlDD
JgfCVfSWLJxX8ki+dv0SBGxX8GLDCD93Dr24cc3HdyNbBnnic4zVIAFQGNYEQIKB
AQDkaAK45eDFij8HL2x65gYAY6xFkwEadsfWi18771j4tsDchH0LJ7394OfiMo/+
J57O0e4YePz4wRszmnzGFQDU/fvXojkAQvOpNVf5O336AvsVZBc2+hSozzTtGQSA
AP7xYxd4MQGgx3z/+BNCgO5VJBqGGU4E33jDIKYdcNyR6F1pNXXXIUW5cUEhhVoA
UNmKFHUAQDzzIWHfMvOpA8ARLP32IoCKffPiNgkKKMCLD6YIzosh0lgRdp/NKGVE
NoKIGJAr/SZiiV+eiBiEMKl45UN2tfPifOwkKdQQTwFQRDnOCGDAQACsUE8+ZXBo
kpAUEkmakRQi6WeIS1LYJE0APElhlEVt6KZPkh7qEw5xEnanQGHyZyZBGw5HGJkv
fQpUpUTZpc+a/+gz6an+0jElXoKY2eXAiENWSuh8hm6Y6HyLzgQAHBT284GlPN0l
wbLMBjYUqkYBwIJTs+5XKwC3BlnpttwSl6KJz0qaKgD5sJrPqz+hG62zeNpFgGcA
5Crprv/0Ktqv/wQrEwQASPFMMioAMMW6APBIYTHsBgVtpMiOm+Rd747Y7cSSkuoS
v4UNHGkA5ZBAGBTl9BbuOqz62PBOCSdVAgAI1EfQA3dBAO+LxDAkz4vxNMQkYyhN
kQVDGNtFAkOq4QSACg8IQPI/4QQQgcvhhkpwUysnDLNdMktM8dZj9vzzQkEDMPRC
Rd8kozz4XAhAE/2gkxtRAsjJqhAADABUADy8nAD+zAssRQAAMtDjzzEDiDAMAghg
w40BJ4cEKKuQRy555PqKpABhAiyEgF2bJnT5XR+YPcY8EkQgTzoGbFAPG43bFLdo
dv8UgA8v39W3Un8XZvjm2WnN9e88l/S5XZkrxHvnCA0PQOg2YT0PPlIE0o85ALbe
PAA+nGOPPeb4oK7ZMuJ5xDd2PYAUzHn5QyE8ItjFxnzdLIjr5PTXz2rlIClQADLv
rJMIAApQCJUUoj9juMN/AIBB88bwD3pYwC4lwMc/WMcwU+mEXYUx31GuJpoOMId4
IyKHCEdIwhKa8IQoJCH+PqI8uwQwIQP0HGIU+C0ARIAe81lH7qxXk2sRpgX+CovA
34bBAgBU4x9eKl64FnAOVu3jCgAwgDfmE6INaCte9sti/VboEcO86AeW6l1ohvGi
wSxwPnewiyHmQ0Gi+PAuQDxVYIqIGCUKpVJhUF+I7GLFLtlFi4CUHBepAy4FpUxA
hYzQXab4j2yIUSg1+EwRFNaFeqCmA/34RzkQswSgpMAuIsBh5PZIRn488Ir7uIc8
2FGOblBDGQLhQxmg8AMYnGAEH+AABjCwgQ6EgAQruIEQnPAFPQgkGdPwxjneUY99
DLI85YBSGA8Jqmg+ioeTYSA7JGAXDtysjUOJ5GImKccNUamTP/lkpXiwjwpxgZol
eZwW/dEP9QUyX8H+G4kFOQVPfnZKJncpQj/qeY8sYXMmm9sBNgSijRgAoAEKY0ED
L4eO+fhjAYuBE0/EA4NVTQ4bb/uHOACgmZR4CXi/sxh16AWpEikEACw9qD7HQI3C
0cMdEzBANsApFN4hBqLlFE02isFBje6kWpIKwc34gYHM+BEA4uAGNZYhEEawgQq1
JMEGIpAAArzuLgEgAAIcgIES0KAIXDDmMJABDWts4xvkeOZG9rlHddGVJXb5QT/K
QYAHoK19MlWkMaQZ2JUwAHvzIUcYXjQEw8SIMFa6yQXsgoN2JpYg0ngRN+KmjX8U
Ea8oBZ5JADCETP4jHxKILCLtKgTT5iMCqu3+yGGrtAPvMA4D95gPPSbAMg75gEqI
eWGZRAMUDormSf1wxtViS5PJTgwBajpHP/UZ2t+NFjHM9ec0KTOS2S4mALVVUAD4
wdfyxSMfIivIb0Uj3FIBAB4vWsf3aMJNAHCjWC8qIsneAYTCII8m4lwBPwj7oDUh
SQH3AAfLVuI90RigAzugQh0EQoxkNCMa0WhGMmo2jDlIIQccqN5n0EkSDQCgA3xQ
QwOQ9UiDeIwDelBxYRliUElFYLXDmIaOp1HXgtS3Uh0Y7l2bu61tUGgfw0gA53Ai
zjoS5FiEWQB81WAXBDC4ulsj8UhMDCKXJsRjXfZIjTd0Y1AFAA07xBb+G95GkB9L
KsguYVwKWGUjK/PkamSMXDVoYNp/gKOphDHB9SSQW2meFwI1YFWIkOCPybJEbUf7
QzLEIQ+P3nM++oiHOI6hB+gAoAQocehd7DychXAmfCEB7rZe0C6pDeMFFMtuSRgn
GlLrxM0bsoA17PkPfMDhLoKuIWIK8KJ3FoYC+pgHdh6N5W6B+iSirvJCWmyQU8sa
I6quFKu12x1YT+za1LUGq5wxX5hUTwi8tl8/hgFccKMkbgJQ05pClFsJJJpVVADA
OkL0NZVgjAnpvjTk/MEEu0iAI1WIgAJCsBBas7gBGJ22CxeCAQWMTSK/szO0fEqx
liwsJw7nVgf+xPEidoDZ3Sf56rCLvRgG9gkA/U5J2BZjAA20gAmRWwILMCDizxx8
IwlfeMOnW1cWT1whFb94RD5TgQk3g6pQUPKouU0ijktgDMNwBiy/gNFEmiRuFOgz
hfgBMzvapALdLNc92YFUGcQkCJ2BHL3/YW/I4WMBQpDHgllC6zy/yB/4uGk6yCGO
b3CDG98QBznQ4Y7niZ2K0p5rYfp4EDpaigcACAQfAICp4OQgISHH3tKBFwAH3KUL
6yjQOr5wF9iidCUq/4zZawLorSVBlP9Y9+vcDhO4i4bYFDI2YsRhMlunxOEXEHjk
nLt3jSCG8gaxvEIwf5fOc+fzCAk97SD+shgpvGPg4wAjXkxvFwooYx3s2AYUWo+d
ALCBHQM/x4fCXJIR2AUakWuGXUaQE7tooNCXtg+PdRdA5RJ2gUlyBwD1dm+scg3v
dRwusWzRMAxScAIPkG2S4gAlwARZpwx4wRGmNwz40A/t4DEvZRfhdRDHogz6xwEJ
gXbosn5SIDj0oCMQcWqUUQTR8A730A/7MA/ewActZBdqwCpusBhBZg72sA/8UA/7
VjWLETEnYX/bwn9GAzwFsAy89g6oUYAetyHANx/CVxgm0GjllmpYpHyChHIOQX70
ByoomBBQ1k0v2E/r90+m5l8kRz/l8ECEkQOWRSHQUBgwgCOT4w/+xoAYUnhdDGAO
zsAHSdACLDAEYTAM5DBbV4gB9qCG85GIhBE7X4gNo6SAdMeAa+IPGsAp7oUXE6AB
QwgABIABFoCDd8EAG5Ba1HYRy/Mi6fAjwZFdl8MNI/VfcIguBTAAgXguP8cQN/AZ
NwBfkcMP0WBc78Uq8VAYK2AOk9MNvLUY2Hdd3HKFoYUDALgP7CE/BgiGLPcZ30BK
X8iJgkRIW/KLMnQXxNhqh9JzyuIQzUgYBVBRrFJPa7IPBWcXDGBpL9JkwxBw/hBw
8zGIhfGNJLE1NvFACDAP89EP8cAO6AAOxOCQ9NMNaTZjFsEvE9Bnw6ABKumKpCgB
BLCSGtD+BS8SDQvgDSSJEScGDgM2H/YwDJzxAulgT/6ADvVRN8MAgPzwDY/RRVrw
IvhwNKVGGoyHLrnIKRiwJiHYEJ9xByA5kKxzF49XIdhBAM3QlS+SD2CGhyFBkbSH
OSXAA0hQiVy2LQ6gjRRyDMvGEjNnF1BQB36JH4Lol35ZGDfQJjdpEaRlP9WDAPaj
Al20GI7pZWLST1VZdG84mXbhDC9yD8QgAxglABTgBNbgUf6gB3EHOcdgF81AIfWg
DDkAAQEQAA+ggzs5H3Oglh8Re9jCASVQAhywYtzFKF70D80QcsRyT+VVmdTld/8Q
IjKwA9C5A6uiBdG5AwNgivoQANX+cJgVgQAQoHZr4kgdUJtjZ2JGxir44ABemBEA
EAMv8g4AUDaIxDgrQBruUA+vojyeYwC81g8BYB0MsRhdYJasEg3Y4ZD+kBsQ4A5a
lA9IdYYYoZuVwobgCABXgJD1gIGiEQD4RyHgUD2ghRjQSD+IEQ+X8xIcF5HzAYV3
QQLzUQWisZ44uRjyWYx5AiZ+op/JsxgAKnF3cQG85gwpOnUDZoaiCDnc0C/zcQ+B
oKEUYE3/cA+xVxIEUABAYhfIEJbr1hlFQACgCBOMQwCrEleQdTOXFjKXSV1Q2pyk
ODl19yIyUAcXUCrM+XcNcAyjJAGS01IawTiEwg9OYCmbgwz+/EIa9OAqfrJgAMAA
L7WQFcKnSPdTCGk/3xA3uEch9AAAE3Cp9iNdiDGnI1GlV7otw9ClX/oSDoeAL2II
XMOc1AOh5bEYIzo5ImIF3EkRGzIAwLIY8+GGXmcRoacuHIejJcKoonKGtXeabCop
HIAjxzENkeNIXyBSr/iJe/gPtUEYoDpaD0CeL6IPgvIteTaGwylwDuiPKmEXgcim
48AO7soOmfQO78oODmCKzTkBQ1CjKAEAmhk5JNBZkEMNLSA5yHCr/ORBn6MQzAFL
iUou/TApMDoM+ieRhjQBNMBNFuAQwHFpg1inzTkAZhpI6pSmHxGO16Os89EOEkqq
L2L+DoBxqpMhq/bzqcQQn+koGruKGPMxkiSLq7gpEB/0KmoJo3dBsat1FxmrlYVh
l+jALQbACHZRBqOYAH/ALQiwif/gicrZEbmBp3uKasICABxgWTV7F2MQloFkmdA3
GWEIeYVRb8SxJssAOHQaOf1gZaO0AGj7D5v3EdQ4e6AyDJnaXu2SSelFELkxD5Ba
ECEHuMcKAAx6T/2gAHkhQb3Gbgx0aVq7tRyhodhVE8CFc+vTjdb1IvohGynxGbMq
SCJisBgnGgyQs4UxH7jWsxTxtyd4dEc7KcClEI3LfYVRD/PRZN0iAN+3Jv3ghxOT
ZyNluxrxGAuwrui5OQwnE5f+gwAjKo05Zoic6A/RBqvsaQFrsg7QUL7QgHn1pgHm
Cw2OQiHa0HwswQEGwL3S5AAASCH2cFge+w/wUAAnMBLYkS3eIQT0wSG20asGvAL/
YIMIMZcTgRgDsLf1gwa203X2JXBN+7MdgRrcUr0xMYR3YAyl6rndIm4UArWu66OF
IQAsLACMSSFh0MISSmUv8RgCQLmzOx9ZgBhVoCjVARj/KxIBLCqYacCV6cCvSxir
8pSLUQBDQI2EEQFLMx9PJBoY4ATBCgAQ0CMaHKsmPDkemMITATME0ERqOAzpMDn1
0HMUipNb/LULODnbKcbcdxvxUE/6cA4DKAHSUA8DVQ/+0RABd8EF6KAP/sAPObM5
JHGHAGA43rEA/zC30yIgHTAfx2IQx5EM/wAzCHEEd7Fto0cY4itw0fAZ9wtI8/Cr
j7m8MQHFv8MHlnkXAwB/88FU4KuLktK25IoYn2WAI2A/I0AACzCw9bOMIcHIjmxI
dzHJNuomSNXJn/zAhbEqm4QYQpBbWyoa24cG1RoAxqA+99BghSFBGcy57AkAoks/
/hAwdPwQl0MAa3ppDoIE9GOZkTkZA2CWc/emo9jOGisbKhcAHAADJKCPJFUCMLAB
wAWatyzNcWhI9GAPbgIAOzAfOAAAWrZH9XAPQkt0x/rLktMP3AAOaNsOixEBkYP+
D9eQxpLDxM47o2zpEhZcXcI7pHaBAYHoqck8kbm8jrDjzwHaw/C4JjREXQ+9uxjC
SUgtmaF8FzhkLwcodrE8MdTwIvsAg4SBI+Tz0sAKAAtwypIzD4xzjycBGPAMj/CA
HPTDD6Tb0D6LtQkYx5JzhEC9EHyBp/EAouDZD9vQdQywDX2GD3tUADfjgbESEn7I
ZgWBUUZGAwECAwDwPv/AHkoXIu45UsYqINhRZkl8FxwgOfXAZRqAkQOZbUeApLTm
BHuLn12cEVm8LWRtErSIUgRATxuSCC+SRnVNdSsXfKTqEiZAAJCD1QbAKg5HAZAz
AIcNEsrLITP92IhR2YX+kdk2ytlNnSaNhBjRgLyWRzHHSTMi+g8IwtUUcYfZAEjj
DQWglQAszYlJ6nfeSiHMQIbXFc/SJNeRkyWlgozzkW+BADnVDJBrArVUUMvhKhJi
Ew+8ZRBmJN4kRRBol2chQt2Asd0hkoK4cQHyANkV4UMOIDmQDTphmawoOx/xgIP7
y7+I8WzHjFLqvRLNdhdzxtokRYsBMKL38DfMw9Pq6NsfB+OE4cM5LLt3IeRufd0M
XhglNQxYXYubURgYfh3mjBA+JIrhgBi55Q9wcAXC2yaN8aAzNAw5MAC51Q4/UAcm
jhjCa5ksHhvofE8NphLe5gCRC48hklnNGQAha9X+KWoSITWK+I2euotXGnBN8sYq
EJB8kOMO5WojJTEAA5AP9FCoApIDrTJEA1Hh80Fu+wGLq9JfBkEAFWAP+HC4na2u
kKN3AGACYwAg4rYPfSbOd/EMR5ZJXaCpdQAzego5zTvliBlaKpEDMX4XjKBJdnEC
5IUYP0BYft7TPr4hhJuuQY5E3zUfGHgDRP7o9Ncps93p9DeSv34X+GHSn6g+10jR
VDQf88CzhPEA5eIPecZl5eJMhZFJ3Q3UdlHnWmQyKVFfF8CpalgfJNMPSia8CUgY
eUMSzIHtgF6KkvO+clIqJXBNBs8qJPACkSPRfhcwo0VGJhogAMRGAIAB7bL+h807
EE0l2fpLEAjQABgZItbn0HdxvGsyDnaBkQ6YN2JjWrpNGHsoDwZAAN0wAAIgvKUM
APH9D6lJ3j77eihB4s1mZEu/3WRaGDR/DwCy3CARtJ+hy5VCTl9Y5P8whzn8GZWM
Tx7tfGGGGCTP280B9QWRojF/6h/QQHeBAccQA+ojX3YhvH1mmqJRDBSy907da1Dw
DDDImPswpSLRVHN2aceyrSTxOR8A1srH0QSQSTap6JDD976uiwIwqdcU6GtibGWC
3JBn37mHAAwAktLld442GQRQLutw4HaRW4bZLoZ47u0Cf0xMEPoDf/tw4BNRBIXR
rxSSD9OADaqy+gP+kDt4HsvQeIebAwXzsdXsgA0Bx8h2kdEeAfVbI/kjAZzDviCr
4skJsCpTPQfMHrO/59PEtYp/ROScMx82DQbZ7v6PZCLdAS5DeBEAUQTAwIGBhBAs
969fv3/xCDr79w9etH/pCF4kaK/fMHkRhxHUpzCiN4JwpGBcMkzlSpYtXb58OXBY
RJo1bd78CADmTp49FQwcke/mUKJDPzpRKEJnUX8PMPaEGlVlAADZiH6EICFADaL7
CMiUGlasygEA7kWEASAGQ5s5id3sR0NtxHsABozFu7IAAGoRwQUIsHIgu4g7AARR
aZdtPwM6h2UBkCMiO7DDFgT4FnEbAAF5W2L+hGITDYCfAOpF5AIAgbILMCJiwwgg
ZL4AR3JiiziNc2OrNPuVJuhZbGzixZ8KF+vA+HLmA+/80/f12D9/GIgPCBnxXWXk
UakaH3BO/DkczbufH1Z2QlmaCGLXjG2AJoACFOyij7oXY+DEsRHnjE0lyAJUaYHY
OutuuXlq6qcsALSISAYA1OnnK+I2+Ac2JiJiYaAKbKLMOPx4Ggi3ok6MhrsRXeJg
oA7wOTHGoeRx7xx/5gAgAHpO5AMjCFbciQkAkiDKmRqOrCERoq4Z6AYgPXuwHmgI
ImEbevS5x5wxLhrjnHv0oScbEgiSpp4uHHsSJgCAoImY+3ISJ6J1ZOr+YM2aTiIh
J3ciEgcsA42hyQoAbOtug4uwq0kggsKJqBkAyvhHmQD2+cccjAbgEwB4/mEAgB3/
YeSiZWoqB6MN0vysOVVRbekDVa9bBsDYMBDqIzb8+Wez4ripyQQAGmCVJSFfbc7J
YKVagCgRHsCAKAweEIGoBI5N9dL+AqyTuDyLK5A4QpEztLh4/sFnwX9yGAiCiCYA
AJp/UiguNEIAYEGh79CISB2hSi3u1GMHilPGoUhCM9iBHDhNYIXZcYqLd26QKUbY
jqM2x7MUvikGFand6aIHLHAvtgEokEAA4hK4wKngOE4sAKEi6vEicGiSlRyFGFLn
opkyvSgQ3xr+ww+jZ2q6Qqcalvon55nGAeCdf+a8KNl/kAmAn38wkC+iEABIxAkA
rKnpTJ0rJnY5jst+6h93ijvhLHo+MFEf64oLoyZnNkYVbbNZ7gkAjDEugW9Z9Sac
uKCLi1MPBWoliFJDZ9rS8H+OAGCHf+QhCDd6OvsnRW7J5vVvmpgsGNWyAjgnIn/Y
wfXEeQrwhih/kjldroGaYKsohyg+VgUA3hI9IngG4kFwEjXwhtKI6ElvoBXOWcyc
FQbqLOF/9uFGg9KPNXkbmvwJ46JmtklmmD9MBoCAFVR+YAULA0hkmGW0mZKgJFr/
h1/8KrhIA/w/usfwPkAXAODLIeOQCEb+LBARRkwgIgkwQUTsAQAL9CMbANiTBL8z
EAmcrXC8Mx1GYmAfVe1IGeKKiDtapw90GScB+KPN9lDluw8SpHjGg4kCBBYyHdYE
CiPgSk0QIDj01dCI++MWqH73j+0MZE+GUcM/BkcQZPxDQm74B9MGAqNELIUNxekg
2ZgRvIgUA29AGsgcaGJGQJ0oHEizSTnghREJUERG/ggZlVgGAArg7284kiEOh6GA
B8DoJkzagNVssg/r9MYm+GjAtFg2BACMAR/mWIYepmfE4uBgGM7w0kcCdziCgC1f
AJiZXHbkjwC04HIA8B49MBKtf4ThQ/kAAFL+IQ0AVJEQBshdIED+yCpOnnFFGKGC
P/ChqhdERGOxcYBN/LGNCDSnIzR5AQA+sEdOCvIlwIlNaN4VmwhGxIV8oySxBqCB
E9zgCFqAAxy0cIQanEADDnrVKNHTr4oAAAO4ugDA/iHM50xxINWw4lKoMRDX7MMA
AahHPzplOA9CioxUMOaIBhORc1AlHTH6iBQ+lQ91DMNVFwkAD5RxDmcY4lMn6tAw
UWWo2InuHmXxZkx2dhN/MKAYV4lAUT4iuOYYIARIMAQxsgGOcqSjHfGIRzvSUY5v
ZIMYhkBCCBrDHDQSJALK8wcEcPCPhSojIgsoQD8c8gx/1AMjLOCHP6gggX+gAwBs
iEgRAnD+j3wYAIsRkccGA5mmYg5WowRpgdW6sap/gKM4BWidPJhBBUJEw6AX8R7N
MrqicH0wpy5ZTtaKExGliIhvy4lAEoZBDXTUw4+yqwc6qDGMJlTTtIeNTTsS+tGc
gC1FSmJGcWZGyYQYYyBVZBIWHUtRjvlKAbnDGGMAkKdgtQAABsAVOwz0nBOdA58D
KGKO8CmADQYAHTIqA4HOpgKakJR8LCGGNcphvY+E8bOCGRpRSKANolCjmURBhmGf
FJsAkEANxyiHPchIk3uQgxhfaJF6cQsAQmjWHPoYAAzUCgEA6CEJqhHsoQhAgDkI
BAr2yIcALPcR3VIHYgTZAd98ZUT+6rLqaE0Syj1UxhwElMFCKC2LOVRXk+GZrSYh
Oi1GCCACGRShC2W4whBMYCA63pclzDEncda1N24SBANhOIY5DLngmuCjHMS4gm1X
dszY1CFpAHBziAjhDWFSYH3FYYAIfmIIamDUNP/gAQFOYzuMxDjJfRHd3QSMHv41
6x/lKQF0b3IPKsdmAoK5CAKQkIxrglTCx/KBTupAwuUkwAnOcI+Vr7xTm/yG1TUZ
RgNeSxNDLHpFTlFAE4iRDuWRuSj5EMcwUkCVuwyYIDb7R19HwIxO4fODX1GBNAbg
A5oomnjG6+axsgUAwvBjk4S7dGJEMOZ6ZCMMWzWOLlX3E77+hRoADPjGPGbd3nKk
09ZJLo7URvuPEXCZY05JAjqy42sZ2QMcgip2Vy8igB2dexhiM2IAVLuUcxDnhnwr
iwR6LTB9KAdBwQpoAzwihTET5SQCBoCTtBGPeRfFGrGBAd++EwAMNEElxHCGM4ih
EijMbbM4xAACOg1rAESg5HRxCvBsIg8DiADbrya4jO6Wg7wNRAH0mMcgY6MAFWhB
JdBYKjnMgY5ziKMb2IhG+bSwggYQxwLDqIc78ClIZ+vt46za2kCM0Y5svqpv1z1C
Etr+qgHWBAj0kjkAoiiwPt2bb9YJQN39FpElxKYI88FIAUzmdKKyKeoY+wjVCYsR
GXD+Ad1W7/rXwz72sp897cNY++APJYRtrxnbuWw5Tw/ieORU3ixDmTUvBawcp5GR
HCIj6gcUeSJ+fEQDqv6MAowxD4bsIx3hGwgFqnEPf/jDHtNg10DGoA5K9UMexGA3
tsv5eYGl12ADqTRpnICMcxz9b/yARzaG0YLw5jGnNewy4tA0/ZApllCOwhkAP/qI
hDsbKwkHYxiGMWgCIQACJugClfgGedCHAHg+6FuJwouRDxCABEgBgekAHLKLjWO/
ogio99u6+as/MsM//eO/zxGkbPmD3PMNOBgIDuCmNvINNrAAP4oGquCCvjkCMlub
T/uXnQITeHAHd4AHesiH1tn+jovzQKsbiA1qgA6ggBDLkQrogInKES3kvaAJgIFb
waLgsH8hiAcYBnXQwQXjB3EwBDI8QyCpvbLxQQ8Srn/Qhtg4QhKpoZLjhp87pjxi
DgcYACyEvslbwzw8D4GSkX7QB3yoB3mIQnmoB3zQB0kjit1xw4GAQzlcw4iowzsc
m5yaKCCwv5q4hxZiAL75iQZ4mYjgQUdTiD8YiCHoGwJ4qeCZICZkFbkIBDUoAQLE
CAHoACsoBgK4O1XTmJlwBwv5A+vZB2kImQSQhl6jB2FKH6f5iBS4PWQ7xRlBROR4
CFA8x36ghu+4Lzx8lVlkGXkMjogIrovwRUKsoXGhCcz+kUTPILQFaAEp0AOWMAQu
2IHw4wwPVIkYYIChKC0AiCabkL0QGAoFIEeigiMGY6mHg4EIAEOMeIAWOMJmMAcF
s4kTCsiwWMdzhIt3TMdgCT8DgLubYB79sC9uuoHsgJOI0IcbgwqTkQZf2wfmopaR
rAFuKAcoGEmHXEDl8ZrFswmCQaCbcAMAECd++ArjaTuoi4h+oAd0yAZlUIk6CIMr
gAIp0IIwqAOVmB90oAd2/IdqoI9gAYOBGCuiEEuyNMthQEu1ZEu3hEttkEu6/Ack
GIhBzCmGVJWd9MOLcAJc0QcOsz2YCK/CSZ3vwSmWoYptsL/Xsj65gEqMwDzTPM3+
i0jNlvSMtquXfkCHYUiCHTMiBvBFc7AaLbhLVslLANjLoejLsjzLtFzLtnxL+THM
uSwKxQQAxswpRRmIEPgClfiCkxqI/7g9ChiGk9uZeygtqGgMPSA4f0DKJlwHZPgw
FtgUmrCH1GCBYRiHiitNXfyIdQDOAaCrobCInWoR44GYDQlLdUAGLuiAkVSVAOAA
KyAGdFi+LjoBN0QCBhFQAjXQ5kBQBWXQmvgw1hwR6GQO7ORI+2EIf2iCVdyJ0/ug
zKIJ7TktEIyIfYiGENDOi6GJFClN1cwyJYuIkeSBHJ1J/ICYAFABZSysQ4GBvXjQ
94tQ35jQAi2cC13Q5fv+hw19xFURJHcjiBvAlXWwD/7gicbAnahDUQCggT1SB7UZ
EwBIAWuIq3DYPQjIjKuhx0dcv4+wHptAgP+6CczZKd9BwQkoNycYU+IIgEDQTVUh
ACGIhnqwLrIRgG6wh2wQVFVpgJ1TRONI1EXNBvSpUvO40oswkXz8uUElnKKsiVCT
AW56ACrwnnjwOQBIAJtZhzn4AKqYU1VDTXtDzeJwtAJ0wbIp1EPVG0eFVEkl1dgo
gApVMkUtN061soH4gXMYhhMojQUgx3PggR9VOAAoAWw4n58rix9AzL+hTVLkGAQw
gHwYhhBTAMccCCu4hx5xSAD4EI/gtqHQB3olCvn+pAnrQMHlKElFpIJrcgfmHAgE
aIFyJUZjK5sGKAbl0YdhsEdPfVZi+T+Z8Adj2CCokLwPmo6aqAMAgENqCZnAUKR+
2IYY+ABnyA5/aAb/y0Ic/QfiqMjioAEf5dC8YI4PSAI1A4CBTSGDBYAJSII9XNht
JRabxMRE+LGyUbXGMIA7XYiaoIevkKQbLM+XoAomGNe/ITWC8NJfJQgEwIATeAEZ
WAERgIDMzNlj2quIOJormDU3gSWe8pobiAh8oIp/LY4kYIh8sAAAqAHCsIl1QJcK
EIp+ENqjXZF+IwgHCINLvYgdUMHroZziCIAcSAuCCIGnLZurxaFsaVqoUNb+YW2L
HDmbB2iCDCq4MjiaeRVZqqCJMYUPHTUnAVAZviWOOsAVfjgBwSXcmjBcAHiBEQUk
GwwWx32VIbpFchkGyV2Ozr2vuTGlE1G0bcopLnAQBYCKgSiDrv2bgGLcw3qAO7CG
d1DDmvA+cyCGHdg8D6ScMriHlxuIbVoqb2gGKADbTesGcNC/kwqAa7gHNQAAMNDd
ItAGKXCQmpIiAPCB4KWJePiwnVqs67qDdUiNyySmgVABBesHcRBWjCCBbsAfcrAu
4vgAaDiLjdBgQXpVwvss7R0I0FWTIo2YmrDLtu3encoHdtAGZ4BAlVCGaSgH5Uy2
AOA8XK3XNXSKA07+YAc5L3t94JuQYAAwK44aCAO44AzWVuG4iDkghzlIAOIQgOqt
yo4NgB+ghmkgQCtLUz5QmNEAgBaAyhoehjkUHe0ZX/S4AAO4Bjy2iXv4Ah1Gj44t
JgbkmDTVidbZB2YIABUFECnwx3j9Dkagic1Qg5bNSuehljTlguWrhzkqjg7IBnGI
qeJAgDh9Dao4wc9SZLSh4zoGLRu+YZogGGoJKHWwBimY2P1QgWGAB8rxQEyBSUTu
5OBgZEcWMnsdCEmmCz74jiqKCEvJZNXZZABYgWO2C1NViG4Y1BLwBvw5hxsLkDF7
h7lpZW8qgYEQAvANS8NAPFlWibQIAIg4RaP+JeSOoYIFqwtVs5ACCAOVcAZs+IZy
WId2gAd5oAd6qAd7sAd6kId4eId2YId0GIdtiIZiUIkw0A9jZhUHGSOaOOeUoxR6
oM0AcINhOD0H2JGgpA9z9IeieZNgGTwDGANw6AdyiL8j8od2GAbxJYDPWucPek95
HobNpWWuiaMuxgvOcNdXsQ9/HggSKIopwAEYUIER6IAOCIESUAEY4AEwIIoI8+gQ
AoCQ1g7r6ALKtM4cSenTK4Hy080CgGmZLusVabsAMMd/sIdTJo4OwIZxXg4FCJi8
tY6g9ib+UQsplZF9OGEMkGfrQIDCXsNXbmE0CozmFRh2gJj70g8BCAT+Gl1BSh6I
u16RywUAGXCGe6CGHyOACihdsK2A7yJhcTiC79jHYBlqgngo4xAAB/gAHOgCNICC
H4gBE7AAUr3UDhQkxa4hyJblF7bhPyhcph6LbMspIk1qa6EW1FZt1v6xCaABcFqO
BaABCSCIAajt2+5FahlqATgCbNCHcuhlwhmGfjiHP6Ay5jYeKjsCxhaYfVAUYIFK
A5mA9TzH3fPVDt1CT+KGdrgHKfUHMDkHaLgDxcbeTx2ILjAXmPyHeeBiY6HJ7QZb
nx1ZsimOCfgCZSji9B2KfXAHbZjW28Khnf4gAndIG7dhNyMy6xYLD9WbDMchLBXA
COiAFKABIHD+gi8oAzaYAz3QgzlggzL4AicAAhpIgQ6IAOjNUmp56uUIgARQgAVY
AAVIAGUNABMPQLuIbbRp2nwWizFWPHcGzi8CgAVwyLJIAdE+RYPimzfPkQJAAMkL
AB+4L3hmXQ+niSWsgcgstQsw2xrgAR6ogRc4gQuQc4qllhe7CBxwhg5fMHyIht+9
iJgTpEwvJjwfZhInCHyhWh/HC0AHc0P/LHiuAW04h3aYh3vYB0COEX/Yh3uYB3c4
h224sUZHceKYADUAJXqoXOrYh3koh2UIA8tE3mPhdOYoAAnAgA/ogA3YgA74AAyQ
gGPFCFM3ntIIBF+XHV58N+ijiiZ49hX+nIes5ZgimKgB2KoEoHXog2dFH4qBQPZR
vAgM8DpvgHA89od7aIdvIIYwaOvLrroc0YNgrIl9sAd5gAd4gKqN50R9aDlw2DFv
Iu9iutXPanMjYq+aGEZBwvfY4HeHhOdXhMllElxHH4i3Q3DReYdhCNw9ZrOt64KV
ogcAh4uxpHYdh3OpmBu5jTp/yOB0vtgcBPiICNkFh4oaGIES+JbhUAN+YOEYwAsm
SIEQKNMnUWyO/JFkvwFr4HMy0wdv0IKNTTIBuErVWYft5ABDPpQNgIJhWAc/moet
cmESl3pvYvVlLLmWFw6t53qdFaGxL/uzBxLF1mxFxyUAWHuCBwD+DeAGdmcKb9jD
ECUIGhAH0OcpcoBnE00yuGK/ftik+6rlqteHiMcLPeZVqXiAt/0HfjAAm4yKiVT2
fUp8i7Ux+EsImJyHGUtVjrkxi4oIafj5i0gADBCBE2gBFjCBEACZ2KAAe46IeUlt
3U1q2S9+nakJt8pD3CcO6IYKhQV+qBB+SyN+gmCCbwCHbbAGaCgflUiEOQCIL1CE
1FARAsODBxhCqKghBMqXOYmGUUz2zNo2cN+YAOjYkSLIkCJHkiRZwyMAK/z+sfyn
b502inOoIAGSY4eQJFbuDCO2jd2+lv/6/UApoyTSpEpPoiQm1J88cc6GMSpjpUmR
I06uoKH+GI3cPH9Ch6EEcFQp2rQhOz64J/Qt3Lhw7zn4qPbu3Y6J5PLt65elPRYo
8SoIsEHIMHL09OmLJ45QhI4Q0AIAIhQOALQYOjqY4w1evn31zg078iGAAbwky7Ju
7fo17LKqVXu89vc2X3seZ/Mm27Fby2cdFbiJts6eWL7+7K2D5kZBR2Utx+3u3Ts2
9uzWt1PM7t37AHgt69lVCz37ZKWuNXtPvf07/PjluZdE+SJ5vGEf5AMIIGKYPCz1
k8Jg9KUlm4DZIIGAfAo4sU0/LJUhm4FqbdARN7hp+I82HX1QoWoCAJBEchuaCJc/
4/imlgEfrSSXP9uEMN9IBABgjlD+8AQQQFIdYVBNhHL1Q0xHA1jXkTX5KLkkk006
+SSUUEZDI4jddUTOiRvyEwCVVa71EUvuCGCAM0Ge2E80CASwDkvIVOclUhfyB9+H
cKIl4px5RhDgP/R0SVKL8SVl4xDDGEDBMGH012N8Rl6XJ6Ss2QkSShn6MwyXkQaQ
iFjiFDjplx7R8088HEQKQAcBkvcpqF8OkeVtRWXWKkkPAGCBPrDq2tI+f4pUVgNs
/sPPPfiU+I8/0zC4wEgkgDlsrv8U0xEHI0EAwADHHOtPPva8KA8FFM7W0Te77rqN
rwZ6BENQ5sLo26y0wptAgJhN4242AHDRJwNvygvvqbH9K5L+rQHLR8Aw5mCTLqVz
MiuSs5mJNUw0LPlWrUjXzvnoMN94/DHIIYs8MskkrwiqRwHkeozBYPYzgL+toiQC
Sx0Y3AFLJ7BKawkdCesuXOl0xMLADZ8DtK4tojUjAArkAEAB6ywjQqYC7LBMtP/U
I4RrPLKkDwwhuPWPM3iyxkI8LfEzzRE2dtQBMe8kAAANBadHGwDlIm0iuvHaeYFH
GHBzLNDp3ODRBQMDzhY6gqHjLjsAfLDOBIgX3XPLsBFdNMCZ87f0cE8HPAxL/PDA
Qrud51m3ZLyRu7eJ5TDM3eIPsCRD5imwZEFHif+7OAA59Jn5qENYPnBHNMAOVwuz
V9n+ERTLnxguXj4AMATwZSEwzIv/qAPHBgo4sMEOw7jDUj4EAoBBPSzlB0QHDyiA
wRjltDRkv609kAQAKnD3uvRu0zdaaYwthvjG2GCFD3IMYzMeeQDnChgAmJkAH7vK
xwoAIIBMAQCCRfOcwD4IwjxVL2CG+BoMOpKCfFgsYP57T94CeBvZ+c1OGqMIBw1m
JQ8OTGMBsELEDFYCK2SKh//qSMVkSDbngagj7FAibvaDF5QkYCSRAUAFuGEmucTD
ZguoXAR+BiNx2AwADRjJAnY2rhhCkS8DpFUWWhOBJAzDGeFQhzzuEZp+9GMf+biH
PNQRjqk4oQKtAQPnKBLHsij+AEAnmscw0lgWRHJuhK+ppCU/lxePVFEkV8QO6egh
AgB8EQAbEM86vHNGkUiSiUjJpKDgCMuOUJJzi4RlLf+1g44kMIC6AcASBtYinLXR
L/5oQA0ZBYDtIaVgDCAEAuGSHxsJgCIF6M8d3EG4e4hjGBprJFLq4srVsLGYcHmj
vI5gyWAmMiTqZM0DnFBHbpRjHe14xzvawQ5zdAMaw5DCJ1HCTs7tcpYCFaZB4bPJ
ZSalYLARgAyoaU0NJiFcsQFnScSZzCkmFJT/eicIB9rO0qyznYEqAEpTqtKVsrSl
Lu1IJ+VVpAY44AEQiIAEJkABClTAAj79KVCDKtQKVID+AhOYgAQiAIGEOKABTmUA
A+a20fqsLy2B6ogBOkCDGpwAmVgNiVSbRoIa1CAEDPKIo5QSMRgiYAFufStc4yrX
udKVroFK5AsCFoAYjBQpeT3VXvtqqI7CFHmE1Y5afGTV7LiHImGFTVqTstYjHfaS
nPurpvgq2JFgFlKB7Wtlpwqn0IbwQCHAyw5g5hookLM1ATiLWgSTS7yRVlztxMFV
s4OAHGxWLbiFz257a6XDGra2rcnLae+S2tewdiSveS1eZEtZ48aMc7/9TnCFq5Tr
eie72v1ulbIg3vGSt7zmPS9604te8LJXve59L3zJy9750re+9g1JfPOr3/XeV7BJ
+/1vfvsr4AETuMAGPjCCE6zgBTO4wQ5+MIQjLOEJU7jCFr4whjOs4Q1zuMMe/jCI
QyziEZO4xCY+MYpTrOIVs7jFLn4xjF0cEAA7
}

set pieceImageData(Leipzig,85) {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}

set pieceImageData(Leipzig,90) {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}

set pieceImageData(Leipzig,95) {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}

####################
# Merida:

lappend boardStyles Merida

set pieceImageData(Merida,25) {
R0lGODlhLAEZAMIAAL+/v39/fz8/PwAAAP///////////////yH5BAEKAAcALAAAAAAsARkA
AAP+eLrc/jDKSau9OOvNu/9gKI5kaZ5oqmJAAGTCq8heS1etqwT8zt+P1kIwECx0mcHHBqMB
N8xLTsYL+JARoYJo3D0pyk5AMLZeikaAoNshsytls1sxKEvU4x3BXH9TWnVfcAOEZhaEaUUf
hGEWAYV0hJF1d4iTl1KPWEkEnY0VAwRqoWSbGAIEfhM8BIwBe4x7hgujAGqtW3kHpLZFgrSa
vxOMkmeIrqbGnxSPxM6uDgCEvcVck9TCB4DJh524Fy5rr1Vr2Q+aGKze6949DaE9jzSN0las
yxD4GM7phcjlGtCBe0Zw1iR7A+bRotRMnwOHjl6RkbKGHYBOeFigigH+rlSVjzwmNqjlY0Ej
d9I4TrDGoaHBSkUaxhAl0oK0aeBesWPnjsFNKoZOmvlJgWXAhLBeQpipc2cqpUFQdVL5h4zT
TmMEIdElkJI2qFoOzAzL7ZwzqA64EHE2s+aEm4zMzfAIkpxWKl26DgVraKyhsg3GsHMbIVSR
q57MVVy35oK4uo0jcNVR5aucl/V41AnlSZPmbA2JoWVQJxVBpAmLElQVYfFg1kfypkZXL1e0
OpoftWrlWd4wpxCB/VjXFCNsWlJ3T5VLB/gqhkI2HnCB0OAt4qXlDRZ2OviMhKE3I6L5llir
uGfqPnpeXawidAKRi2LVO7uLVNydr7y4kzP+Y2F+BTLfGfplsd4rShi2yx67mDKTRRvxt44a
EnSnGkHnFYKfBGslt9Zo75xWnhLN7CIJJDgxEMNa09wSA1yBHCeWhMatUpw3LeykSz7r+PcN
KAW2hsceLtIXw0s+EqdOfxyu9txqoaGy4wPOZFgMKCIOE9M0rhSy1kNWTlMFjIT8GARSGKWW
RXLY0ehNcA/ugSOIpAXJYzlquEFGnmY255Q0br4JkzPCkEkMi7H02QCiodFpUpYVHlMEIx0y
AiaiviT0DCre6dbZfsX1Bhxa121HIJPDuIDGlqv24sCS7CTZDojhgYgpMs8gSGp3zJlIEBjd
/RqYqlUadqgsa97+mFVhpYoUp5KVgKRmN6hKEAdiISmFJka53YejjKNs+kum0Lh3FrJZlIbV
tFgKay0ykJX7Ti8e7UZOKBQy+ydEUtmiUqk80SphWDjw+taRH+E2JlWLcqFeSGhoaeFSa6yh
pqH2rUJGH47KtxPDZyLWoyAV5dDtcJEtFei3EOBx5Hcrw5JqwhQhBnJae/45hoxs2rxSsIqc
udlQp43jncIhSQF0NhsHO2VaQFvCocipGBiZGjHLLBlddrQbrI0Pg2Rt2GJHCrSBxWCs4XqS
PUwtYp0+C+FoWSGWUdtU9/SbyGy3PAalgL1DddywzkpYYKU4le27UXfstNZ+s7jnIVH6a3wv
IuTQ7ZHkmY+dt6Ny67iMyS5gndCLH31x8sO4tU06SDlYa0vYszMONOjBSjl66qZjTbrqvbGu
N+Jjzrn41sVzezwEhevoqKyiMyAYVj8EU4U3hyNNdt9Qp069ZjJi/vCXkkXtlcRFQz6d+bk+
VAjZli41zsN7hD+/euq/yjVkz2//d8MxCYkRHvO3lJHGf1XgV86cZ8CHNG9WwQlP0bwGJSIs
ykm3ClqI2Mcv84WPfWAjW0QQOBKfYCEKMzgHAiszNojRBQ6aydXwVLi9EfqvhMBwwiaAt0Ja
3euFzIjhWWa4giIa8YhITKISl8jEJjrxiVCM4gYSAAA7
}

set pieceImageData(Merida,30) {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}

set pieceImageData(Merida,35) {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}

set pieceImageData(Merida,40) {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}

set pieceImageData(Merida,45) {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}

set pieceImageData(Merida,50) {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}

set pieceImageData(Merida,55) {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}

set pieceImageData(Merida,60) {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}

set pieceImageData(Merida,65) {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}

set pieceImageData(Merida,70) {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}

set pieceImageData(Merida,75) {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}

set pieceImageData(Merida,80) {
R0lGODlhwANQAOdAAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoKCgsL
CwwMDA0NDQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZGRoaGhsb
GxwcHB0dHR4eHh8fHyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygoKCkpKSoqKisr
KywsLC0tLS4uLi8vLzAwMDExMTIyMjMzMzQ0NDU1NTY2Njc3Nzg4ODk5OTo6Ojs7
Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkNDQ0REREVFRUZGRkdHR0hISElJSUpKSktL
S0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVVVVZWVldXV1hYWFlZWVpaWltb
W1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2RkZGVlZWZmZmdnZ2hoaGlpaWpqamtr
a2xsbG1tbW5ubm9vb3BwcHFxcXJycnNzc3R0dHV1dXZ2dnd3d3h4eHl5eXp6ent7
e3x8fH19fX5+fn9/f4CAgIGBgYKCgoODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouL
i4yMjI2NjY6Ojo+Pj5CQkJGRkZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampub
m5ycnJ2dnZ6enp+fn6CgoKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqur
q6ysrK2tra6urq+vr7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7
u7y8vL29vb6+vr+/v8DAwMHBwcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvL
y8zMzM3Nzc7Ozs/Pz9DQ0NHR0dLS0tPT09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb
29zc3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl5ebm5ufn5+jo6Onp6erq6uvr
6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf39/j4+Pn5+fr6+vv7
+/z8/P39/f7+/v///yH+FUNyZWF0ZWQgd2l0aCBUaGUgR0lNUAAh+QQBCgC/ACwA
AAAAwANQAAAI/gB/CRxIsKDBgwgTKlzIsKHDhxAjSpxIsaLFixgzatzIsaPHjyBD
ihxJsqTJkyhTqlzJsqXLlzBjypxJs6bNmzhz6tzJs6fPn0CDCh1KtKjRo0iTKl3K
tKnTp1CjSp1KtarVq1izat3KtavXr2DDih1LtqzZs2jTql3Ltq3bt3Djyp1Lt67d
nD8WLAByt69funn3/v2KAMHgwwkBKF7MVDHihoUfSx64mPFSx0xjSJgQI2cBxQEc
ynj6o/IQm1wqqy5wULXq1q4XUzm5gcCEhYoHnEgxAHPCCQQ29PStVDNnz6BFkzaN
OrZi1gadE6csfbbJ2rcVOl8IXDjP6UZ7/qsecNNAZcPaAVBoKsH1epqpnUMvKB0A
bOfWR1JQjd6gAgAO0PPPP/W0119BCKiWXU7gFSVeZeTZZN5iB8L23lLtqXahTPHF
Nh9B9d0XW34i7XceQv/FVuFACVa2IE4NCtXhA0AA4cBiZNSEAQAShLDYCghVZsFS
TihWBzjg1KGYFPApxsaTT2oAwIfU4QAlGzQ0qBgGV7KhGIkgbaBYBDnsCIACsP0y
4IC/NNgiBjlEsKVOMQbVYWw50mRmZUCKOKRSRcbG5Ex3riaia4eqBuZHYrqGZnTS
HdSiahjQaR9SikEAjj8D+sMNA3WyJAMAE/hDDagALGBQAAAkIIVi/j4opVgYa/7z
RagqxVfrP0pSKZBi39S6jZYAsLHrlyQpRgin/yBDLDO1UkNsMp0mgqtLWQKAA6b1
XTrTqK6pWhCrlcWaVIiESudrm5FCil+y27kbW6KW3ZTttuEBAEE9u/4zD6gRykSG
Yv38g88V9f7yAgABjNPPDtf6pJg1tVoT8Um61torbMGuOay3IBZ7LACLUmRFYgDg
s6Y//6UAKRy1MgLeCWcy+08+in2BEBYr3SgdAUM9KF3AMQ0cr0ALI3puuxyqS2/C
1L2b0clBOucyfUwPRLNzOh/Es0o+Owe0UIqF0++AH9ek2DtrOiOAb4rpMaA+oD56
lGLT1CrN/sUmZbymkqEVxAOwwiqWA6TG1oqsRRlC/QsTBNfKAQCVFiQCw83YYw80
vXFg0I4d1OoPq0WsWpkDKREggADkLjYA1UF16/hL6LLr6NJHx1RoZYETNLh0h2Mt
dUWNgwe5c5UTdHlsnhe0p2ulj3t66qu3nhvsP7EAQARndwpqCzQp9kyt6qT4y8AE
3LNmM7x7N9TbP9TqAwBEw+T3gErW1zHa3Sa+5uIUQdVrsOaONeWjN+YqyNtUI4CD
DG4A+ViTO8CjIpbwDSfakx0AwDeTbp2vWwFwn1AW6Jr6vWR3Gkxht0r2EAFWRl6q
SSBBSLiYBhrkd/MS3olWcsGbPAAA/kjo3oByAIAH0ORtXdgVPH7IMABooVb9YKJr
VBAUo9GAGMQAV03ux6tu7e8fH5OO/wYEwIk4Bh/8QMcFAGBD6nygHPVYB8RAVpAE
VMZukNrBOupRDh/RMUEOIMc+8sEuJ/CQjkKRYreMOBMaxsZ6sqMiUIymtHSp8JKy
Y6FDnNPGX+WujndEWQ5Z5BxDqqSHNvnhEYT4DyJCgCalQUDB5vaLFCmGG7u6g5GS
YEvFGAAoH3DNCLaomF3545jITOYx+6XMZtqMjCSrSIJGUCtuTIeSlXnBQiQggYVk
UDVdwFozakXETp4ElTVRZH1eOZPSSEcDQnNNHXipml/+JJiq/hlmkzDJz+FJZFKV
FAg2F6NNhXDTm7EJZ8hiY06ToJMm2qPAM0X3Qw52EADgGJA1eqmYeOzKG4TzBzt+
UQEI/WQIlYnePlnJ0paerYwRmVWt4kGsxZwGN4g0yPxeCKlz1IpdhzzKN7tlUZk4
JwzvGF19zPEPkZLUpD5B6WJUasl+WlU2FandQhVz0/QwZKez0+o5cxo7AJSje+J4
qEgUA4UB+WwE0PBSAPixq3YoBlor+8YNKrOhnEzIl80BgEsH61KYQuRtNahVOerk
BAzQoCFLYogMMGBK2GCjVq8i60jUelHZ2cQ1EGDqP/bRLdF2Sq987clfAWDPfV71
qppk/ogjeXqQxj6WIZFdyGQrC8MBpoSzMnkbBlS2q3uUtKG0A808/mGNH4SDU+3Q
Zr/ooRhinO0cKaAtThZwV2UopgHEFCxhx9s9wz5Eqrg0GAxCdS189jVNCWHVB+wx
oHKwSpIpOYEJkDJb1yDXJa5JAHH/cY9unbVf2NXuTbirGvDucxsQjrCEJ0zhCls4
wtgwr0OkOkr4KsS9uNXsLyC5GPyiRL9L+wBd17SPRqmNjYr5A2H1oRhndM8fG11M
Z24CAcewSTEvst9rXxtbhpArAh8QDxTSw8j4zo4gDMapADowgSeHhASuEYFRPBu+
ANM1HlQgsWo+wIwIGjPHitmx/k16HJsgn7CY5I3zmvqhYYeIeckoazJCWreQKKcn
oCXBsmq0vGUAUGtNxACuRxJkAHZcTgHjtcYv9sHKe3C4AzYx308Vg7qmDdmqRZat
amqAUxHbztRWFsjxFtM7k3wmNyRs7VDEChOAVqYGXBCzcwYQhnb0y9KLwXRNOKqa
TutOMeOUc5y9G02LOJLUfy41qnG16uSg5NX0i3W+DFGrOdCPJkXA2z/aQQKKKVuI
/rDde10yIevuil0J6CwARNCletv73vdenqIF8gEL0EAIIW52kAJgHoUkIdUC4YIQ
LiBslNgRActQnz/g0QXF4DEo8XQduD/tGiewTXTqpslq/p0Tb6Mqxgr6OLdL96EF
hD+k3/8OeGwVXJCDX0vhDFfJwyPeVIpbXCi9jEatmP1zmCgmBRMdrcrPZg1yNfwl
rAqAufsljah3dgDVWLoQrfEgj+BK44nhQA1EzGevruRWAWBHv4AaFGI75+IWjI0B
Rs7PLqivYk6Xia5d0+rkAsACXAi84AdP+MIbvvBS2jfWSm3CrSqk7ChjCdrV/m7F
m+R5CfjDLAfUDz3YcTEXcEkYFOPTWp1jcIzQ+q6qsRgYvORWAEAAOVgZjgnN5PMA
SMTmVZ9uCn1EMYQOUgTelpAYOFFmwY9OANqjkBJYPiJvu0L3VgCAsfXkeSkMfUtG
/k+paPRjHxYYMgKysfrWv56ft+e4BleUEeD/WbPGX0zyddj85x8WANI/G/Wtv5PP
WwAZ8pB0nSIPx1BSsdcSa6QCtbIPFacYHKB6u2IMLicSy4MBHsVS8GCAJSATzqcY
NzBgS5cPOKRPHkEu2mECRbKBB1Fw0cAwCBFMSEB96dF3FQEurpE8WGNjZ8M+ZKVO
ixECLIF7mMR+JrFGlREImxcoQ/YLzySB9hcR+oZJKggTHZgbBXCFWJiFWriFWig0
JNgRJihKADCFBbFaNMhvNBcyZzgRNkgpVaOD2vAADgANA8KDCOGDigGEKoEqjLBi
LcUPf6AY4qISrKImA5IP/vgEADTgaxCIWRP4ES1SA2bWUvgQfyUXE4tBAdsgDpzY
iZ74iaDYidywJyJhgJcYHSYAUmSlGOCgDjFySzKIInNyEXjoGrLGLtvQPeBAHF9A
ABoEdyPhQvw0iClhPck2WiOmfoGwK5llaiFha5h0in43AgKydPSgb6WoGNK4Vavo
WzqkWSmCgxRRi/WENbn4D1VWfZyyiyDTi7+IEkRkH3HGLtD2WwBwDJwXj4pxaI24
JvqQjsZ2EuQCB7vXUv2gBtYWE76ofmAXEmCVGCbQD/9RNfSAM6uIAPwQi/cBcBWB
TUCCDeSADuJADb+QA0IjbIqhDN3TgpcSfothAKdh/g3igA7kgA2/QH2LoQUmoY9X
VY8o8UK1Yg8MKW7+CJCE2C0UYCLSsYYrsZAKcGDKVg4p0ngc8ZBV82SAFjV1shgc
SREe+QsgKZIkaZKVgZIAoJL/4DMGUDAsKRAu+YNwUAzW4A3ZkAx3YISKoZMloRhF
IIAs5Q9C8ISQJY//4ISM0Y+7klaC+Xg+djb3kAM7AIKbxkYzgX1DJo4gkYZtYgL/
EAgAwACtUQCc0mMH8R938A8aSX8VEZiKgQbyIET8IA5h8CAtIgTdczx/ZQB3YA4F
WSvygAaLwRfw8mmHRDm7R2dDiQB3NyCK6Yxg2C0+cExA0C3/tRJmMgYqNwaz/rhZ
WFkZoNlbpemNjreai+GasCmbtKkYtvkPeqAYMPMPuFkZOUANklkr63AEwUkSqREA
Fxhn8cAq2ONQADAOoyWMUMlS5zANKTdeHXISPoOP3ZMNiuENQsQubtYSHhiKGhqK
e+Wc7TcA5nE19MGZrohI4cYCAxJuo4E16ICaOdUC9JMgFqGNBOpS+PALABUA9YkP
1rMAxbCgLTUO5jMSKNRPAbqXinFZinVJTPALjSIdTrArDWoSYRMpP9YtFxp32Hlu
2umhGFEZIsqNJuoaKyqmBwGjj1g1CVCjlIijvKMydgUA62Aw1jMAhvCaLqUNtjcS
/0EDKrdXRBgS0ykA/pTGjozwC2igpC2lVHxAXvfwakW1VgCgBqxkMQBwjt0THxe1
pcrWpQLKdiM6IDvSpATxQ3LzD21yi0igHpySmtTxC72RVazFiISVD25QGcvQL0QH
AIQApIPlDnsaEm7XT4EKEtOpGHR1D7/wDdIgJyk0AAMyQd0iDrXyqIoRqSGhQYZ4
almTXAHAheDKhWE4nDW1GKQ6ED6oqlnJrbJqALQ6IPtgDtiQDM3wDdVoQLe6GLn6
DzVwAwOyq0jALzPFDcyQDNmQDn44IOnwatxpiMoGqgJ6mjezAh3gqy7lD4qRRORl
OyWRIApgsbtiqZh6NvhgHnoGYADAqXLmqUiq/kafiYo/1nd3NSAZRkeFOCCu+gs3
AgHSShEtQn5ytg3i0QHP5A8d8BxfNF4f852ZyZD2qBjLwA+6xE/Q+g/U1S0pUHmL
iSDaeqWLZHLqJ6CLwbRamZCeBGgkZhBV6qVcCwBA21TWIAMktgE/KixDyykQ1lRH
yzDIUK2/kI4QMgRmsyaWSrZeBwB0eG57w7YYATkBsFwqh5yJEGcle3Tw4rCiUw/0
QA+JZmibSw+9iapbG1Mpm52jGzLY8A0UxJlWOx2K0aL/0LMhc4HUFwZYA5IPBSsq
Z02KMXtrEg6gkVHnJlWSGrYnUW2vBWn/wA4aJLwDUrkAEKZN6xwVsAPW/it0/zAN
1rsDifdJGOq0SEpzHcatUBMbtmumZgQAPrAm94CT0rEAzGAzvAsAs7cPKQe8ULsm
/PALdKcaSEBpA/I7ksqPcrYMp7t4WgcPMzuPaSqr77omOFAfJ3A263DAm1S6XGrB
v8BdajI4rTZ6rPsP6/UBIUNc/FCIAxFMCoizAMAFBMEqMOAP3gWMDDEhBypn7IID
taICitG3KncORfd74Cu2n+av/3ANGhTCXkuuqmEBobsyJtCt32u8JMFgrEYQ3Ddm
YkociVgZLjwQkETDC2HDnCdokSSwoqstO9yY//AOlukc6/kPQHwm2UqYD6vBvxB+
EgDAKmfAAPDA/oNVD+QiQx4RxQ0ggIAbGwlwNv7AXV2JsiobZyxLEgvDBP8AD6xS
pqkRwm0pELfiALUiJkhAHcdIfbAzdgHga3ywQemrAH5JWP6QLeowIOZgOK88WP6A
KnVMxSTxlsSJPymUDrUiyLAiElHsHCjKUqsKx5g4xCORNJWhyUcDe64xymerGqfs
Gtg6mK48IIubQhZwd7GsGLP8D7U8hrMUD8PqHL7rDz4TEj8UOucWTAHJnc57bv1Q
ZaWibDbHuBFhHi/QPe1ADAJhc19MDHN6NtqDmYcUyeQ1yclyAQMiM95iBQAQwvoQ
qwIxOUBQKxbdZAwzYNSHZ+wisVmSJ6Tb/tFaNw+90QQDQgX0c68qh5/+/BDkiEn1
XLyfZgAqww8NkEK0Uiv9LBL9yxjUcA3Z8HHtMA1M/Qv9tZ0oy8vc6VsWPUqTExsg
HRskjSfpq9LwiUkksGIsDQAu/Q8wHQAfhw/Fo0HcNiBNMLqKIcxyVqJjlX9L9wxs
HGeqWNMPoRhlXamKMbK3+W1Gh8GdisfIejPcxUivosQW/Sg3uyZs9x9JUCvU1wQC
IScCNiATmb4Sq3WBqKP3wCqTq3qrzNcXTJxE/Mv/wHopRAC+utc67UFe2y1U+bQc
N1aqwdhvJxB7JxDDitm/4Kzi2dcA8Nndq0L+E9r4MNoY7A88mUI8/iDZcA0AHZCw
g8UPR8uUHfEfClCfcQYP5qEAkxhn/dAiJ8sRrJIDLSWyLbVXYvyThr2yiA0ABfQP
zoAZb63E7OhJivoPquhJ6cXC1pySz5u7drx09fA21iAtAkBfqgexhztk3M0R68xP
OVAw+2CAKUQNUITeIbF3r1Hb9RHfup3bq20Zbx0v6CIdBT6+xu2wwphC1EogDC4t
AHCBzNBPWXul3OkE2M1S/AAFGhx//61s+GAmx6hswLm1+/EALYXEADDgQnQjX/i9
Dj1eEM2d5+gPl9NAq6rE/eDI7HLfAyIPjoGfGGnZAHAavdEBs0TXnt2IkAMF4dZW
EHjaU31V/iYRf+q3r+TbLUWwK02O2gyhlLSdxrJz5XEn1bNdQ7+wzLEBcCFC07Hh
5t57wZ/tyypUAbNU5+GmwzcDjRpkxGk8EmbyApDbUvOQNCSMpKu0dPCwJ0ceZ6q7
tawp02cTDwaAAKvePfOQsc2c5YS15ZLqsOfsA4GpxP8gMwEQmHPlDVDQBNvQD70h
t8e9K9TnA8cKldOA4EEEgd1Qfb1BoRC44qj+Wq/OxJ+2AATNTwLgq7du6AvBmrLz
BQNSBimkUH6H4uHrGsq+lPYeG9juHNwuxRcc7v/QgPykg+NOAL2RN4qOSQ4LeySR
jqHRUskIABpgEr2RABCubPoAq5VR/trntg8LZLgcUV0G+cSTaXLEPljGHhKfQQWO
OCUXvQ9/gAEwMA7Muxgc4NplU4UAkA7z8At6cFbU92p/Lbq3jVMN0Ij8IB4DEOTn
xkQXb1UdXxIZN5SYZO7wmvK7DEJQAAUirpmn5MwjgW2uwfZD6fZQJRHftSboYFU9
fsKLEUH+8NP8FAB4+g9mUhIdCgBJuyvz/sgiESjXcG714KaK0YEKf276GBJv8wBW
T177ADAwb7r0DhEjAAAPuCb08CAlgDDJIUAMIDQMsLdFVA2T8gzuOwAyHW7NIxGo
Qnmqt14AwN4QKK0RIPj8hPghoYQMSfSYdKprMvkg8dSv9fTy/u3oIfH5Xv9atR8R
t78mp81PCypo8iyt6LcmaL49Y5V6FYrH7GLq5MUOV9A6j6IY0710HFvH5K9y3tb5
G6EYMe9SMw8SZ72cik4uAJFAAACCBQkGsGbM4EIAARoiKPjr38SJFQAg+ZVR40aO
HQm6oRhS5EiSEwkRlFhSpUo4KDu+hBkzJkOaEWXexOmx5k6eABRk7MnTgshfNnMe
5RhU6UKkTZ1qXLr06dSMVKJexWoQI9WPFPsNyQqA3cQyBMtMvBYWjT+KRQFQnTrw
7Uq3A+A+JahuYj0pKVf+u3fFoIWNBJv8RfzvXEEud29CBBAtsUqFPh1fLgxgzOSS
Y1xi/s5JcAGyfBP3RTBYQJ27FgxJ6P1HLQHDBNHEOSwYYR9FeVbfwi24jvNft8+G
r0x3EHROuUvtLr8ZtiZhqNIB3Au5mGBj6BshW1/4sztw8EzHzyyf3uDd4BT55cia
baLblG6vumE7Ud6Ahud1EoTAnpXugaCgAPzbSAEALtirQADq+WsbBQm6QSdGjiNp
H9wuQNC+X/rBkB+3BOgQL80wDMmz30qs7qARcugANwAagO0fdn6Zo45f1slvInya
aeKEEqBwRp+JsmkOgjt+CeSE9dgDIAIBURTJGYK0oVIkehz4rETrDixxwoK6uEce
1KKqMCnrwAlJQ4I4RFA9gkhk/hEpObtk8U71HCPIAuwm4scHrIiZD6WJ7sDqlx7z
CQHP8ygoSAhujPxLn214KAhO/wz9BwiC5uhxJH/sU+ElLgjaJsuQMDDKP/4A2OAa
EPN5hxxvsIkmGmy8Ieed0vixhlUACqizKYI2y1LFYoHiiUxVQ1KHg54cc7CDKVW1
hqBvnv2HHmExYBHS8jQ9byE9KFJjqVI7OtU6vyYSdkVXGbImnXny2ccff/jJh550
tGGI2GVDu3NgPdOjliBr3fvhqpSSIaiZiXyTKiR7RiAI3A4LagEdDM1JQblNI/un
HoKsWIkfJghCICYDCIKQWyha9a+EghJ4uScDvkth4KOO/lVV2WUJiuEXHzZYwAIg
fpmHW5H6weYHAgoyQAphLyuAIAriGY4ffOiBZx10yqGvnHTYgaeefEDkrJ0HCBJv
YznBLLcgCNieprmdWoYpZ+mQpWhmR8ezmepQRf0OgJ59xklPg4MKQIIWpFjyF2am
0Yabb8IBxxtuspFGmYzYQKIEMad1LOsoxwIUB4MG4EAIN34hphpvxjmHnSmtJLnb
dc4Rx5tpMiqDhwtkBICPkNJ52zK5Dzycs35+wW1kbP4hh6BzVOpnB4JIkIkgGpz+
x8M6/Y6Kb8YbPzHZwRG8oKF3yE/MH3vmwccfeByaALOcEWDTSOpRDmf8QgsvsIDq
/q6ygA/8QEfZYEdpRpKNqTlPbo6rG6e8oRTwocc6KiAKzRCUs3MRh2XrI9gOyrFC
FrbQhS8sh/fkxaL4LaQAMUhENMxRj+iFSB7iUAYcSqA3gvTvMjkbgHEmoo8dMIIb
8+jhSKRBkGkkph/xuEYdpMC2fxwDN3EbmQLSwa1zzGaGoCEIoe6RgzBwcSSCAcAR
ZOIgLDltGSKMEwCuYLlvlGM17khHObwhOim8D4VqkpPPxGdFfdQjHu5YRzrQYQ5z
oCMd63BHPNTmRpUI6oxw4RJK9LWOXwDhdAcDwAScQAx19GNUBTHiBQ+WQQBI7B9F
CIocY+Ig6zxAJHc05HgI/iIcfADSVrxKhzvu4Y94BPOQzAIcioQ2NIKUih2cpF9I
+IGOXzTKmU0JJQDQwA8qUYMg1qDSPrQASy8BgAHzc1o7JjQeDcSxJN2AQ36iQRAn
RCeV2KRSN/B4npABYTI0AMC6nvkSVA7sBqgKST7WUY1foAEHHUjcUhDQgRuU4RfV
WAelJiIO8UHnAwUxQQNqUoAO5KALjPiFMZ5RjW14Y3Ph+IY3tlENZxTjF4z4wg4+
gD6DKOCkBClBnlA50LvUU2HWoF5B7lCOcPLTn+AJgBsF+k3QhAwAH1AgTQbwgYEo
dKFqMsD2snSOnDmUINfI5mTYUdLlHBUAI4iZSPxR/o91eOMZGflDGaBwhB90gCAi
cAIX1GCIjDyDG+eQx25Icg+MIbVEA0EAPLLpjpc9BzoAEMCfLPay0tTjZTC4Kjfo
V46CLE2p3ZgMNriqSAAYgA23xW1udbtb3ZpxYPxzhzO6YIGlFgQDY5CGPAxLt+Ws
LDxLwwY78EG+fLhjG79IQvOedNniEsSzy9lJCdjiqYKgNnzqEek/WEsQ17YzK2fV
CQJqlCV1QOa3qSSnSvzRSHiwQx2TJEc4wkGOSqoDbfXQRxQpAoP+dMe5AHgAO/wh
D278QgofeFV6HoCDPyDDHNOVh0VmexcJEMQbcf3HNjLWHYLUgJOBAMALJlJI/jC+
JGd1yKY6CjKCOrkToCThB0TgmxkECCee86RmTQJQgRc0oXLIcEY1spE5bmwjG9aA
huh+8Qcq0EADGaYJgibAz3goOJv0KAsANFCnEnd3xZ+lSQC2p48KWrBvchLtP3RM
EB4r9b1DZhYATlAHQhfa0IdG9KGdNGLMpHEi+UAHNH5hBRhUgKhRMQAFXkCFXzzj
HBJU8SdBM2YADCCsbn7AhNas1Hdlkz7QERwQJIg9h6AzOaLWCGRw8GMquaMgD2DR
y/xyj3kAchzjSCb+KGKI2gIabu3YLJLr9B0CyOAX00CHPcw8GX/gYx3YKKUZAZAA
uYUBxStBFK5Z7Gam/lJFcEyZiDK2C5OMgoceIfE1QYBdIr8pQAZzyAgxnOEMYmSk
DjVgANWcze5lQSQBhHCqmzVgCIuQO4/s3kmdHFKB/KKYHyX+LmZquACYOsEhJmCL
DAQtkwnBQLL0yzcACKDU267g0gZBQAvckOYhE6QB8NzsAhjNJwBUg9f080f21I2Z
qYng3CphQak1jnHvdqeGBvGBPu6h3ROwXE/3pkjMZ97ObUw3MflQes+pnmSqz/s8
dW57QUI+MtU+/R/ZGHpOxGWQAHAt7TFR6UVeTr93uJ1w4EnqQiPSDcY33vGPh3zk
HW8+pcrH7iEh6dIvs4JSHz2b/nhZ1/289u7s/l3ucJdJ4O/UNIoUvt2YsRkIj+Op
xD/Tu+DQV+51v3ve93734HhVseKMASEE4triUEfa7qEPfvTDlf3gxz7wYQ95sKMc
2ECGhUcA5tdvfvjFP37y67H85j8/+tOv/vWzL4Xt00T0HRrICS4/ERLI/DyvCoBD
zlGP+LW3I82rg22jEngwvHU7CAxIgj/4BWWIBmuwhmgQHT5AguMpwIGhGKojgx6b
C5HQB3k4B24ooF8wBDgIAypwAiZIAieQAi5gAwVcQGzolfwJIc27DIKQB1G5B3co
h22AhoIDrDuYAzi4Az5IBI1ohmsQh3Wgh46jCJOhwcsgInYbu+7AP+QB/gD/4wjt
upMbpAgC7D6iQ6fjAIe86w7fMIfLMweCyEA/24BAqIZ3YEJu8Yd5qDAVqB73asM3
jMNnmcM6vMN2koz5ewYydIpS4w8DiIk2a7Vs8kJCtJMrNIc9LAl+KAchcETQuECM
W8MScQgtyIdyMAY2YIFTso4CGAEt+IVwuIdTYa6R+YZ+aIfhEQIKTI8GiAE3OIZy
QLtLfMS4e0IoIQhEhIk2OxgunIhG/EWuWAB+mAdv+AU4AAISkIAFKIACWAAJMIEi
0ANjCId66IcxWyjf8Lxn6Qc1nLoPmD+KeKhWrBt0TMd/eKhkpIoaGJb0ejp9yJoi
YBEGCIDFeQlh/imGy2umL4QLBRqAGvgFbWgHswsJfGAHcIuBDBNGFPINzfmGi8TI
jNTIjeRIjeQGc2SRk7LCmjAABoCACtCAD/gADagACGCAm6uJDVCqCOC+oBiAmgwK
+yoRevRFANDHEuFHf+yIeDkYrqGIgeTFm8iaBCDFoHgALpnI9fGNfXC+qrTKq8TK
rMzKfQDJEjmpARBApxE6mWwnsHxHoZPHuLiId/yHIxiWhTIBTrE7ZCwRYlyIAWCA
CqiABcBJAKCOQxLHyytHANjEDvmC8KgBNfgFaSgHd6CHtUGMfugXHRweN8iBhDMI
LBi9A+QBHakGcECHd1AbqgwVf+iHfWik/ndAB3CAqjvwAQ2IQhaJQowTmEOKy+Iy
ymOswOWwy6z4S4r0xcJEkMMEALCbiH6YB3OAqopKAho4gQ64AAqIAAiYAAvYABJ4
ASHgAkL4BWcQh3cYPHwgCM10L+P8B+RUzoxAg+Z8zuiczuq8zuzczu78zvAkSChZ
xKd7tUMiCHObP7qsEyioKp6AAPI8q8C0u8EUzjz6BXK4lri6B7JJypyAiJbBhncY
RwzpB3jIhl9QEHYUpp6cUGBcqtz8BwBlEQFdigIdskxktwV1RXUohi+IkTuBADkS
hzFMy6mAjG+QURodSeu40V/IUZGRG7VKxzTcUfD6KkmMKxQtlpUZ/gBnRIltcAgm
ALSqIIgMzRIFrZPWGAAnzaZ+eBkWUKovYMuWWFJjEdE1bTQ306wu3E3/WBkBoNK3
sFIAwNIsdVE3g9HxaI2eNFP36kmlMs/Lm4cRnQpPMrL/nNO6kQhiIIhlKB9FxcQt
Fcyu7BCH8IHI1Dp6kId4iAd4iAd5oIflG8ckaDC5CcN0xDs3/Zk2PSRP6q441c37
RKO5oI9KhdXx6NPu+tPuCNKGsAAcoILKeYZpuAZt6AZwAIdu0IZrmIa/+gU9sIId
wIDZXNWLY4gAKNZjbSxlZVZnhVZppVZrxVZt7VX2mbX5E8915QoAAIl3hNKnwIIh
OIIioAFU/pSJQgIAJ2AL4oSDf/AHSwQA7ogJLqCBIshXAz2PQLXIjpTYifXIFtPA
Y3CPd7iuP0iCFJiAU9uJApgAFUgCPviFbXCHlwOmEmmXB+0HeSiH4fmFLxiCFggB
DHiABcAZA0iABXgADPiAFtDOIowGcogHJrQHq5IlX+RPdrPVE33Um7jXfN3Xm/BX
gP0H19FTgjVYhIUJhWXYInBYQCUIqtTKs0VbrORKAEBIP0MAGvgFa1gHbZPDe3jI
X8gBcWPZgnjbuJ3bsPwLf7BbcMvbgugnueFSbhlMFFqnADDG+Yu5tASCYTWIBBjU
XxiCVxECcgoygmAAENkHTxqAIdCI/hWot24VgssggzbNuLoBB2y4A7s6mA5gg2nY
qjD5qn5Qh2Pgghq9kwDAgL6IRMNSn5ERUcbFOBON3KeY3KCwXI3IXMPIFycErWXS
B9El3YwwXchJXcdYXZpIXBQZTIYYmRMA3GfxJNwVtPNVFU8q3roR07jiB0ttioHI
Abb8h3aI2o3wpgBALWcIh0ACB6MB2YJYAGNgm6IQgIHA2PM8BrSkCQMYAmIIB3NI
B3AooBbAjT6jiu9lXfIdD8PqiQBogBDYAScYgz+AqY0wBDagAiAwAQnoS4MgyzAq
4IUIgASYgA4ggRNggRdIARL4gApQAHWVu7Za2rhDISOWk8fV/l9c9aY7WeCD4eCp
8OCFCF8NrYnzEOH8PDdJhZUL8mIUA2N4RY88u7ykNeNCBABmwN89G7EYQAmGFBV5
+IZfUAMWgIAO0AJs6Dh24I8doMcBcAeK2AdrsIIOgAAWYINf+AZ5UDB8cIsWgIvV
DQBywORM1uRN5uRO9uRPzmT+oCW+/YG4VQdvxBDBbYcKowJe2l/yYAgEiIFAMAZu
YAd6sEeV2Id6aIdvEJ0dwEwQ5lamXR+qyys9e+VfkOODEWRUouQOroksPo7xNQ8D
RFKR2Ad6sL5uwLJk8MFfKAZlgAYpC4d1mIcEK4m5ol9EuuY20eZy4GZo8GaNCOdx
zoZy/j7nKFLnNWYoAHjay8s3FCII1nnH9WI0uaQSehAXZrGAQ8WQ/bRi0MJflcia
DAqAHEAGeGBfzqgHa+CC70AQ+CiIBoCDa3hc8qkHbmCEq2PbJG47gcY4OjboZGwo
+yiYSq6JBdbpnebpnvbpn9bWuiEActKfDqWCEjjdpRAACagBOPgFcICi80Ti8xDp
oSZYDv2Fo05qpVjqpn7qqCZTi82jVp0/c+Lnoziqdp2/b0jmXwiDUuNCe1gHc4ig
yTgHB1mcqIOwdlaJfGAHuv6T/YDV1RWAiS6Jig5RHzjmy9MHOAqDeRmAO1CHjaaS
ePgFiKAT4y1UxpHd7ho8tsbV/re+k7zGIJz+YGGGsw8wBiCASTlBAB/4haN67Psj
CNVmbTd77dieE7kpoXTUg3XOiQoavPmTLVy9bACoEC0EAAQ4AVTEhnVYJkCBh2mQ
IQC43F/AFILYgWmAh/wS3G/7hSswgYyCALy1s4gubMMeCcSGjoiLAELwBjSmH3rY
BjgIpwYw3hVQBhM9N39oB90G7hbZbJ+Bu+5yo+Ieuq3GiuvO7vSosae44tNe54hr
U/weZVlFEEhpgDHg8A738A8H8RAXcQ7nEo2hrX+lghRX8RVn8RZ38RdX8UXLu6sI
AAXgPhC1ae9SAMoNM+9tiBEH8iAXchB3iPOo7oKQgH6q/gbIyuW/6Ad8eAdxKCAf
COaCqOHxEIGFeIC+EAd5kOaR8Gtw44GM2jf/ML22M/HHwTgnWHEZT8v0wPE98XEJ
b2ukOHJfvPLuyPIPLnPNfulilvCnMAGLg4kYUD0cbgKZ0FqasEWZQIDrhmY6N26n
iOI4e4APWIEcQAI21wItMMEiqIET0ICmNIgIKBYfGNYHYAEoqJxlmIZs4IZuuMhu
2AZcOYaMGAMgGKqdqOJhJj3GoXNBJ/SXMHQlS/SYWHSGaPSYeHTVlfRJb4pKdzNT
rxNU78le9w+g1vZt53YUau0/z9KF4vZxJ/dxLxYn4AAmvgoJKOVDUoEZTo88l81y
wqd3bff2QA93ca/3faf3c0/3O2H3Z3r37pL3fDf4g0f4hFf48cACIHiBEvgADsAA
DOCADyABFvCBvlh4JlABCOBxmlgAEcDChSf5kjf5k0f5X2j4h4/4ia/4i894kud4
j8eKkB/5lMf5nNf5nef5nvf5nwf6oBf6oSf6ojf6o0f6pFf6pWf6pnf6p4f6qJf6
qaf6qrf6q8f6rNf6ref6rvf6rwf7sBf7sSf7sjf7s0f7tFf7tWf7tnf7t4f7uJf7
LA0IADs=
}

set pieceImageData(Merida,85) {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}

set pieceImageData(Merida,90) {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}

set pieceImageData(Merida,95) {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}

######################################################################

# setPieceData:
#   Given a piece font name and size, resets the images for
#   pieces of that size.
#
proc setPieceData {font size} {
  image create photo e$size -height $size -width $size
  image create photo tempPieces$font$size -data $::pieceImageData($font,$size)
  set x 0
  foreach p {wp wn wb wr wq wk bp bn bb br bq bk} {
    image create photo $p$size -width $size -height $size
    $p$size copy tempPieces$font$size -from $x 0 [expr $x + $size - 1] [expr $size - 1]
    incr x $size
  }
  image delete tempPieces$font$size
}

# setPieceFont:
#   Given a piece font name, resets all piece images in all
#   available board sizes to that font.
#
proc setPieceFont {font} {
  #set start [clock clicks -milli]
  foreach size $::boardSizes { setPieceData $font $size }
  #set end [clock clicks -milli]
  #puts "Font: $font. Time: [expr $end - $start] ms."
}

# Ensure the board style is valid:
if {[lsearch -exact $boardStyles $boardStyle] == -1} {
  set boardStyle [lindex $boardStyles 0]
}

# Set up the board style:
setPieceFont $boardStyle
